Class: Aws::MediaConnect::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MediaConnect::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-mediaconnect/client.rb
Overview
An API client for MediaConnect. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::MediaConnect::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_bridge_outputs(params = {}) ⇒ Types::AddBridgeOutputsResponse
Adds outputs to an existing bridge.
-
#add_bridge_sources(params = {}) ⇒ Types::AddBridgeSourcesResponse
Adds sources to an existing bridge.
-
#add_flow_media_streams(params = {}) ⇒ Types::AddFlowMediaStreamsResponse
Adds media streams to an existing flow.
-
#add_flow_outputs(params = {}) ⇒ Types::AddFlowOutputsResponse
Adds outputs to an existing flow.
-
#add_flow_sources(params = {}) ⇒ Types::AddFlowSourcesResponse
Adds sources to a flow.
-
#add_flow_vpc_interfaces(params = {}) ⇒ Types::AddFlowVpcInterfacesResponse
Adds VPC interfaces to a flow.
-
#batch_get_router_input(params = {}) ⇒ Types::BatchGetRouterInputResponse
Retrieves information about multiple router inputs in AWS Elemental MediaConnect.
-
#batch_get_router_network_interface(params = {}) ⇒ Types::BatchGetRouterNetworkInterfaceResponse
Retrieves information about multiple router network interfaces in AWS Elemental MediaConnect.
-
#batch_get_router_output(params = {}) ⇒ Types::BatchGetRouterOutputResponse
Retrieves information about multiple router outputs in AWS Elemental MediaConnect.
-
#create_bridge(params = {}) ⇒ Types::CreateBridgeResponse
Creates a new bridge.
-
#create_flow(params = {}) ⇒ Types::CreateFlowResponse
Creates a new flow.
-
#create_gateway(params = {}) ⇒ Types::CreateGatewayResponse
Creates a new gateway.
-
#create_router_input(params = {}) ⇒ Types::CreateRouterInputResponse
Creates a new router input in AWS Elemental MediaConnect.
-
#create_router_network_interface(params = {}) ⇒ Types::CreateRouterNetworkInterfaceResponse
Creates a new router network interface in AWS Elemental MediaConnect.
-
#create_router_output(params = {}) ⇒ Types::CreateRouterOutputResponse
Creates a new router output in AWS Elemental MediaConnect.
-
#delete_bridge(params = {}) ⇒ Types::DeleteBridgeResponse
Deletes a bridge.
-
#delete_flow(params = {}) ⇒ Types::DeleteFlowResponse
Deletes a flow.
-
#delete_gateway(params = {}) ⇒ Types::DeleteGatewayResponse
Deletes a gateway.
-
#delete_router_input(params = {}) ⇒ Types::DeleteRouterInputResponse
Deletes a router input from AWS Elemental MediaConnect.
-
#delete_router_network_interface(params = {}) ⇒ Types::DeleteRouterNetworkInterfaceResponse
Deletes a router network interface from AWS Elemental MediaConnect.
-
#delete_router_output(params = {}) ⇒ Types::DeleteRouterOutputResponse
Deletes a router output from AWS Elemental MediaConnect.
-
#deregister_gateway_instance(params = {}) ⇒ Types::DeregisterGatewayInstanceResponse
Deregisters an instance.
-
#describe_bridge(params = {}) ⇒ Types::DescribeBridgeResponse
Displays the details of a bridge.
-
#describe_flow(params = {}) ⇒ Types::DescribeFlowResponse
Displays the details of a flow.
-
#describe_flow_source_metadata(params = {}) ⇒ Types::DescribeFlowSourceMetadataResponse
The ‘DescribeFlowSourceMetadata` API is used to view information about the flow’s source transport stream and programs.
-
#describe_flow_source_thumbnail(params = {}) ⇒ Types::DescribeFlowSourceThumbnailResponse
Describes the thumbnail for the flow source.
-
#describe_gateway(params = {}) ⇒ Types::DescribeGatewayResponse
Displays the details of a gateway.
-
#describe_gateway_instance(params = {}) ⇒ Types::DescribeGatewayInstanceResponse
Displays the details of an instance.
-
#describe_offering(params = {}) ⇒ Types::DescribeOfferingResponse
Displays the details of an offering.
-
#describe_reservation(params = {}) ⇒ Types::DescribeReservationResponse
Displays the details of a reservation.
-
#get_router_input(params = {}) ⇒ Types::GetRouterInputResponse
Retrieves information about a specific router input in AWS Elemental MediaConnect.
-
#get_router_input_source_metadata(params = {}) ⇒ Types::GetRouterInputSourceMetadataResponse
Retrieves detailed metadata information about a specific router input source, including stream details and connection state.
-
#get_router_input_thumbnail(params = {}) ⇒ Types::GetRouterInputThumbnailResponse
Retrieves the thumbnail for a router input in AWS Elemental MediaConnect.
-
#get_router_network_interface(params = {}) ⇒ Types::GetRouterNetworkInterfaceResponse
Retrieves information about a specific router network interface in AWS Elemental MediaConnect.
-
#get_router_output(params = {}) ⇒ Types::GetRouterOutputResponse
Retrieves information about a specific router output in AWS Elemental MediaConnect.
-
#grant_flow_entitlements(params = {}) ⇒ Types::GrantFlowEntitlementsResponse
Grants entitlements to an existing flow.
-
#list_bridges(params = {}) ⇒ Types::ListBridgesResponse
Displays a list of bridges that are associated with this account and an optionally specified Amazon Resource Name (ARN).
-
#list_entitlements(params = {}) ⇒ Types::ListEntitlementsResponse
Displays a list of all entitlements that have been granted to this account.
-
#list_flows(params = {}) ⇒ Types::ListFlowsResponse
Displays a list of flows that are associated with this account.
-
#list_gateway_instances(params = {}) ⇒ Types::ListGatewayInstancesResponse
Displays a list of instances associated with the Amazon Web Services account.
-
#list_gateways(params = {}) ⇒ Types::ListGatewaysResponse
Displays a list of gateways that are associated with this account.
-
#list_offerings(params = {}) ⇒ Types::ListOfferingsResponse
Displays a list of all offerings that are available to this account in the current Amazon Web Services Region.
-
#list_reservations(params = {}) ⇒ Types::ListReservationsResponse
Displays a list of all reservations that have been purchased by this account in the current Amazon Web Services Region.
-
#list_router_inputs(params = {}) ⇒ Types::ListRouterInputsResponse
Retrieves a list of router inputs in AWS Elemental MediaConnect.
-
#list_router_network_interfaces(params = {}) ⇒ Types::ListRouterNetworkInterfacesResponse
Retrieves a list of router network interfaces in AWS Elemental MediaConnect.
-
#list_router_outputs(params = {}) ⇒ Types::ListRouterOutputsResponse
Retrieves a list of router outputs in AWS Elemental MediaConnect.
-
#list_tags_for_global_resource(params = {}) ⇒ Types::ListTagsForGlobalResourceResponse
Lists the tags associated with a global resource in AWS Elemental MediaConnect.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List all tags on a MediaConnect resource in the current region.
-
#purchase_offering(params = {}) ⇒ Types::PurchaseOfferingResponse
Submits a request to purchase an offering.
-
#remove_bridge_output(params = {}) ⇒ Types::RemoveBridgeOutputResponse
Removes an output from a bridge.
-
#remove_bridge_source(params = {}) ⇒ Types::RemoveBridgeSourceResponse
Removes a source from a bridge.
-
#remove_flow_media_stream(params = {}) ⇒ Types::RemoveFlowMediaStreamResponse
Removes a media stream from a flow.
-
#remove_flow_output(params = {}) ⇒ Types::RemoveFlowOutputResponse
Removes an output from an existing flow.
-
#remove_flow_source(params = {}) ⇒ Types::RemoveFlowSourceResponse
Removes a source from an existing flow.
-
#remove_flow_vpc_interface(params = {}) ⇒ Types::RemoveFlowVpcInterfaceResponse
Removes a VPC Interface from an existing flow.
-
#restart_router_input(params = {}) ⇒ Types::RestartRouterInputResponse
Restarts a router input.
-
#restart_router_output(params = {}) ⇒ Types::RestartRouterOutputResponse
Restarts a router output.
-
#revoke_flow_entitlement(params = {}) ⇒ Types::RevokeFlowEntitlementResponse
Revokes an entitlement from a flow.
-
#start_flow(params = {}) ⇒ Types::StartFlowResponse
Starts a flow.
-
#start_router_input(params = {}) ⇒ Types::StartRouterInputResponse
Starts a router input in AWS Elemental MediaConnect.
-
#start_router_output(params = {}) ⇒ Types::StartRouterOutputResponse
Starts a router output in AWS Elemental MediaConnect.
-
#stop_flow(params = {}) ⇒ Types::StopFlowResponse
Stops a flow.
-
#stop_router_input(params = {}) ⇒ Types::StopRouterInputResponse
Stops a router input in AWS Elemental MediaConnect.
-
#stop_router_output(params = {}) ⇒ Types::StopRouterOutputResponse
Stops a router output in AWS Elemental MediaConnect.
-
#tag_global_resource(params = {}) ⇒ Struct
Adds tags to a global resource in AWS Elemental MediaConnect.
-
#tag_resource(params = {}) ⇒ Struct
Associates the specified tags to a resource with the specified ‘resourceArn` in the current region.
-
#take_router_input(params = {}) ⇒ Types::TakeRouterInputResponse
Associates a router input with a router output in AWS Elemental MediaConnect.
-
#untag_global_resource(params = {}) ⇒ Struct
Removes tags from a global resource in AWS Elemental MediaConnect.
-
#untag_resource(params = {}) ⇒ Struct
Deletes specified tags from a resource in the current region.
-
#update_bridge(params = {}) ⇒ Types::UpdateBridgeResponse
Updates the bridge.
-
#update_bridge_output(params = {}) ⇒ Types::UpdateBridgeOutputResponse
Updates an existing bridge output.
-
#update_bridge_source(params = {}) ⇒ Types::UpdateBridgeSourceResponse
Updates an existing bridge source.
-
#update_bridge_state(params = {}) ⇒ Types::UpdateBridgeStateResponse
Updates the bridge state.
-
#update_flow(params = {}) ⇒ Types::UpdateFlowResponse
Updates an existing flow.
-
#update_flow_entitlement(params = {}) ⇒ Types::UpdateFlowEntitlementResponse
Updates an entitlement.
-
#update_flow_media_stream(params = {}) ⇒ Types::UpdateFlowMediaStreamResponse
Updates an existing media stream.
-
#update_flow_output(params = {}) ⇒ Types::UpdateFlowOutputResponse
Updates an existing flow output.
-
#update_flow_source(params = {}) ⇒ Types::UpdateFlowSourceResponse
Updates the source of a flow.
-
#update_gateway_instance(params = {}) ⇒ Types::UpdateGatewayInstanceResponse
Updates an existing gateway instance.
-
#update_router_input(params = {}) ⇒ Types::UpdateRouterInputResponse
Updates the configuration of an existing router input in AWS Elemental MediaConnect.
-
#update_router_network_interface(params = {}) ⇒ Types::UpdateRouterNetworkInterfaceResponse
Updates the configuration of an existing router network interface in AWS Elemental MediaConnect.
-
#update_router_output(params = {}) ⇒ Types::UpdateRouterOutputResponse
Updates the configuration of an existing router output in AWS Elemental MediaConnect.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
7536 7537 7538 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 7536 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
7539 7540 7541 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 7539 def errors_module Errors end |
Instance Method Details
#add_bridge_outputs(params = {}) ⇒ Types::AddBridgeOutputsResponse
Adds outputs to an existing bridge.
526 527 528 529 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 526 def add_bridge_outputs(params = {}, = {}) req = build_request(:add_bridge_outputs, params) req.send_request() end |
#add_bridge_sources(params = {}) ⇒ Types::AddBridgeSourcesResponse
Adds sources to an existing bridge.
590 591 592 593 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 590 def add_bridge_sources(params = {}, = {}) req = build_request(:add_bridge_sources, params) req.send_request() end |
#add_flow_media_streams(params = {}) ⇒ Types::AddFlowMediaStreamsResponse
Adds media streams to an existing flow. After you add a media stream to a flow, you can associate it with a source and/or an output that uses the ST 2110 JPEG XS or CDI protocol.
665 666 667 668 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 665 def add_flow_media_streams(params = {}, = {}) req = build_request(:add_flow_media_streams, params) req.send_request() end |
#add_flow_outputs(params = {}) ⇒ Types::AddFlowOutputsResponse
Adds outputs to an existing flow. You can create up to 50 outputs per flow.
825 826 827 828 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 825 def add_flow_outputs(params = {}, = {}) req = build_request(:add_flow_outputs, params) req.send_request() end |
#add_flow_sources(params = {}) ⇒ Types::AddFlowSourcesResponse
Adds sources to a flow.
980 981 982 983 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 980 def add_flow_sources(params = {}, = {}) req = build_request(:add_flow_sources, params) req.send_request() end |
#add_flow_vpc_interfaces(params = {}) ⇒ Types::AddFlowVpcInterfacesResponse
Adds VPC interfaces to a flow.
1033 1034 1035 1036 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 1033 def add_flow_vpc_interfaces(params = {}, = {}) req = build_request(:add_flow_vpc_interfaces, params) req.send_request() end |
#batch_get_router_input(params = {}) ⇒ Types::BatchGetRouterInputResponse
Retrieves information about multiple router inputs in AWS Elemental MediaConnect.
1166 1167 1168 1169 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 1166 def batch_get_router_input(params = {}, = {}) req = build_request(:batch_get_router_input, params) req.send_request() end |
#batch_get_router_network_interface(params = {}) ⇒ Types::BatchGetRouterNetworkInterfaceResponse
Retrieves information about multiple router network interfaces in AWS Elemental MediaConnect.
1218 1219 1220 1221 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 1218 def batch_get_router_network_interface(params = {}, = {}) req = build_request(:batch_get_router_network_interface, params) req.send_request() end |
#batch_get_router_output(params = {}) ⇒ Types::BatchGetRouterOutputResponse
Retrieves information about multiple router outputs in AWS Elemental MediaConnect.
1308 1309 1310 1311 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 1308 def batch_get_router_output(params = {}, = {}) req = build_request(:batch_get_router_output, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 7376 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MediaConnect') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-mediaconnect' context[:gem_version] = '1.103.0' Seahorse::Client::Request.new(handlers, context) end |
#create_bridge(params = {}) ⇒ Types::CreateBridgeResponse
Creates a new bridge. The request must include one source.
1443 1444 1445 1446 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 1443 def create_bridge(params = {}, = {}) req = build_request(:create_bridge, params) req.send_request() end |
#create_flow(params = {}) ⇒ Types::CreateFlowResponse
Creates a new flow. The request must include one source. The request optionally can include outputs (up to 50) and entitlements (up to 50).
2082 2083 2084 2085 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 2082 def create_flow(params = {}, = {}) req = build_request(:create_flow, params) req.send_request() end |
#create_gateway(params = {}) ⇒ Types::CreateGatewayResponse
Creates a new gateway. The request must include at least one network (up to four).
2139 2140 2141 2142 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 2139 def create_gateway(params = {}, = {}) req = build_request(:create_gateway, params) req.send_request() end |
#create_router_input(params = {}) ⇒ Types::CreateRouterInputResponse
Creates a new router input in AWS Elemental MediaConnect.
2476 2477 2478 2479 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 2476 def create_router_input(params = {}, = {}) req = build_request(:create_router_input, params) req.send_request() end |
#create_router_network_interface(params = {}) ⇒ Types::CreateRouterNetworkInterfaceResponse
Creates a new router network interface in AWS Elemental MediaConnect.
2555 2556 2557 2558 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 2555 def create_router_network_interface(params = {}, = {}) req = build_request(:create_router_network_interface, params) req.send_request() end |
#create_router_output(params = {}) ⇒ Types::CreateRouterOutputResponse
Creates a new router output in AWS Elemental MediaConnect.
2759 2760 2761 2762 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 2759 def create_router_output(params = {}, = {}) req = build_request(:create_router_output, params) req.send_request() end |
#delete_bridge(params = {}) ⇒ Types::DeleteBridgeResponse
Deletes a bridge. Before you can delete a bridge, you must stop the bridge.
2788 2789 2790 2791 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 2788 def delete_bridge(params = {}, = {}) req = build_request(:delete_bridge, params) req.send_request() end |
#delete_flow(params = {}) ⇒ Types::DeleteFlowResponse
Deletes a flow. Before you can delete a flow, you must stop the flow.
2818 2819 2820 2821 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 2818 def delete_flow(params = {}, = {}) req = build_request(:delete_flow, params) req.send_request() end |
#delete_gateway(params = {}) ⇒ Types::DeleteGatewayResponse
Deletes a gateway. Before you can delete a gateway, you must deregister its instances and delete its bridges.
2847 2848 2849 2850 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 2847 def delete_gateway(params = {}, = {}) req = build_request(:delete_gateway, params) req.send_request() end |
#delete_router_input(params = {}) ⇒ Types::DeleteRouterInputResponse
Deletes a router input from AWS Elemental MediaConnect.
2880 2881 2882 2883 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 2880 def delete_router_input(params = {}, = {}) req = build_request(:delete_router_input, params) req.send_request() end |
#delete_router_network_interface(params = {}) ⇒ Types::DeleteRouterNetworkInterfaceResponse
Deletes a router network interface from AWS Elemental MediaConnect.
2913 2914 2915 2916 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 2913 def delete_router_network_interface(params = {}, = {}) req = build_request(:delete_router_network_interface, params) req.send_request() end |
#delete_router_output(params = {}) ⇒ Types::DeleteRouterOutputResponse
Deletes a router output from AWS Elemental MediaConnect.
2946 2947 2948 2949 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 2946 def delete_router_output(params = {}, = {}) req = build_request(:delete_router_output, params) req.send_request() end |
#deregister_gateway_instance(params = {}) ⇒ Types::DeregisterGatewayInstanceResponse
Deregisters an instance. Before you deregister an instance, all bridges running on the instance must be stopped. If you want to deregister an instance without stopping the bridges, you must use the –force option.
2985 2986 2987 2988 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 2985 def deregister_gateway_instance(params = {}, = {}) req = build_request(:deregister_gateway_instance, params) req.send_request() end |
#describe_bridge(params = {}) ⇒ Types::DescribeBridgeResponse
Displays the details of a bridge.
3051 3052 3053 3054 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 3051 def describe_bridge(params = {}, = {}) req = build_request(:describe_bridge, params) req.send_request() end |
#describe_flow(params = {}) ⇒ Types::DescribeFlowResponse
Displays the details of a flow. The response includes the flow Amazon Resource Name (ARN), name, and Availability Zone, as well as details about the source, outputs, and entitlements.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* flow_active
* flow_deleted
* flow_standby
3330 3331 3332 3333 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 3330 def describe_flow(params = {}, = {}) req = build_request(:describe_flow, params) req.send_request() end |
#describe_flow_source_metadata(params = {}) ⇒ Types::DescribeFlowSourceMetadataResponse
The ‘DescribeFlowSourceMetadata` API is used to view information about the flow’s source transport stream and programs. This API displays status messages about the flow’s source as well as details about the program’s video, audio, and other data.
3402 3403 3404 3405 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 3402 def (params = {}, = {}) req = build_request(:describe_flow_source_metadata, params) req.send_request() end |
#describe_flow_source_thumbnail(params = {}) ⇒ Types::DescribeFlowSourceThumbnailResponse
Describes the thumbnail for the flow source.
3437 3438 3439 3440 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 3437 def describe_flow_source_thumbnail(params = {}, = {}) req = build_request(:describe_flow_source_thumbnail, params) req.send_request() end |
#describe_gateway(params = {}) ⇒ Types::DescribeGatewayResponse
Displays the details of a gateway. The response includes the gateway Amazon Resource Name (ARN), name, and CIDR blocks, as well as details about the networks.
3478 3479 3480 3481 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 3478 def describe_gateway(params = {}, = {}) req = build_request(:describe_gateway, params) req.send_request() end |
#describe_gateway_instance(params = {}) ⇒ Types::DescribeGatewayInstanceResponse
Displays the details of an instance.
3517 3518 3519 3520 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 3517 def describe_gateway_instance(params = {}, = {}) req = build_request(:describe_gateway_instance, params) req.send_request() end |
#describe_offering(params = {}) ⇒ Types::DescribeOfferingResponse
Displays the details of an offering. The response includes the offering description, duration, outbound bandwidth, price, and Amazon Resource Name (ARN).
3555 3556 3557 3558 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 3555 def describe_offering(params = {}, = {}) req = build_request(:describe_offering, params) req.send_request() end |
#describe_reservation(params = {}) ⇒ Types::DescribeReservationResponse
Displays the details of a reservation. The response includes the reservation name, state, start date and time, and the details of the offering that make up the rest of the reservation (such as price, duration, and outbound bandwidth).
3599 3600 3601 3602 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 3599 def describe_reservation(params = {}, = {}) req = build_request(:describe_reservation, params) req.send_request() end |
#get_router_input(params = {}) ⇒ Types::GetRouterInputResponse
Retrieves information about a specific router input in AWS Elemental MediaConnect.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* input_active
* input_deleted
* input_standby
3733 3734 3735 3736 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 3733 def get_router_input(params = {}, = {}) req = build_request(:get_router_input, params) req.send_request() end |
#get_router_input_source_metadata(params = {}) ⇒ Types::GetRouterInputSourceMetadataResponse
Retrieves detailed metadata information about a specific router input source, including stream details and connection state.
3785 3786 3787 3788 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 3785 def (params = {}, = {}) req = build_request(:get_router_input_source_metadata, params) req.send_request() end |
#get_router_input_thumbnail(params = {}) ⇒ Types::GetRouterInputThumbnailResponse
Retrieves the thumbnail for a router input in AWS Elemental MediaConnect.
3824 3825 3826 3827 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 3824 def get_router_input_thumbnail(params = {}, = {}) req = build_request(:get_router_input_thumbnail, params) req.send_request() end |
#get_router_network_interface(params = {}) ⇒ Types::GetRouterNetworkInterfaceResponse
Retrieves information about a specific router network interface in AWS Elemental MediaConnect.
3870 3871 3872 3873 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 3870 def get_router_network_interface(params = {}, = {}) req = build_request(:get_router_network_interface, params) req.send_request() end |
#get_router_output(params = {}) ⇒ Types::GetRouterOutputResponse
Retrieves information about a specific router output in AWS Elemental MediaConnect.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* output_active
* output_deleted
* output_routed
* output_standby
* output_unrouted
3963 3964 3965 3966 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 3963 def get_router_output(params = {}, = {}) req = build_request(:get_router_output, params) req.send_request() end |
#grant_flow_entitlements(params = {}) ⇒ Types::GrantFlowEntitlementsResponse
Grants entitlements to an existing flow.
4036 4037 4038 4039 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 4036 def grant_flow_entitlements(params = {}, = {}) req = build_request(:grant_flow_entitlements, params) req.send_request() end |
#list_bridges(params = {}) ⇒ Types::ListBridgesResponse
Displays a list of bridges that are associated with this account and an optionally specified Amazon Resource Name (ARN). This request returns a paginated result.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4099 4100 4101 4102 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 4099 def list_bridges(params = {}, = {}) req = build_request(:list_bridges, params) req.send_request() end |
#list_entitlements(params = {}) ⇒ Types::ListEntitlementsResponse
Displays a list of all entitlements that have been granted to this account. This request returns 20 results per page.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4154 4155 4156 4157 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 4154 def list_entitlements(params = {}, = {}) req = build_request(:list_entitlements, params) req.send_request() end |
#list_flows(params = {}) ⇒ Types::ListFlowsResponse
Displays a list of flows that are associated with this account. This request returns a paginated result.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4216 4217 4218 4219 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 4216 def list_flows(params = {}, = {}) req = build_request(:list_flows, params) req.send_request() end |
#list_gateway_instances(params = {}) ⇒ Types::ListGatewayInstancesResponse
Displays a list of instances associated with the Amazon Web Services account. This request returns a paginated result. You can use the filterArn property to display only the instances associated with the selected Gateway Amazon Resource Name (ARN).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4279 4280 4281 4282 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 4279 def list_gateway_instances(params = {}, = {}) req = build_request(:list_gateway_instances, params) req.send_request() end |
#list_gateways(params = {}) ⇒ Types::ListGatewaysResponse
Displays a list of gateways that are associated with this account. This request returns a paginated result.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4334 4335 4336 4337 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 4334 def list_gateways(params = {}, = {}) req = build_request(:list_gateways, params) req.send_request() end |
#list_offerings(params = {}) ⇒ Types::ListOfferingsResponse
Displays a list of all offerings that are available to this account in the current Amazon Web Services Region. If you have an active reservation (which means you’ve purchased an offering that has already started and hasn’t expired yet), your account isn’t eligible for other offerings.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4398 4399 4400 4401 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 4398 def list_offerings(params = {}, = {}) req = build_request(:list_offerings, params) req.send_request() end |
#list_reservations(params = {}) ⇒ Types::ListReservationsResponse
Displays a list of all reservations that have been purchased by this account in the current Amazon Web Services Region. This list includes all reservations in all states (such as active and expired).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4465 4466 4467 4468 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 4465 def list_reservations(params = {}, = {}) req = build_request(:list_reservations, params) req.send_request() end |
#list_router_inputs(params = {}) ⇒ Types::ListRouterInputsResponse
Retrieves a list of router inputs in AWS Elemental MediaConnect.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4531 4532 4533 4534 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 4531 def list_router_inputs(params = {}, = {}) req = build_request(:list_router_inputs, params) req.send_request() end |
#list_router_network_interfaces(params = {}) ⇒ Types::ListRouterNetworkInterfacesResponse
Retrieves a list of router network interfaces in AWS Elemental MediaConnect.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4590 4591 4592 4593 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 4590 def list_router_network_interfaces(params = {}, = {}) req = build_request(:list_router_network_interfaces, params) req.send_request() end |
#list_router_outputs(params = {}) ⇒ Types::ListRouterOutputsResponse
Retrieves a list of router outputs in AWS Elemental MediaConnect.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4658 4659 4660 4661 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 4658 def list_router_outputs(params = {}, = {}) req = build_request(:list_router_outputs, params) req.send_request() end |
#list_tags_for_global_resource(params = {}) ⇒ Types::ListTagsForGlobalResourceResponse
Lists the tags associated with a global resource in AWS Elemental MediaConnect. The API supports the following global resources: router inputs, router outputs and router network interfaces.
4690 4691 4692 4693 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 4690 def (params = {}, = {}) req = build_request(:list_tags_for_global_resource, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List all tags on a MediaConnect resource in the current region.
4720 4721 4722 4723 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 4720 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#purchase_offering(params = {}) ⇒ Types::PurchaseOfferingResponse
Submits a request to purchase an offering. If you already have an active reservation, you can’t purchase another offering.
4778 4779 4780 4781 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 4778 def purchase_offering(params = {}, = {}) req = build_request(:purchase_offering, params) req.send_request() end |
#remove_bridge_output(params = {}) ⇒ Types::RemoveBridgeOutputResponse
Removes an output from a bridge.
4812 4813 4814 4815 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 4812 def remove_bridge_output(params = {}, = {}) req = build_request(:remove_bridge_output, params) req.send_request() end |
#remove_bridge_source(params = {}) ⇒ Types::RemoveBridgeSourceResponse
Removes a source from a bridge.
4846 4847 4848 4849 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 4846 def remove_bridge_source(params = {}, = {}) req = build_request(:remove_bridge_source, params) req.send_request() end |
#remove_flow_media_stream(params = {}) ⇒ Types::RemoveFlowMediaStreamResponse
Removes a media stream from a flow. This action is only available if the media stream is not associated with a source or output.
4881 4882 4883 4884 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 4881 def remove_flow_media_stream(params = {}, = {}) req = build_request(:remove_flow_media_stream, params) req.send_request() end |
#remove_flow_output(params = {}) ⇒ Types::RemoveFlowOutputResponse
Removes an output from an existing flow. This request can be made only on an output that does not have an entitlement associated with it. If the output has an entitlement, you must revoke the entitlement instead. When an entitlement is revoked from a flow, the service automatically removes the associated output.
4920 4921 4922 4923 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 4920 def remove_flow_output(params = {}, = {}) req = build_request(:remove_flow_output, params) req.send_request() end |
#remove_flow_source(params = {}) ⇒ Types::RemoveFlowSourceResponse
Removes a source from an existing flow. This request can be made only if there is more than one source on the flow.
4956 4957 4958 4959 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 4956 def remove_flow_source(params = {}, = {}) req = build_request(:remove_flow_source, params) req.send_request() end |
#remove_flow_vpc_interface(params = {}) ⇒ Types::RemoveFlowVpcInterfaceResponse
Removes a VPC Interface from an existing flow. This request can be made only on a VPC interface that does not have a Source or Output associated with it. If the VPC interface is referenced by a Source or Output, you must first delete or update the Source or Output to no longer reference the VPC interface.
4998 4999 5000 5001 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 4998 def remove_flow_vpc_interface(params = {}, = {}) req = build_request(:remove_flow_vpc_interface, params) req.send_request() end |
#restart_router_input(params = {}) ⇒ Types::RestartRouterInputResponse
Restarts a router input. This operation can be used to recover from errors or refresh the input state.
5032 5033 5034 5035 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 5032 def restart_router_input(params = {}, = {}) req = build_request(:restart_router_input, params) req.send_request() end |
#restart_router_output(params = {}) ⇒ Types::RestartRouterOutputResponse
Restarts a router output. This operation can be used to recover from errors or refresh the output state.
5066 5067 5068 5069 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 5066 def restart_router_output(params = {}, = {}) req = build_request(:restart_router_output, params) req.send_request() end |
#revoke_flow_entitlement(params = {}) ⇒ Types::RevokeFlowEntitlementResponse
Revokes an entitlement from a flow. Once an entitlement is revoked, the content becomes unavailable to the subscriber and the associated output is removed.
5103 5104 5105 5106 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 5103 def revoke_flow_entitlement(params = {}, = {}) req = build_request(:revoke_flow_entitlement, params) req.send_request() end |
#start_flow(params = {}) ⇒ Types::StartFlowResponse
Starts a flow.
5133 5134 5135 5136 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 5133 def start_flow(params = {}, = {}) req = build_request(:start_flow, params) req.send_request() end |
#start_router_input(params = {}) ⇒ Types::StartRouterInputResponse
Starts a router input in AWS Elemental MediaConnect.
5172 5173 5174 5175 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 5172 def start_router_input(params = {}, = {}) req = build_request(:start_router_input, params) req.send_request() end |
#start_router_output(params = {}) ⇒ Types::StartRouterOutputResponse
Starts a router output in AWS Elemental MediaConnect.
5211 5212 5213 5214 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 5211 def start_router_output(params = {}, = {}) req = build_request(:start_router_output, params) req.send_request() end |
#stop_flow(params = {}) ⇒ Types::StopFlowResponse
Stops a flow.
5241 5242 5243 5244 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 5241 def stop_flow(params = {}, = {}) req = build_request(:stop_flow, params) req.send_request() end |
#stop_router_input(params = {}) ⇒ Types::StopRouterInputResponse
Stops a router input in AWS Elemental MediaConnect.
5274 5275 5276 5277 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 5274 def stop_router_input(params = {}, = {}) req = build_request(:stop_router_input, params) req.send_request() end |
#stop_router_output(params = {}) ⇒ Types::StopRouterOutputResponse
Stops a router output in AWS Elemental MediaConnect.
5307 5308 5309 5310 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 5307 def stop_router_output(params = {}, = {}) req = build_request(:stop_router_output, params) req.send_request() end |
#tag_global_resource(params = {}) ⇒ Struct
Adds tags to a global resource in AWS Elemental MediaConnect. The API supports the following global resources: router inputs, router outputs and router network interfaces.
5337 5338 5339 5340 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 5337 def tag_global_resource(params = {}, = {}) req = build_request(:tag_global_resource, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Associates the specified tags to a resource with the specified ‘resourceArn` in the current region. If existing tags on a resource are not specified in the request parameters, they are not changed. When a resource is deleted, the tags associated with that resource are deleted as well.
5372 5373 5374 5375 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 5372 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#take_router_input(params = {}) ⇒ Types::TakeRouterInputResponse
Associates a router input with a router output in AWS Elemental MediaConnect.
5415 5416 5417 5418 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 5415 def take_router_input(params = {}, = {}) req = build_request(:take_router_input, params) req.send_request() end |
#untag_global_resource(params = {}) ⇒ Struct
Removes tags from a global resource in AWS Elemental MediaConnect. The API supports the following global resources: router inputs, router outputs and router network interfaces.
5444 5445 5446 5447 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 5444 def untag_global_resource(params = {}, = {}) req = build_request(:untag_global_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Deletes specified tags from a resource in the current region.
5470 5471 5472 5473 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 5470 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_bridge(params = {}) ⇒ Types::UpdateBridgeResponse
Updates the bridge.
5561 5562 5563 5564 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 5561 def update_bridge(params = {}, = {}) req = build_request(:update_bridge, params) req.send_request() end |
#update_bridge_output(params = {}) ⇒ Types::UpdateBridgeOutputResponse
Updates an existing bridge output.
5613 5614 5615 5616 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 5613 def update_bridge_output(params = {}, = {}) req = build_request(:update_bridge_output, params) req.send_request() end |
#update_bridge_source(params = {}) ⇒ Types::UpdateBridgeSourceResponse
Updates an existing bridge source.
5677 5678 5679 5680 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 5677 def update_bridge_source(params = {}, = {}) req = build_request(:update_bridge_source, params) req.send_request() end |
#update_bridge_state(params = {}) ⇒ Types::UpdateBridgeStateResponse
Updates the bridge state.
5712 5713 5714 5715 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 5712 def update_bridge_state(params = {}, = {}) req = build_request(:update_bridge_state, params) req.send_request() end |
#update_flow(params = {}) ⇒ Types::UpdateFlowResponse
Updates an existing flow.
<note markdown=“1”> Because ‘UpdateFlowSources` and `UpdateFlow` are separate operations, you can’t change both the source type AND the flow size in a single request.
* If you have a `MEDIUM` flow and you want to change the flow source
to NDI®:
* First, use the `UpdateFlow` operation to upgrade the flow size to
`LARGE`.
* After that, you can then use the `UpdateFlowSource` operation to
configure the NDI source.
-
If you’re switching from an NDI source to a transport stream (TS) source and want to downgrade the flow size:
-
First, use the ‘UpdateFlowSource` operation to change the flow source type.
-
After that, you can then use the ‘UpdateFlow` operation to downgrade the flow size to `MEDIUM`.
-
</note>
6077 6078 6079 6080 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 6077 def update_flow(params = {}, = {}) req = build_request(:update_flow, params) req.send_request() end |
#update_flow_entitlement(params = {}) ⇒ Types::UpdateFlowEntitlementResponse
Updates an entitlement. You can change an entitlement’s description, subscribers, and encryption. If you change the subscribers, the service will remove the outputs that are are used by the subscribers that are removed.
6165 6166 6167 6168 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 6165 def update_flow_entitlement(params = {}, = {}) req = build_request(:update_flow_entitlement, params) req.send_request() end |
#update_flow_media_stream(params = {}) ⇒ Types::UpdateFlowMediaStreamResponse
Updates an existing media stream.
6246 6247 6248 6249 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 6246 def update_flow_media_stream(params = {}, = {}) req = build_request(:update_flow_media_stream, params) req.send_request() end |
#update_flow_output(params = {}) ⇒ Types::UpdateFlowOutputResponse
Updates an existing flow output.
6497 6498 6499 6500 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 6497 def update_flow_output(params = {}, = {}) req = build_request(:update_flow_output, params) req.send_request() end |
#update_flow_source(params = {}) ⇒ Types::UpdateFlowSourceResponse
Updates the source of a flow.
<note markdown=“1”> Because ‘UpdateFlowSources` and `UpdateFlow` are separate operations, you can’t change both the source type AND the flow size in a single request.
* If you have a `MEDIUM` flow and you want to change the flow source
to NDI®:
* First, use the `UpdateFlow` operation to upgrade the flow size to
`LARGE`.
* After that, you can then use the `UpdateFlowSource` operation to
configure the NDI source.
-
If you’re switching from an NDI source to a transport stream (TS) source and want to downgrade the flow size:
-
First, use the ‘UpdateFlowSource` operation to change the flow source type.
-
After that, you can then use the ‘UpdateFlow` operation to downgrade the flow size to `MEDIUM`.
-
</note>
6759 6760 6761 6762 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 6759 def update_flow_source(params = {}, = {}) req = build_request(:update_flow_source, params) req.send_request() end |
#update_gateway_instance(params = {}) ⇒ Types::UpdateGatewayInstanceResponse
Updates an existing gateway instance.
6794 6795 6796 6797 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 6794 def update_gateway_instance(params = {}, = {}) req = build_request(:update_gateway_instance, params) req.send_request() end |
#update_router_input(params = {}) ⇒ Types::UpdateRouterInputResponse
Updates the configuration of an existing router input in AWS Elemental MediaConnect.
7113 7114 7115 7116 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 7113 def update_router_input(params = {}, = {}) req = build_request(:update_router_input, params) req.send_request() end |
#update_router_network_interface(params = {}) ⇒ Types::UpdateRouterNetworkInterfaceResponse
Updates the configuration of an existing router network interface in AWS Elemental MediaConnect.
7180 7181 7182 7183 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 7180 def update_router_network_interface(params = {}, = {}) req = build_request(:update_router_network_interface, params) req.send_request() end |
#update_router_output(params = {}) ⇒ Types::UpdateRouterOutputResponse
Updates the configuration of an existing router output in AWS Elemental MediaConnect.
7367 7368 7369 7370 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 7367 def update_router_output(params = {}, = {}) req = build_request(:update_router_output, params) req.send_request() end |
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
## Basic Usage
A waiter will call an API operation until:
-
It is successful
-
It enters a terminal state
-
It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
## Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
## Callbacks
You can be notified before each polling attempt and before each delay. If you throw ‘:success` or `:failure` from these callbacks, it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
## Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
## Valid Waiters
The following table lists the valid waiter names, the operations they call, and the default ‘:delay` and `:max_attempts` values.
| waiter_name | params | :delay | :max_attempts | | ————— | ————————– | ——– | ————- | | flow_active | #describe_flow | 3 | 40 | | flow_deleted | #describe_flow | 3 | 40 | | flow_standby | #describe_flow | 3 | 40 | | input_active | #get_router_input | 3 | 40 | | input_deleted | #get_router_input | 3 | 40 | | input_standby | #get_router_input | 3 | 40 | | output_active | #get_router_output | 3 | 40 | | output_deleted | #get_router_output | 3 | 40 | | output_routed | #get_router_output | 3 | 40 | | output_standby | #get_router_output | 3 | 40 | | output_unrouted | #get_router_output | 3 | 40 |
7492 7493 7494 7495 7496 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 7492 def wait_until(waiter_name, params = {}, = {}) w = waiter(waiter_name, ) yield(w.waiter) if block_given? # deprecated w.wait(params) end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
7500 7501 7502 |
# File 'lib/aws-sdk-mediaconnect/client.rb', line 7500 def waiter_names waiters.keys end |