Class: Aws::MediaConnect::Types::BlackFramesConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconnect/types.rb

Overview

Detects black frames in the router input’s source content and reports them through a CloudWatch metric, an EventBridge event, and a router input message.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#stateString

Indicates whether black frames detection is enabled or disabled.

Returns:

  • (String)


906
907
908
909
910
911
# File 'lib/aws-sdk-mediaconnect/types.rb', line 906

class BlackFramesConfiguration < Struct.new(
  :state,
  :threshold_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#threshold_secondsInteger

The number of consecutive seconds of black frames that MediaConnect must detect before it reports an issue.

Returns:

  • (Integer)


906
907
908
909
910
911
# File 'lib/aws-sdk-mediaconnect/types.rb', line 906

class BlackFramesConfiguration < Struct.new(
  :state,
  :threshold_seconds)
  SENSITIVE = []
  include Aws::Structure
end