Class: Aws::MediaConnect::Types::Bridge

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconnect/types.rb

Overview

A Bridge is the connection between your data center’s Instances and the Amazon Web Services cloud. A bridge can be used to send video from the Amazon Web Services cloud to your data center or from your data center to the Amazon Web Services cloud.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bridge_arnString

The Amazon Resource Number (ARN) of the bridge.

Returns:

  • (String)


940
941
942
943
944
945
946
947
948
949
950
951
952
953
# File 'lib/aws-sdk-mediaconnect/types.rb', line 940

class Bridge < Struct.new(
  :bridge_arn,
  :bridge_messages,
  :bridge_state,
  :egress_gateway_bridge,
  :ingress_gateway_bridge,
  :name,
  :outputs,
  :placement_arn,
  :source_failover_config,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#bridge_messagesArray<Types::MessageDetail>

Messages with details about the bridge.

Returns:



940
941
942
943
944
945
946
947
948
949
950
951
952
953
# File 'lib/aws-sdk-mediaconnect/types.rb', line 940

class Bridge < Struct.new(
  :bridge_arn,
  :bridge_messages,
  :bridge_state,
  :egress_gateway_bridge,
  :ingress_gateway_bridge,
  :name,
  :outputs,
  :placement_arn,
  :source_failover_config,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#bridge_stateString

The state of the bridge.

Returns:

  • (String)


940
941
942
943
944
945
946
947
948
949
950
951
952
953
# File 'lib/aws-sdk-mediaconnect/types.rb', line 940

class Bridge < Struct.new(
  :bridge_arn,
  :bridge_messages,
  :bridge_state,
  :egress_gateway_bridge,
  :ingress_gateway_bridge,
  :name,
  :outputs,
  :placement_arn,
  :source_failover_config,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#egress_gateway_bridgeTypes::EgressGatewayBridge

An egress bridge is a cloud-to-ground bridge. The content comes from an existing MediaConnect flow and is delivered to your premises.



940
941
942
943
944
945
946
947
948
949
950
951
952
953
# File 'lib/aws-sdk-mediaconnect/types.rb', line 940

class Bridge < Struct.new(
  :bridge_arn,
  :bridge_messages,
  :bridge_state,
  :egress_gateway_bridge,
  :ingress_gateway_bridge,
  :name,
  :outputs,
  :placement_arn,
  :source_failover_config,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#ingress_gateway_bridgeTypes::IngressGatewayBridge

An ingress bridge is a ground-to-cloud bridge. The content originates at your premises and is delivered to the cloud.



940
941
942
943
944
945
946
947
948
949
950
951
952
953
# File 'lib/aws-sdk-mediaconnect/types.rb', line 940

class Bridge < Struct.new(
  :bridge_arn,
  :bridge_messages,
  :bridge_state,
  :egress_gateway_bridge,
  :ingress_gateway_bridge,
  :name,
  :outputs,
  :placement_arn,
  :source_failover_config,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the bridge.

Returns:

  • (String)


940
941
942
943
944
945
946
947
948
949
950
951
952
953
# File 'lib/aws-sdk-mediaconnect/types.rb', line 940

class Bridge < Struct.new(
  :bridge_arn,
  :bridge_messages,
  :bridge_state,
  :egress_gateway_bridge,
  :ingress_gateway_bridge,
  :name,
  :outputs,
  :placement_arn,
  :source_failover_config,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#outputsArray<Types::BridgeOutput>

The outputs on this bridge.

Returns:



940
941
942
943
944
945
946
947
948
949
950
951
952
953
# File 'lib/aws-sdk-mediaconnect/types.rb', line 940

class Bridge < Struct.new(
  :bridge_arn,
  :bridge_messages,
  :bridge_state,
  :egress_gateway_bridge,
  :ingress_gateway_bridge,
  :name,
  :outputs,
  :placement_arn,
  :source_failover_config,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#placement_arnString

The placement Amazon Resource Number (ARN) of the bridge.

Returns:

  • (String)


940
941
942
943
944
945
946
947
948
949
950
951
952
953
# File 'lib/aws-sdk-mediaconnect/types.rb', line 940

class Bridge < Struct.new(
  :bridge_arn,
  :bridge_messages,
  :bridge_state,
  :egress_gateway_bridge,
  :ingress_gateway_bridge,
  :name,
  :outputs,
  :placement_arn,
  :source_failover_config,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#source_failover_configTypes::FailoverConfig

The settings for source failover.



940
941
942
943
944
945
946
947
948
949
950
951
952
953
# File 'lib/aws-sdk-mediaconnect/types.rb', line 940

class Bridge < Struct.new(
  :bridge_arn,
  :bridge_messages,
  :bridge_state,
  :egress_gateway_bridge,
  :ingress_gateway_bridge,
  :name,
  :outputs,
  :placement_arn,
  :source_failover_config,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#sourcesArray<Types::BridgeSource>

The sources on this bridge.

Returns:



940
941
942
943
944
945
946
947
948
949
950
951
952
953
# File 'lib/aws-sdk-mediaconnect/types.rb', line 940

class Bridge < Struct.new(
  :bridge_arn,
  :bridge_messages,
  :bridge_state,
  :egress_gateway_bridge,
  :ingress_gateway_bridge,
  :name,
  :outputs,
  :placement_arn,
  :source_failover_config,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end