Class: Aws::MediaConnect::Types::CreateFlowRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconnect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zoneString

The Availability Zone that you want to create the flow in. These options are limited to the Availability Zones within the current Amazon Web Services Region.

Returns:



1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1296

class CreateFlowRequest < Struct.new(
  :availability_zone,
  :entitlements,
  :media_streams,
  :name,
  :outputs,
  :source,
  :source_failover_config,
  :sources,
  :vpc_interfaces,
  :maintenance,
  :source_monitoring_config,
  :flow_size,
  :ndi_config,
  :encoding_config,
  :flow_tags)
  SENSITIVE = []
  include Aws::Structure
end

#encoding_configTypes::EncodingConfig

The encoding configuration to apply to the NDI® source when transcoding it to a transport stream for downstream distribution. You can choose between several predefined encoding profiles based on common use cases.

Returns:



1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1296

class CreateFlowRequest < Struct.new(
  :availability_zone,
  :entitlements,
  :media_streams,
  :name,
  :outputs,
  :source,
  :source_failover_config,
  :sources,
  :vpc_interfaces,
  :maintenance,
  :source_monitoring_config,
  :flow_size,
  :ndi_config,
  :encoding_config,
  :flow_tags)
  SENSITIVE = []
  include Aws::Structure
end

#entitlementsArray<Types::GrantEntitlementRequest>

The entitlements that you want to grant on a flow.

Returns:



1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1296

class CreateFlowRequest < Struct.new(
  :availability_zone,
  :entitlements,
  :media_streams,
  :name,
  :outputs,
  :source,
  :source_failover_config,
  :sources,
  :vpc_interfaces,
  :maintenance,
  :source_monitoring_config,
  :flow_size,
  :ndi_config,
  :encoding_config,
  :flow_tags)
  SENSITIVE = []
  include Aws::Structure
end

#flow_sizeString

Determines the processing capacity and feature set of the flow. Set this optional parameter to LARGE if you want to enable NDI sources or outputs on the flow.

Returns:



1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1296

class CreateFlowRequest < Struct.new(
  :availability_zone,
  :entitlements,
  :media_streams,
  :name,
  :outputs,
  :source,
  :source_failover_config,
  :sources,
  :vpc_interfaces,
  :maintenance,
  :source_monitoring_config,
  :flow_size,
  :ndi_config,
  :encoding_config,
  :flow_tags)
  SENSITIVE = []
  include Aws::Structure
end

#flow_tagsHash<String,String>

The key-value pairs that can be used to tag and organize the flow.

Returns:



1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1296

class CreateFlowRequest < Struct.new(
  :availability_zone,
  :entitlements,
  :media_streams,
  :name,
  :outputs,
  :source,
  :source_failover_config,
  :sources,
  :vpc_interfaces,
  :maintenance,
  :source_monitoring_config,
  :flow_size,
  :ndi_config,
  :encoding_config,
  :flow_tags)
  SENSITIVE = []
  include Aws::Structure
end

#maintenanceTypes::AddMaintenance

The maintenance settings you want to use for the flow.

Returns:



1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1296

class CreateFlowRequest < Struct.new(
  :availability_zone,
  :entitlements,
  :media_streams,
  :name,
  :outputs,
  :source,
  :source_failover_config,
  :sources,
  :vpc_interfaces,
  :maintenance,
  :source_monitoring_config,
  :flow_size,
  :ndi_config,
  :encoding_config,
  :flow_tags)
  SENSITIVE = []
  include Aws::Structure
end

#media_streamsArray<Types::AddMediaStreamRequest>

The media streams that you want to add to the flow. You can associate these media streams with sources and outputs on the flow.

Returns:



1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1296

class CreateFlowRequest < Struct.new(
  :availability_zone,
  :entitlements,
  :media_streams,
  :name,
  :outputs,
  :source,
  :source_failover_config,
  :sources,
  :vpc_interfaces,
  :maintenance,
  :source_monitoring_config,
  :flow_size,
  :ndi_config,
  :encoding_config,
  :flow_tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the flow.

Returns:



1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1296

class CreateFlowRequest < Struct.new(
  :availability_zone,
  :entitlements,
  :media_streams,
  :name,
  :outputs,
  :source,
  :source_failover_config,
  :sources,
  :vpc_interfaces,
  :maintenance,
  :source_monitoring_config,
  :flow_size,
  :ndi_config,
  :encoding_config,
  :flow_tags)
  SENSITIVE = []
  include Aws::Structure
end

#ndi_configTypes::NdiConfig

Specifies the configuration settings for a flow’s NDI source or output. Required when the flow includes an NDI source or output.

Returns:



1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1296

class CreateFlowRequest < Struct.new(
  :availability_zone,
  :entitlements,
  :media_streams,
  :name,
  :outputs,
  :source,
  :source_failover_config,
  :sources,
  :vpc_interfaces,
  :maintenance,
  :source_monitoring_config,
  :flow_size,
  :ndi_config,
  :encoding_config,
  :flow_tags)
  SENSITIVE = []
  include Aws::Structure
end

#outputsArray<Types::AddOutputRequest>

The outputs that you want to add to this flow.

Returns:



1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1296

class CreateFlowRequest < Struct.new(
  :availability_zone,
  :entitlements,
  :media_streams,
  :name,
  :outputs,
  :source,
  :source_failover_config,
  :sources,
  :vpc_interfaces,
  :maintenance,
  :source_monitoring_config,
  :flow_size,
  :ndi_config,
  :encoding_config,
  :flow_tags)
  SENSITIVE = []
  include Aws::Structure
end

#sourceTypes::SetSourceRequest

The settings for the source that you want to use for the new flow.

Returns:



1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1296

class CreateFlowRequest < Struct.new(
  :availability_zone,
  :entitlements,
  :media_streams,
  :name,
  :outputs,
  :source,
  :source_failover_config,
  :sources,
  :vpc_interfaces,
  :maintenance,
  :source_monitoring_config,
  :flow_size,
  :ndi_config,
  :encoding_config,
  :flow_tags)
  SENSITIVE = []
  include Aws::Structure
end

#source_failover_configTypes::FailoverConfig

The settings for source failover.

Returns:



1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1296

class CreateFlowRequest < Struct.new(
  :availability_zone,
  :entitlements,
  :media_streams,
  :name,
  :outputs,
  :source,
  :source_failover_config,
  :sources,
  :vpc_interfaces,
  :maintenance,
  :source_monitoring_config,
  :flow_size,
  :ndi_config,
  :encoding_config,
  :flow_tags)
  SENSITIVE = []
  include Aws::Structure
end

#source_monitoring_configTypes::MonitoringConfig

The settings for source monitoring.

Returns:



1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1296

class CreateFlowRequest < Struct.new(
  :availability_zone,
  :entitlements,
  :media_streams,
  :name,
  :outputs,
  :source,
  :source_failover_config,
  :sources,
  :vpc_interfaces,
  :maintenance,
  :source_monitoring_config,
  :flow_size,
  :ndi_config,
  :encoding_config,
  :flow_tags)
  SENSITIVE = []
  include Aws::Structure
end

#sourcesArray<Types::SetSourceRequest>

The sources that are assigned to the flow.

Returns:



1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1296

class CreateFlowRequest < Struct.new(
  :availability_zone,
  :entitlements,
  :media_streams,
  :name,
  :outputs,
  :source,
  :source_failover_config,
  :sources,
  :vpc_interfaces,
  :maintenance,
  :source_monitoring_config,
  :flow_size,
  :ndi_config,
  :encoding_config,
  :flow_tags)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_interfacesArray<Types::VpcInterfaceRequest>

The VPC interfaces you want on the flow.

Returns:



1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1296

class CreateFlowRequest < Struct.new(
  :availability_zone,
  :entitlements,
  :media_streams,
  :name,
  :outputs,
  :source,
  :source_failover_config,
  :sources,
  :vpc_interfaces,
  :maintenance,
  :source_monitoring_config,
  :flow_size,
  :ndi_config,
  :encoding_config,
  :flow_tags)
  SENSITIVE = []
  include Aws::Structure
end