Class: Aws::MediaConnect::Types::CreateRouterNetworkInterfaceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::CreateRouterNetworkInterfaceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique identifier for the request to ensure idempotency.
-
#configuration ⇒ Types::RouterNetworkInterfaceConfiguration
The configuration settings for the router network interface.
-
#name ⇒ String
The name of the router network interface.
-
#region_name ⇒ String
The Amazon Web Services Region for the router network interface.
-
#tags ⇒ Hash<String,String>
Key-value pairs that can be used to tag and organize this router network interface.
Instance Attribute Details
#client_token ⇒ String
A unique identifier for the request to ensure idempotency.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
1493 1494 1495 1496 1497 1498 1499 1500 1501 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1493 class CreateRouterNetworkInterfaceRequest < Struct.new( :name, :configuration, :region_name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#configuration ⇒ Types::RouterNetworkInterfaceConfiguration
The configuration settings for the router network interface.
1493 1494 1495 1496 1497 1498 1499 1500 1501 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1493 class CreateRouterNetworkInterfaceRequest < Struct.new( :name, :configuration, :region_name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the router network interface.
1493 1494 1495 1496 1497 1498 1499 1500 1501 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1493 class CreateRouterNetworkInterfaceRequest < Struct.new( :name, :configuration, :region_name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#region_name ⇒ String
The Amazon Web Services Region for the router network interface. Defaults to the current region if not specified.
1493 1494 1495 1496 1497 1498 1499 1500 1501 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1493 class CreateRouterNetworkInterfaceRequest < Struct.new( :name, :configuration, :region_name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Key-value pairs that can be used to tag and organize this router network interface.
1493 1494 1495 1496 1497 1498 1499 1500 1501 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1493 class CreateRouterNetworkInterfaceRequest < Struct.new( :name, :configuration, :region_name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |