Class: Aws::MediaConnect::Types::CreateRouterOutputRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::CreateRouterOutputRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The Availability Zone where you want to create the router output.
-
#client_token ⇒ String
A unique identifier for the request to ensure idempotency.
-
#configuration ⇒ Types::RouterOutputConfiguration
The configuration settings for the router output.
-
#maintenance_configuration ⇒ Types::MaintenanceConfiguration
The maintenance configuration settings for the router output, including preferred maintenance windows and schedules.
-
#maximum_bitrate ⇒ Integer
The maximum bitrate for the router output.
-
#name ⇒ String
The name of the router output.
-
#region_name ⇒ String
The Amazon Web Services Region for the router output.
-
#routing_scope ⇒ String
Specifies whether the router output can take inputs that are in different Regions.
-
#tags ⇒ Hash<String,String>
Key-value pairs that can be used to tag this router output.
-
#tier ⇒ String
The tier level for the router output.
Instance Attribute Details
#availability_zone ⇒ String
The Availability Zone where you want to create the router output. This must be a valid Availability Zone for the region specified by ‘regionName`, or the current region if no `regionName` is provided.
1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1632 class CreateRouterOutputRequest < Struct.new( :name, :configuration, :maximum_bitrate, :routing_scope, :tier, :region_name, :availability_zone, :maintenance_configuration, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique identifier for the request to ensure idempotency.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1632 class CreateRouterOutputRequest < Struct.new( :name, :configuration, :maximum_bitrate, :routing_scope, :tier, :region_name, :availability_zone, :maintenance_configuration, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#configuration ⇒ Types::RouterOutputConfiguration
The configuration settings for the router output.
1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1632 class CreateRouterOutputRequest < Struct.new( :name, :configuration, :maximum_bitrate, :routing_scope, :tier, :region_name, :availability_zone, :maintenance_configuration, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#maintenance_configuration ⇒ Types::MaintenanceConfiguration
The maintenance configuration settings for the router output, including preferred maintenance windows and schedules.
1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1632 class CreateRouterOutputRequest < Struct.new( :name, :configuration, :maximum_bitrate, :routing_scope, :tier, :region_name, :availability_zone, :maintenance_configuration, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#maximum_bitrate ⇒ Integer
The maximum bitrate for the router output.
1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1632 class CreateRouterOutputRequest < Struct.new( :name, :configuration, :maximum_bitrate, :routing_scope, :tier, :region_name, :availability_zone, :maintenance_configuration, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the router output.
1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1632 class CreateRouterOutputRequest < Struct.new( :name, :configuration, :maximum_bitrate, :routing_scope, :tier, :region_name, :availability_zone, :maintenance_configuration, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#region_name ⇒ String
The Amazon Web Services Region for the router output. Defaults to the current region if not specified.
1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1632 class CreateRouterOutputRequest < Struct.new( :name, :configuration, :maximum_bitrate, :routing_scope, :tier, :region_name, :availability_zone, :maintenance_configuration, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#routing_scope ⇒ String
Specifies whether the router output can take inputs that are in different Regions. REGIONAL (default) - can only take inputs from same Region. GLOBAL - can take inputs from any Region.
1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1632 class CreateRouterOutputRequest < Struct.new( :name, :configuration, :maximum_bitrate, :routing_scope, :tier, :region_name, :availability_zone, :maintenance_configuration, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Key-value pairs that can be used to tag this router output.
1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1632 class CreateRouterOutputRequest < Struct.new( :name, :configuration, :maximum_bitrate, :routing_scope, :tier, :region_name, :availability_zone, :maintenance_configuration, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#tier ⇒ String
The tier level for the router output.
1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1632 class CreateRouterOutputRequest < Struct.new( :name, :configuration, :maximum_bitrate, :routing_scope, :tier, :region_name, :availability_zone, :maintenance_configuration, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |