Class: Aws::MediaConnect::Types::DeleteRouterNetworkInterfaceResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconnect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the deleted router network interface.

Returns:

  • (String)


1815
1816
1817
1818
1819
1820
1821
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1815

class DeleteRouterNetworkInterfaceResponse < Struct.new(
  :arn,
  :name,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the deleted router network interface.

Returns:

  • (String)


1815
1816
1817
1818
1819
1820
1821
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1815

class DeleteRouterNetworkInterfaceResponse < Struct.new(
  :arn,
  :name,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The current state of the deleted router network interface, indicating where it is in the deletion process.

Returns:

  • (String)


1815
1816
1817
1818
1819
1820
1821
# File 'lib/aws-sdk-mediaconnect/types.rb', line 1815

class DeleteRouterNetworkInterfaceResponse < Struct.new(
  :arn,
  :name,
  :state)
  SENSITIVE = []
  include Aws::Structure
end