Class: Aws::MediaConnect::Types::DestinationConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconnect/types.rb

Overview

The definition of a media stream that you want to associate with the output.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destination_ipString

The IP address where you want MediaConnect to send contents of the media stream.

Returns:

  • (String)


2179
2180
2181
2182
2183
2184
2185
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2179

class DestinationConfigurationRequest < Struct.new(
  :destination_ip,
  :destination_port,
  :interface)
  SENSITIVE = []
  include Aws::Structure
end

#destination_portInteger

The port that you want MediaConnect to use when it distributes the media stream to the output.

Returns:

  • (Integer)


2179
2180
2181
2182
2183
2184
2185
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2179

class DestinationConfigurationRequest < Struct.new(
  :destination_ip,
  :destination_port,
  :interface)
  SENSITIVE = []
  include Aws::Structure
end

#interfaceTypes::InterfaceRequest

The VPC interface that you want to use for the media stream associated with the output.



2179
2180
2181
2182
2183
2184
2185
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2179

class DestinationConfigurationRequest < Struct.new(
  :destination_ip,
  :destination_port,
  :interface)
  SENSITIVE = []
  include Aws::Structure
end