Class: Aws::MediaConnect::Types::Encryption
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::Encryption
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
Encryption information.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#algorithm ⇒ String
The type of algorithm that is used for the encryption (such as aes128, aes192, or aes256).
-
#constant_initialization_vector ⇒ String
A 128-bit, 16-byte hex value represented by a 32-character string, to be used with the key for encrypting content.
-
#device_id ⇒ String
The value of one of the devices that you configured with your digital rights management (DRM) platform key provider.
-
#key_type ⇒ String
The type of key that is used for the encryption.
-
#region ⇒ String
The Amazon Web Services Region that the API Gateway proxy endpoint was created in.
-
#resource_id ⇒ String
An identifier for the content.
-
#role_arn ⇒ String
The ARN of the role that you created during setup (when you set up MediaConnect as a trusted entity).
-
#secret_arn ⇒ String
The ARN of the secret that you created in Secrets Manager to store the encryption key.
-
#url ⇒ String
The URL from the API Gateway proxy that you set up to talk to your key server.
Instance Attribute Details
#algorithm ⇒ String
The type of algorithm that is used for the encryption (such as aes128, aes192, or aes256).
2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 2364 2365 2366 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2354 class Encryption < Struct.new( :algorithm, :constant_initialization_vector, :device_id, :key_type, :region, :resource_id, :role_arn, :secret_arn, :url) SENSITIVE = [] include Aws::Structure end |
#constant_initialization_vector ⇒ String
A 128-bit, 16-byte hex value represented by a 32-character string, to be used with the key for encrypting content. This parameter is not valid for static key encryption.
2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 2364 2365 2366 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2354 class Encryption < Struct.new( :algorithm, :constant_initialization_vector, :device_id, :key_type, :region, :resource_id, :role_arn, :secret_arn, :url) SENSITIVE = [] include Aws::Structure end |
#device_id ⇒ String
The value of one of the devices that you configured with your digital rights management (DRM) platform key provider. This parameter is required for SPEKE encryption and is not valid for static key encryption.
2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 2364 2365 2366 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2354 class Encryption < Struct.new( :algorithm, :constant_initialization_vector, :device_id, :key_type, :region, :resource_id, :role_arn, :secret_arn, :url) SENSITIVE = [] include Aws::Structure end |
#key_type ⇒ String
The type of key that is used for the encryption. If no keyType is provided, the service will use the default setting (static-key).
2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 2364 2365 2366 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2354 class Encryption < Struct.new( :algorithm, :constant_initialization_vector, :device_id, :key_type, :region, :resource_id, :role_arn, :secret_arn, :url) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
The Amazon Web Services Region that the API Gateway proxy endpoint was created in. This parameter is required for SPEKE encryption and is not valid for static key encryption.
2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 2364 2365 2366 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2354 class Encryption < Struct.new( :algorithm, :constant_initialization_vector, :device_id, :key_type, :region, :resource_id, :role_arn, :secret_arn, :url) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
An identifier for the content. The service sends this value to the key server to identify the current endpoint. The resource ID is also known as the content ID. This parameter is required for SPEKE encryption and is not valid for static key encryption.
2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 2364 2365 2366 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2354 class Encryption < Struct.new( :algorithm, :constant_initialization_vector, :device_id, :key_type, :region, :resource_id, :role_arn, :secret_arn, :url) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of the role that you created during setup (when you set up MediaConnect as a trusted entity).
2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 2364 2365 2366 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2354 class Encryption < Struct.new( :algorithm, :constant_initialization_vector, :device_id, :key_type, :region, :resource_id, :role_arn, :secret_arn, :url) SENSITIVE = [] include Aws::Structure end |
#secret_arn ⇒ String
The ARN of the secret that you created in Secrets Manager to store the encryption key. This parameter is required for static key encryption and is not valid for SPEKE encryption.
2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 2364 2365 2366 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2354 class Encryption < Struct.new( :algorithm, :constant_initialization_vector, :device_id, :key_type, :region, :resource_id, :role_arn, :secret_arn, :url) SENSITIVE = [] include Aws::Structure end |
#url ⇒ String
The URL from the API Gateway proxy that you set up to talk to your key server. This parameter is required for SPEKE encryption and is not valid for static key encryption.
2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 2364 2365 2366 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2354 class Encryption < Struct.new( :algorithm, :constant_initialization_vector, :device_id, :key_type, :region, :resource_id, :role_arn, :secret_arn, :url) SENSITIVE = [] include Aws::Structure end |