Class: Aws::MediaConnect::Types::FabricConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconnect/types.rb

Overview

The fabric configuration settings for the router output.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#recovery_latency_modeString

The recovery latency mode for the router fabric connection. Valid values include the following:

  • BALANCED (default) – Optimizes for stream quality.

  • LOW_LATENCY – Reduces latency at the potential cost of stream quality under adverse network conditions.

Returns:

  • (String)


2435
2436
2437
2438
2439
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2435

class FabricConfiguration < Struct.new(
  :recovery_latency_mode)
  SENSITIVE = []
  include Aws::Structure
end