Class: Aws::MediaConnect::Types::Flow
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::Flow
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
The settings for a flow, including its source, outputs, and entitlements.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The Availability Zone that you want to create the flow in.
-
#description ⇒ String
A description of the flow.
-
#egress_ip ⇒ String
The IP address from which video will be sent to output destinations.
-
#encoding_config ⇒ Types::EncodingConfig
The encoding configuration to apply to the NDIĀ® source when transcoding it to a transport stream for downstream distribution.
-
#entitlements ⇒ Array<Types::Entitlement>
The entitlements in this flow.
-
#flow_arn ⇒ String
The Amazon Resource Name (ARN) of the flow.
-
#flow_size ⇒ String
Determines the processing capacity and feature set of the flow.
-
#maintenance ⇒ Types::Maintenance
The maintenance settings for the flow.
-
#media_streams ⇒ Array<Types::MediaStream>
The media streams that are associated with the flow.
-
#name ⇒ String
The name of the flow.
-
#ndi_config ⇒ Types::NdiConfig
Specifies the configuration settings for a flow's NDI source or output.
-
#outputs ⇒ Array<Types::Output>
The outputs in this flow.
-
#source ⇒ Types::Source
The source for the flow.
-
#source_failover_config ⇒ Types::FailoverConfig
The settings for the source failover.
-
#source_monitoring_config ⇒ Types::MonitoringConfig
The settings for source monitoring.
-
#sources ⇒ Array<Types::Source>
The settings for the sources that are assigned to the flow.
-
#status ⇒ String
The current status of the flow.
-
#vpc_interfaces ⇒ Array<Types::VpcInterface>
The VPC Interfaces for this flow.
Instance Attribute Details
#availability_zone ⇒ String
The Availability Zone that you want to create the flow in. These options are limited to the Availability Zones within the current Amazon Web Services Region.
2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2688 class Flow < Struct.new( :availability_zone, :description, :egress_ip, :entitlements, :flow_arn, :media_streams, :name, :outputs, :source, :source_failover_config, :sources, :status, :vpc_interfaces, :maintenance, :source_monitoring_config, :flow_size, :ndi_config, :encoding_config) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the flow. This value is not used or seen outside of the current MediaConnect account.
2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2688 class Flow < Struct.new( :availability_zone, :description, :egress_ip, :entitlements, :flow_arn, :media_streams, :name, :outputs, :source, :source_failover_config, :sources, :status, :vpc_interfaces, :maintenance, :source_monitoring_config, :flow_size, :ndi_config, :encoding_config) SENSITIVE = [] include Aws::Structure end |
#egress_ip ⇒ String
The IP address from which video will be sent to output destinations.
2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2688 class Flow < Struct.new( :availability_zone, :description, :egress_ip, :entitlements, :flow_arn, :media_streams, :name, :outputs, :source, :source_failover_config, :sources, :status, :vpc_interfaces, :maintenance, :source_monitoring_config, :flow_size, :ndi_config, :encoding_config) SENSITIVE = [] include Aws::Structure end |
#encoding_config ⇒ Types::EncodingConfig
The encoding configuration to apply to the NDIĀ® source when transcoding it to a transport stream for downstream distribution.
2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2688 class Flow < Struct.new( :availability_zone, :description, :egress_ip, :entitlements, :flow_arn, :media_streams, :name, :outputs, :source, :source_failover_config, :sources, :status, :vpc_interfaces, :maintenance, :source_monitoring_config, :flow_size, :ndi_config, :encoding_config) SENSITIVE = [] include Aws::Structure end |
#entitlements ⇒ Array<Types::Entitlement>
The entitlements in this flow.
2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2688 class Flow < Struct.new( :availability_zone, :description, :egress_ip, :entitlements, :flow_arn, :media_streams, :name, :outputs, :source, :source_failover_config, :sources, :status, :vpc_interfaces, :maintenance, :source_monitoring_config, :flow_size, :ndi_config, :encoding_config) SENSITIVE = [] include Aws::Structure end |
#flow_arn ⇒ String
The Amazon Resource Name (ARN) of the flow.
2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2688 class Flow < Struct.new( :availability_zone, :description, :egress_ip, :entitlements, :flow_arn, :media_streams, :name, :outputs, :source, :source_failover_config, :sources, :status, :vpc_interfaces, :maintenance, :source_monitoring_config, :flow_size, :ndi_config, :encoding_config) SENSITIVE = [] include Aws::Structure end |
#flow_size ⇒ String
Determines the processing capacity and feature set of the flow.
2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2688 class Flow < Struct.new( :availability_zone, :description, :egress_ip, :entitlements, :flow_arn, :media_streams, :name, :outputs, :source, :source_failover_config, :sources, :status, :vpc_interfaces, :maintenance, :source_monitoring_config, :flow_size, :ndi_config, :encoding_config) SENSITIVE = [] include Aws::Structure end |
#maintenance ⇒ Types::Maintenance
The maintenance settings for the flow.
2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2688 class Flow < Struct.new( :availability_zone, :description, :egress_ip, :entitlements, :flow_arn, :media_streams, :name, :outputs, :source, :source_failover_config, :sources, :status, :vpc_interfaces, :maintenance, :source_monitoring_config, :flow_size, :ndi_config, :encoding_config) SENSITIVE = [] include Aws::Structure end |
#media_streams ⇒ Array<Types::MediaStream>
The media streams that are associated with the flow. After you associate a media stream with a source, you can also associate it with outputs on the flow.
2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2688 class Flow < Struct.new( :availability_zone, :description, :egress_ip, :entitlements, :flow_arn, :media_streams, :name, :outputs, :source, :source_failover_config, :sources, :status, :vpc_interfaces, :maintenance, :source_monitoring_config, :flow_size, :ndi_config, :encoding_config) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the flow.
2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2688 class Flow < Struct.new( :availability_zone, :description, :egress_ip, :entitlements, :flow_arn, :media_streams, :name, :outputs, :source, :source_failover_config, :sources, :status, :vpc_interfaces, :maintenance, :source_monitoring_config, :flow_size, :ndi_config, :encoding_config) SENSITIVE = [] include Aws::Structure end |
#ndi_config ⇒ Types::NdiConfig
Specifies the configuration settings for a flow's NDI source or output. Required when the flow includes an NDI source or output.
2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2688 class Flow < Struct.new( :availability_zone, :description, :egress_ip, :entitlements, :flow_arn, :media_streams, :name, :outputs, :source, :source_failover_config, :sources, :status, :vpc_interfaces, :maintenance, :source_monitoring_config, :flow_size, :ndi_config, :encoding_config) SENSITIVE = [] include Aws::Structure end |
#outputs ⇒ Array<Types::Output>
The outputs in this flow.
2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2688 class Flow < Struct.new( :availability_zone, :description, :egress_ip, :entitlements, :flow_arn, :media_streams, :name, :outputs, :source, :source_failover_config, :sources, :status, :vpc_interfaces, :maintenance, :source_monitoring_config, :flow_size, :ndi_config, :encoding_config) SENSITIVE = [] include Aws::Structure end |
#source ⇒ Types::Source
The source for the flow.
2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2688 class Flow < Struct.new( :availability_zone, :description, :egress_ip, :entitlements, :flow_arn, :media_streams, :name, :outputs, :source, :source_failover_config, :sources, :status, :vpc_interfaces, :maintenance, :source_monitoring_config, :flow_size, :ndi_config, :encoding_config) SENSITIVE = [] include Aws::Structure end |
#source_failover_config ⇒ Types::FailoverConfig
The settings for the source failover.
2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2688 class Flow < Struct.new( :availability_zone, :description, :egress_ip, :entitlements, :flow_arn, :media_streams, :name, :outputs, :source, :source_failover_config, :sources, :status, :vpc_interfaces, :maintenance, :source_monitoring_config, :flow_size, :ndi_config, :encoding_config) SENSITIVE = [] include Aws::Structure end |
#source_monitoring_config ⇒ Types::MonitoringConfig
The settings for source monitoring.
2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2688 class Flow < Struct.new( :availability_zone, :description, :egress_ip, :entitlements, :flow_arn, :media_streams, :name, :outputs, :source, :source_failover_config, :sources, :status, :vpc_interfaces, :maintenance, :source_monitoring_config, :flow_size, :ndi_config, :encoding_config) SENSITIVE = [] include Aws::Structure end |
#sources ⇒ Array<Types::Source>
The settings for the sources that are assigned to the flow.
2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2688 class Flow < Struct.new( :availability_zone, :description, :egress_ip, :entitlements, :flow_arn, :media_streams, :name, :outputs, :source, :source_failover_config, :sources, :status, :vpc_interfaces, :maintenance, :source_monitoring_config, :flow_size, :ndi_config, :encoding_config) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the flow.
2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2688 class Flow < Struct.new( :availability_zone, :description, :egress_ip, :entitlements, :flow_arn, :media_streams, :name, :outputs, :source, :source_failover_config, :sources, :status, :vpc_interfaces, :maintenance, :source_monitoring_config, :flow_size, :ndi_config, :encoding_config) SENSITIVE = [] include Aws::Structure end |
#vpc_interfaces ⇒ Array<Types::VpcInterface>
The VPC Interfaces for this flow.
2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2688 class Flow < Struct.new( :availability_zone, :description, :egress_ip, :entitlements, :flow_arn, :media_streams, :name, :outputs, :source, :source_failover_config, :sources, :status, :vpc_interfaces, :maintenance, :source_monitoring_config, :flow_size, :ndi_config, :encoding_config) SENSITIVE = [] include Aws::Structure end |