Class: Aws::MediaConnect::Types::GatewayBridgeSource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconnect/types.rb

Overview

The source configuration for cloud flows receiving a stream from a bridge.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bridge_arnString

The ARN of the bridge feeding this flow.

Returns:

  • (String)


2987
2988
2989
2990
2991
2992
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2987

class GatewayBridgeSource < Struct.new(
  :bridge_arn,
  :vpc_interface_attachment)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_interface_attachmentTypes::VpcInterfaceAttachment

The name of the VPC interface attachment to use for this bridge source.



2987
2988
2989
2990
2991
2992
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2987

class GatewayBridgeSource < Struct.new(
  :bridge_arn,
  :vpc_interface_attachment)
  SENSITIVE = []
  include Aws::Structure
end