Class: Aws::MediaConnect::Types::GetRouterInputThumbnailRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::GetRouterInputThumbnailRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the router input that you want to see a thumbnail of.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the router input that you want to see a thumbnail of.
3138 3139 3140 3141 3142 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3138 class GetRouterInputThumbnailRequest < Struct.new( :arn) SENSITIVE = [] include Aws::Structure end |