Class: Aws::MediaConnect::Types::GrantEntitlementRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::GrantEntitlementRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
The entitlements that you want to grant on a flow.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_transfer_subscriber_fee_percent ⇒ Integer
Percentage from 0-100 of the data transfer cost to be billed to the subscriber.
-
#description ⇒ String
A description of the entitlement.
-
#encryption ⇒ Types::Encryption
The type of encryption that will be used on the output that is associated with this entitlement.
-
#entitlement_status ⇒ String
An indication of whether the new entitlement should be enabled or disabled as soon as it is created.
-
#entitlement_tags ⇒ Hash<String,String>
The key-value pairs that can be used to tag and organize the entitlement.
-
#name ⇒ String
The name of the entitlement.
-
#subscribers ⇒ Array<String>
The Amazon Web Services account IDs that you want to share your content with.
Instance Attribute Details
#data_transfer_subscriber_fee_percent ⇒ Integer
Percentage from 0-100 of the data transfer cost to be billed to the subscriber.
3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3264 class GrantEntitlementRequest < Struct.new( :data_transfer_subscriber_fee_percent, :description, :encryption, :entitlement_status, :name, :subscribers, :entitlement_tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the entitlement. This description appears only on the MediaConnect console and will not be seen by the subscriber or end user.
3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3264 class GrantEntitlementRequest < Struct.new( :data_transfer_subscriber_fee_percent, :description, :encryption, :entitlement_status, :name, :subscribers, :entitlement_tags) SENSITIVE = [] include Aws::Structure end |
#encryption ⇒ Types::Encryption
The type of encryption that will be used on the output that is associated with this entitlement. Allowable encryption types: static-key, speke.
3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3264 class GrantEntitlementRequest < Struct.new( :data_transfer_subscriber_fee_percent, :description, :encryption, :entitlement_status, :name, :subscribers, :entitlement_tags) SENSITIVE = [] include Aws::Structure end |
#entitlement_status ⇒ String
An indication of whether the new entitlement should be enabled or disabled as soon as it is created. If you don’t specify the entitlementStatus field in your request, MediaConnect sets it to ENABLED.
3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3264 class GrantEntitlementRequest < Struct.new( :data_transfer_subscriber_fee_percent, :description, :encryption, :entitlement_status, :name, :subscribers, :entitlement_tags) SENSITIVE = [] include Aws::Structure end |
#entitlement_tags ⇒ Hash<String,String>
The key-value pairs that can be used to tag and organize the entitlement.
3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3264 class GrantEntitlementRequest < Struct.new( :data_transfer_subscriber_fee_percent, :description, :encryption, :entitlement_status, :name, :subscribers, :entitlement_tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the entitlement. This value must be unique within the current flow.
3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3264 class GrantEntitlementRequest < Struct.new( :data_transfer_subscriber_fee_percent, :description, :encryption, :entitlement_status, :name, :subscribers, :entitlement_tags) SENSITIVE = [] include Aws::Structure end |
#subscribers ⇒ Array<String>
The Amazon Web Services account IDs that you want to share your content with. The receiving accounts (subscribers) will be allowed to create their own flows using your content as the source.
3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3264 class GrantEntitlementRequest < Struct.new( :data_transfer_subscriber_fee_percent, :description, :encryption, :entitlement_status, :name, :subscribers, :entitlement_tags) SENSITIVE = [] include Aws::Structure end |