Class: Aws::MediaConnect::Types::ListGatewayInstancesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconnect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filter_arnString

Filter the list results to display only the instances associated with the selected Gateway ARN.

Returns:



3648
3649
3650
3651
3652
3653
3654
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3648

class ListGatewayInstancesRequest < Struct.new(
  :filter_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per API request.

For example, you submit a ListInstances request with MaxResults set at 5. Although 20 items match your request, the service returns no more than the first 5 items. (The service also returns a NextToken value that you can use to fetch the next batch of results.)

The service might return fewer results than the MaxResults value. If MaxResults is not included in the request, the service defaults to pagination with a maximum of 10 results per page.

Returns:



3648
3649
3650
3651
3652
3653
3654
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3648

class ListGatewayInstancesRequest < Struct.new(
  :filter_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token that identifies the batch of results that you want to see.

For example, you submit a ListInstances request with MaxResults set at 5. The service returns the first batch of results (up to 5) and a NextToken value. To see the next batch of results, you can submit the ListInstances request a second time and specify the NextToken value.

Returns:



3648
3649
3650
3651
3652
3653
3654
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3648

class ListGatewayInstancesRequest < Struct.new(
  :filter_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end