Class: Aws::MediaConnect::Types::ListGatewaysResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::ListGatewaysResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#gateways ⇒ Array<Types::ListedGateway>
A list of gateway summaries.
-
#next_token ⇒ String
The token that identifies the batch of results that you want to see.
Instance Attribute Details
#gateways ⇒ Array<Types::ListedGateway>
A list of gateway summaries.
3728 3729 3730 3731 3732 3733 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3728 class ListGatewaysResponse < Struct.new( :gateways, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token that identifies the batch of results that you want to see.
For example, you submit a ListGateways request with MaxResults
set at 5. The service returns the first batch of results (up to 5)
and a NextToken value. To see the next batch of results, you can
submit the ListGateways request a second time and specify the
NextToken value.
3728 3729 3730 3731 3732 3733 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3728 class ListGatewaysResponse < Struct.new( :gateways, :next_token) SENSITIVE = [] include Aws::Structure end |