Class: Aws::MediaConnect::Types::ListOfferingsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconnect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results to return per API request.

For example, you submit a ListOfferings request with MaxResults set at 5. Although 20 items match your request, the service returns no more than the first 5 items. (The service also returns a NextToken value that you can use to fetch the next batch of results.)

The service might return fewer results than the MaxResults value. If MaxResults is not included in the request, the service defaults to pagination with a maximum of 10 results per page.

Returns:

  • (Integer)


3761
3762
3763
3764
3765
3766
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3761

class ListOfferingsRequest < Struct.new(
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token that identifies the batch of results that you want to see.

For example, you submit a ListOfferings request with MaxResults set at 5. The service returns the first batch of results (up to 5) and a NextToken value. To see the next batch of results, you can submit the ListOfferings request a second time and specify the NextToken value.

Returns:

  • (String)


3761
3762
3763
3764
3765
3766
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3761

class ListOfferingsRequest < Struct.new(
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end