Class: Aws::MediaConnect::Types::ListOfferingsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::ListOfferingsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token that identifies the batch of results that you want to see.
-
#offerings ⇒ Array<Types::Offering>
A list of offerings that are available to this account in the current Amazon Web Services Region.
Instance Attribute Details
#next_token ⇒ String
The token that identifies the batch of results that you want to see.
For example, you submit a ListOfferings request with MaxResults
set at 5. The service returns the first batch of results (up to 5)
and a NextToken value. To see the next batch of results, you can
submit the ListOfferings request a second time and specify the
NextToken value.
3785 3786 3787 3788 3789 3790 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3785 class ListOfferingsResponse < Struct.new( :next_token, :offerings) SENSITIVE = [] include Aws::Structure end |
#offerings ⇒ Array<Types::Offering>
A list of offerings that are available to this account in the current Amazon Web Services Region.
3785 3786 3787 3788 3789 3790 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3785 class ListOfferingsResponse < Struct.new( :next_token, :offerings) SENSITIVE = [] include Aws::Structure end |