Class: Aws::MediaConnect::Types::ListReservationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::ListReservationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return per API request.
-
#next_token ⇒ String
The token that identifies the batch of results that you want to see.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return per API request.
For example, you submit a ListReservations request with
MaxResults set at 5. Although 20 items match your request, the
service returns no more than the first 5 items. (The service also
returns a NextToken value that you can use to fetch the next batch
of results.)
The service might return fewer results than the MaxResults value.
If MaxResults is not included in the request, the service defaults
to pagination with a maximum of 10 results per page.
3818 3819 3820 3821 3822 3823 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3818 class ListReservationsRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token that identifies the batch of results that you want to see.
For example, you submit a ListReservations request with
MaxResults set at 5. The service returns the first batch of
results (up to 5) and a NextToken value. To see the next batch of
results, you can submit the ListOfferings request a second time
and specify the NextToken value.
3818 3819 3820 3821 3822 3823 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3818 class ListReservationsRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |