Class: Aws::MediaConnect::Types::ListReservationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconnect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The token that identifies the batch of results that you want to see.

For example, you submit a ListReservations request with MaxResults set at 5. The service returns the first batch of results (up to 5) and a NextToken value. To see the next batch of results, you can submit the ListReservations request a second time and specify the NextToken value.

Returns:

  • (String)


3842
3843
3844
3845
3846
3847
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3842

class ListReservationsResponse < Struct.new(
  :next_token,
  :reservations)
  SENSITIVE = []
  include Aws::Structure
end

#reservationsArray<Types::Reservation>

A list of all reservations that have been purchased by this account in the current Amazon Web Services Region.

Returns:



3842
3843
3844
3845
3846
3847
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3842

class ListReservationsResponse < Struct.new(
  :next_token,
  :reservations)
  SENSITIVE = []
  include Aws::Structure
end