Class: Aws::MediaConnect::Types::MediaConnectFlowRouterInputConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::MediaConnectFlowRouterInputConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
Configuration settings for connecting a router input to a flow output.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#flow_arn ⇒ String
The ARN of the flow to connect to.
-
#flow_output_arn ⇒ String
The ARN of the flow output to connect to this router input.
-
#source_transit_decryption ⇒ Types::FlowTransitEncryption
The decryption configuration for the flow source when connected to this router input.
Instance Attribute Details
#flow_arn ⇒ String
The ARN of the flow to connect to.
4515 4516 4517 4518 4519 4520 4521 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 4515 class MediaConnectFlowRouterInputConfiguration < Struct.new( :flow_arn, :flow_output_arn, :source_transit_decryption) SENSITIVE = [] include Aws::Structure end |
#flow_output_arn ⇒ String
The ARN of the flow output to connect to this router input.
4515 4516 4517 4518 4519 4520 4521 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 4515 class MediaConnectFlowRouterInputConfiguration < Struct.new( :flow_arn, :flow_output_arn, :source_transit_decryption) SENSITIVE = [] include Aws::Structure end |
#source_transit_decryption ⇒ Types::FlowTransitEncryption
The decryption configuration for the flow source when connected to this router input.
4515 4516 4517 4518 4519 4520 4521 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 4515 class MediaConnectFlowRouterInputConfiguration < Struct.new( :flow_arn, :flow_output_arn, :source_transit_decryption) SENSITIVE = [] include Aws::Structure end |