Class: Aws::MediaConnect::Types::MediaLiveChannelRouterInputConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::MediaLiveChannelRouterInputConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
Configuration settings for connecting a router input to a MediaLive channel output.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#media_live_channel_arn ⇒ String
The ARN of the MediaLive channel to connect to this router input.
-
#media_live_channel_output_name ⇒ String
The name of the MediaLive channel output to connect to this router input.
-
#media_live_pipeline_id ⇒ String
The index of the MediaLive pipeline to connect to this router input.
-
#source_transit_decryption ⇒ Types::MediaLiveTransitEncryption
The encryption configuration that defines how content is encrypted during transit between MediaConnect Router and MediaLive.
Instance Attribute Details
#media_live_channel_arn ⇒ String
The ARN of the MediaLive channel to connect to this router input.
4613 4614 4615 4616 4617 4618 4619 4620 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 4613 class MediaLiveChannelRouterInputConfiguration < Struct.new( :media_live_channel_arn, :media_live_pipeline_id, :media_live_channel_output_name, :source_transit_decryption) SENSITIVE = [] include Aws::Structure end |
#media_live_channel_output_name ⇒ String
The name of the MediaLive channel output to connect to this router input.
4613 4614 4615 4616 4617 4618 4619 4620 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 4613 class MediaLiveChannelRouterInputConfiguration < Struct.new( :media_live_channel_arn, :media_live_pipeline_id, :media_live_channel_output_name, :source_transit_decryption) SENSITIVE = [] include Aws::Structure end |
#media_live_pipeline_id ⇒ String
The index of the MediaLive pipeline to connect to this router input.
4613 4614 4615 4616 4617 4618 4619 4620 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 4613 class MediaLiveChannelRouterInputConfiguration < Struct.new( :media_live_channel_arn, :media_live_pipeline_id, :media_live_channel_output_name, :source_transit_decryption) SENSITIVE = [] include Aws::Structure end |
#source_transit_decryption ⇒ Types::MediaLiveTransitEncryption
The encryption configuration that defines how content is encrypted during transit between MediaConnect Router and MediaLive. This configuration determines whether encryption keys are automatically managed by the service or manually managed through Secrets Manager.
4613 4614 4615 4616 4617 4618 4619 4620 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 4613 class MediaLiveChannelRouterInputConfiguration < Struct.new( :media_live_channel_arn, :media_live_pipeline_id, :media_live_channel_output_name, :source_transit_decryption) SENSITIVE = [] include Aws::Structure end |