Class: Aws::MediaConnect::Types::MediaLiveTransitEncryptionKeyConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-mediaconnect/types.rb

Overview

Note:

MediaLiveTransitEncryptionKeyConfiguration is a union - when making an API calls you must set exactly one of the members.

Note:

MediaLiveTransitEncryptionKeyConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of MediaLiveTransitEncryptionKeyConfiguration corresponding to the set member.

Configuration settings for the MediaLive transit encryption key.

Defined Under Namespace

Classes: Automatic, SecretsManager, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#automaticTypes::AutomaticEncryptionKeyConfiguration

Configuration settings for automatic encryption key management, where MediaConnect handles key creation and rotation.



4703
4704
4705
4706
4707
4708
4709
4710
4711
4712
4713
4714
# File 'lib/aws-sdk-mediaconnect/types.rb', line 4703

class MediaLiveTransitEncryptionKeyConfiguration < Struct.new(
  :secrets_manager,
  :automatic,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SecretsManager < MediaLiveTransitEncryptionKeyConfiguration; end
  class Automatic < MediaLiveTransitEncryptionKeyConfiguration; end
  class Unknown < MediaLiveTransitEncryptionKeyConfiguration; end
end

#secrets_managerTypes::SecretsManagerEncryptionKeyConfiguration

The configuration settings for transit encryption using Secrets Manager, including the secret ARN and role ARN.



4703
4704
4705
4706
4707
4708
4709
4710
4711
4712
4713
4714
# File 'lib/aws-sdk-mediaconnect/types.rb', line 4703

class MediaLiveTransitEncryptionKeyConfiguration < Struct.new(
  :secrets_manager,
  :automatic,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SecretsManager < MediaLiveTransitEncryptionKeyConfiguration; end
  class Automatic < MediaLiveTransitEncryptionKeyConfiguration; end
  class Unknown < MediaLiveTransitEncryptionKeyConfiguration; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



4703
4704
4705
# File 'lib/aws-sdk-mediaconnect/types.rb', line 4703

def unknown
  @unknown
end