Class: Aws::MediaConnect::Types::MediaStream

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconnect/types.rb

Overview

A media stream represents one component of your content, such as video, audio, or ancillary data. After you add a media stream to your flow, you can associate it with sources and outputs that use the ST 2110 JPEG XS or CDI protocol.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributesTypes::MediaStreamAttributes

Attributes that are related to the media stream.



4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
# File 'lib/aws-sdk-mediaconnect/types.rb', line 4734

class MediaStream < Struct.new(
  :attributes,
  :clock_rate,
  :description,
  :fmt,
  :media_stream_id,
  :media_stream_name,
  :media_stream_type,
  :video_format)
  SENSITIVE = []
  include Aws::Structure
end

#clock_rateInteger

The sample rate for the stream. This value is measured in Hz.

Returns:

  • (Integer)


4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
# File 'lib/aws-sdk-mediaconnect/types.rb', line 4734

class MediaStream < Struct.new(
  :attributes,
  :clock_rate,
  :description,
  :fmt,
  :media_stream_id,
  :media_stream_name,
  :media_stream_type,
  :video_format)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description that can help you quickly identify what your media stream is used for.

Returns:

  • (String)


4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
# File 'lib/aws-sdk-mediaconnect/types.rb', line 4734

class MediaStream < Struct.new(
  :attributes,
  :clock_rate,
  :description,
  :fmt,
  :media_stream_id,
  :media_stream_name,
  :media_stream_type,
  :video_format)
  SENSITIVE = []
  include Aws::Structure
end

#fmtInteger

The format type number (sometimes referred to as RTP payload type) of the media stream. MediaConnect assigns this value to the media stream. For ST 2110 JPEG XS outputs, you need to provide this value to the receiver.

Returns:

  • (Integer)


4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
# File 'lib/aws-sdk-mediaconnect/types.rb', line 4734

class MediaStream < Struct.new(
  :attributes,
  :clock_rate,
  :description,
  :fmt,
  :media_stream_id,
  :media_stream_name,
  :media_stream_type,
  :video_format)
  SENSITIVE = []
  include Aws::Structure
end

#media_stream_idInteger

A unique identifier for the media stream.

Returns:

  • (Integer)


4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
# File 'lib/aws-sdk-mediaconnect/types.rb', line 4734

class MediaStream < Struct.new(
  :attributes,
  :clock_rate,
  :description,
  :fmt,
  :media_stream_id,
  :media_stream_name,
  :media_stream_type,
  :video_format)
  SENSITIVE = []
  include Aws::Structure
end

#media_stream_nameString

A name that helps you distinguish one media stream from another.

Returns:

  • (String)


4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
# File 'lib/aws-sdk-mediaconnect/types.rb', line 4734

class MediaStream < Struct.new(
  :attributes,
  :clock_rate,
  :description,
  :fmt,
  :media_stream_id,
  :media_stream_name,
  :media_stream_type,
  :video_format)
  SENSITIVE = []
  include Aws::Structure
end

#media_stream_typeString

The type of media stream.

Returns:

  • (String)


4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
# File 'lib/aws-sdk-mediaconnect/types.rb', line 4734

class MediaStream < Struct.new(
  :attributes,
  :clock_rate,
  :description,
  :fmt,
  :media_stream_id,
  :media_stream_name,
  :media_stream_type,
  :video_format)
  SENSITIVE = []
  include Aws::Structure
end

#video_formatString

The resolution of the video.

Returns:

  • (String)


4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
# File 'lib/aws-sdk-mediaconnect/types.rb', line 4734

class MediaStream < Struct.new(
  :attributes,
  :clock_rate,
  :description,
  :fmt,
  :media_stream_id,
  :media_stream_name,
  :media_stream_type,
  :video_format)
  SENSITIVE = []
  include Aws::Structure
end