Class: Aws::MediaConnect::Types::MediaStreamOutputConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::MediaStreamOutputConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
The media stream that you want to associate with the output, and the parameters for that association.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination_configurations ⇒ Array<Types::DestinationConfigurationRequest>
The media streams that you want to associate with the output.
-
#encoding_name ⇒ String
The format that will be used to encode the data.
-
#encoding_parameters ⇒ Types::EncodingParametersRequest
A collection of parameters that determine how MediaConnect will convert the content.
-
#media_stream_name ⇒ String
The name of the media stream that is associated with the output.
Instance Attribute Details
#destination_configurations ⇒ Array<Types::DestinationConfigurationRequest>
The media streams that you want to associate with the output.
4849 4850 4851 4852 4853 4854 4855 4856 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 4849 class MediaStreamOutputConfigurationRequest < Struct.new( :destination_configurations, :encoding_name, :encoding_parameters, :media_stream_name) SENSITIVE = [] include Aws::Structure end |
#encoding_name ⇒ String
The format that will be used to encode the data. For ancillary data streams, set the encoding name to smpte291. For audio streams, set the encoding name to pcm. For video, 2110 streams, set the encoding name to raw. For video, JPEG XS streams, set the encoding name to jxsv.
4849 4850 4851 4852 4853 4854 4855 4856 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 4849 class MediaStreamOutputConfigurationRequest < Struct.new( :destination_configurations, :encoding_name, :encoding_parameters, :media_stream_name) SENSITIVE = [] include Aws::Structure end |
#encoding_parameters ⇒ Types::EncodingParametersRequest
A collection of parameters that determine how MediaConnect will convert the content. These fields only apply to outputs on flows that have a CDI source.
4849 4850 4851 4852 4853 4854 4855 4856 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 4849 class MediaStreamOutputConfigurationRequest < Struct.new( :destination_configurations, :encoding_name, :encoding_parameters, :media_stream_name) SENSITIVE = [] include Aws::Structure end |
#media_stream_name ⇒ String
The name of the media stream that is associated with the output.
4849 4850 4851 4852 4853 4854 4855 4856 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 4849 class MediaStreamOutputConfigurationRequest < Struct.new( :destination_configurations, :encoding_name, :encoding_parameters, :media_stream_name) SENSITIVE = [] include Aws::Structure end |