Class: Aws::MediaConnect::Types::MergeRouterInputProtocolConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-mediaconnect/types.rb

Overview

Note:

MergeRouterInputProtocolConfiguration is a union - when making an API calls you must set exactly one of the members.

Note:

MergeRouterInputProtocolConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of MergeRouterInputProtocolConfiguration corresponding to the set member.

Protocol configuration settings for merge router inputs.

Defined Under Namespace

Classes: Rist, Rtp, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ristTypes::RistRouterInputConfiguration

The configuration settings for a router input using the RIST (Reliable Internet Stream Transport) protocol, including the port and recovery latency.



5009
5010
5011
5012
5013
5014
5015
5016
5017
5018
5019
5020
# File 'lib/aws-sdk-mediaconnect/types.rb', line 5009

class MergeRouterInputProtocolConfiguration < Struct.new(
  :rtp,
  :rist,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Rtp < MergeRouterInputProtocolConfiguration; end
  class Rist < MergeRouterInputProtocolConfiguration; end
  class Unknown < MergeRouterInputProtocolConfiguration; end
end

#rtpTypes::RtpRouterInputConfiguration

The configuration settings for a Router Input using the RTP (Real-Time Transport Protocol) protocol, including the port and forward error correction state.



5009
5010
5011
5012
5013
5014
5015
5016
5017
5018
5019
5020
# File 'lib/aws-sdk-mediaconnect/types.rb', line 5009

class MergeRouterInputProtocolConfiguration < Struct.new(
  :rtp,
  :rist,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Rtp < MergeRouterInputProtocolConfiguration; end
  class Rist < MergeRouterInputProtocolConfiguration; end
  class Unknown < MergeRouterInputProtocolConfiguration; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



5009
5010
5011
# File 'lib/aws-sdk-mediaconnect/types.rb', line 5009

def unknown
  @unknown
end