Class: Aws::MediaConnect::Types::NdiConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::NdiConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
Specifies the configuration settings for NDI sources and outputs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#machine_name ⇒ String
A prefix for the names of the NDI sources that the flow creates.
-
#ndi_discovery_servers ⇒ Array<Types::NdiDiscoveryServerConfig>
A list of up to three NDI discovery server configurations.
-
#ndi_state ⇒ String
A setting that controls whether NDIĀ® sources or outputs can be used in the flow.
Instance Attribute Details
#machine_name ⇒ String
A prefix for the names of the NDI sources that the flow creates. If a custom name isn't specified, MediaConnect generates a unique 12-character ID as the prefix.
5151 5152 5153 5154 5155 5156 5157 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 5151 class NdiConfig < Struct.new( :ndi_state, :machine_name, :ndi_discovery_servers) SENSITIVE = [] include Aws::Structure end |
#ndi_discovery_servers ⇒ Array<Types::NdiDiscoveryServerConfig>
A list of up to three NDI discovery server configurations. While not required by the API, this configuration is necessary for NDI functionality to work properly.
5151 5152 5153 5154 5155 5156 5157 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 5151 class NdiConfig < Struct.new( :ndi_state, :machine_name, :ndi_discovery_servers) SENSITIVE = [] include Aws::Structure end |
#ndi_state ⇒ String
A setting that controls whether NDIĀ® sources or outputs can be used in the flow.
The default value is DISABLED. This value must be set as ENABLED
for your flow to support NDI sources or outputs.
5151 5152 5153 5154 5155 5156 5157 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 5151 class NdiConfig < Struct.new( :ndi_state, :machine_name, :ndi_discovery_servers) SENSITIVE = [] include Aws::Structure end |