Class: Aws::MediaConnect::Types::NdiMediaInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::NdiMediaInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
Metadata about the audio and video media that is part of the NDIĀ® source content. This includes details about the individual media streams.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#streams ⇒ Array<Types::NdiMediaStreamInfo>
A list of the individual media streams that make up the NDI source.
Instance Attribute Details
#streams ⇒ Array<Types::NdiMediaStreamInfo>
A list of the individual media streams that make up the NDI source. This includes details about each stream's codec, resolution, frame rate, audio channels, and other parameters.
5198 5199 5200 5201 5202 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 5198 class NdiMediaInfo < Struct.new( :streams) SENSITIVE = [] include Aws::Structure end |