Class: Aws::MediaConnect::Types::NdiSourceSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::NdiSourceSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
The settings for the NDIĀ® source. This includes the exact name of the upstream NDI sender that you want to connect to your source.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#source_name ⇒ String
The exact name of an existing NDI sender that's registered with your discovery server.
Instance Attribute Details
#source_name ⇒ String
The exact name of an existing NDI sender that's registered with
your discovery server. If included, the format of this name must be
MACHINENAME (ProgramName).
5322 5323 5324 5325 5326 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 5322 class NdiSourceSettings < Struct.new( :source_name) SENSITIVE = [] include Aws::Structure end |