Class: Aws::MediaConnect::Types::Offering
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::Offering
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
A savings plan that reserves a certain amount of outbound bandwidth usage at a discounted rate each month over a period of time.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#currency_code ⇒ String
The type of currency that is used for billing.
-
#duration ⇒ Integer
The length of time that your reservation would be active.
-
#duration_units ⇒ String
The unit of measurement for the duration of the offering.
-
#offering_arn ⇒ String
The Amazon Resource Name (ARN) that MediaConnect assigns to the offering.
-
#offering_description ⇒ String
A description of the offering.
-
#price_per_unit ⇒ String
The cost of a single unit.
-
#price_units ⇒ String
The unit of measurement that is used for billing.
-
#resource_specification ⇒ Types::ResourceSpecification
A definition of the amount of outbound bandwidth that you would be reserving if you purchase the offering.
Instance Attribute Details
#currency_code ⇒ String
The type of currency that is used for billing. The currencyCode used for all reservations is US dollars.
5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 5297 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 5286 class Offering < Struct.new( :currency_code, :duration, :duration_units, :offering_arn, :offering_description, :price_per_unit, :price_units, :resource_specification) SENSITIVE = [] include Aws::Structure end |
#duration ⇒ Integer
The length of time that your reservation would be active.
5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 5297 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 5286 class Offering < Struct.new( :currency_code, :duration, :duration_units, :offering_arn, :offering_description, :price_per_unit, :price_units, :resource_specification) SENSITIVE = [] include Aws::Structure end |
#duration_units ⇒ String
The unit of measurement for the duration of the offering.
5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 5297 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 5286 class Offering < Struct.new( :currency_code, :duration, :duration_units, :offering_arn, :offering_description, :price_per_unit, :price_units, :resource_specification) SENSITIVE = [] include Aws::Structure end |
#offering_arn ⇒ String
The Amazon Resource Name (ARN) that MediaConnect assigns to the offering.
5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 5297 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 5286 class Offering < Struct.new( :currency_code, :duration, :duration_units, :offering_arn, :offering_description, :price_per_unit, :price_units, :resource_specification) SENSITIVE = [] include Aws::Structure end |
#offering_description ⇒ String
A description of the offering.
5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 5297 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 5286 class Offering < Struct.new( :currency_code, :duration, :duration_units, :offering_arn, :offering_description, :price_per_unit, :price_units, :resource_specification) SENSITIVE = [] include Aws::Structure end |
#price_per_unit ⇒ String
The cost of a single unit. This value, in combination with priceUnits, makes up the rate.
5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 5297 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 5286 class Offering < Struct.new( :currency_code, :duration, :duration_units, :offering_arn, :offering_description, :price_per_unit, :price_units, :resource_specification) SENSITIVE = [] include Aws::Structure end |
#price_units ⇒ String
The unit of measurement that is used for billing. This value, in combination with pricePerUnit, makes up the rate.
5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 5297 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 5286 class Offering < Struct.new( :currency_code, :duration, :duration_units, :offering_arn, :offering_description, :price_per_unit, :price_units, :resource_specification) SENSITIVE = [] include Aws::Structure end |
#resource_specification ⇒ Types::ResourceSpecification
A definition of the amount of outbound bandwidth that you would be reserving if you purchase the offering.
5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 5297 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 5286 class Offering < Struct.new( :currency_code, :duration, :duration_units, :offering_arn, :offering_description, :price_per_unit, :price_units, :resource_specification) SENSITIVE = [] include Aws::Structure end |