Class: Aws::MediaConnect::Types::RestartRouterInputResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconnect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the router input that was restarted.

Returns:

  • (String)


5893
5894
5895
5896
5897
5898
5899
# File 'lib/aws-sdk-mediaconnect/types.rb', line 5893

class RestartRouterInputResponse < Struct.new(
  :arn,
  :name,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the router input that was restarted.

Returns:

  • (String)


5893
5894
5895
5896
5897
5898
5899
# File 'lib/aws-sdk-mediaconnect/types.rb', line 5893

class RestartRouterInputResponse < Struct.new(
  :arn,
  :name,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The current state of the router input after the restart operation.

Returns:

  • (String)


5893
5894
5895
5896
5897
5898
5899
# File 'lib/aws-sdk-mediaconnect/types.rb', line 5893

class RestartRouterInputResponse < Struct.new(
  :arn,
  :name,
  :state)
  SENSITIVE = []
  include Aws::Structure
end