Class: Aws::MediaConnect::Types::RouterInputProtocolConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-mediaconnect/types.rb

Overview

Note:

RouterInputProtocolConfiguration is a union - when making an API calls you must set exactly one of the members.

Note:

RouterInputProtocolConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of RouterInputProtocolConfiguration corresponding to the set member.

The protocol configuration settings for a router input.

Defined Under Namespace

Classes: Rist, Rtp, SrtCaller, SrtListener, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ristTypes::RistRouterInputConfiguration

The configuration settings for a router input using the RIST (Reliable Internet Stream Transport) protocol, including the port and recovery latency.



6462
6463
6464
6465
6466
6467
6468
6469
6470
6471
6472
6473
6474
6475
6476
6477
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6462

class RouterInputProtocolConfiguration < Struct.new(
  :rist,
  :srt_listener,
  :srt_caller,
  :rtp,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Rist < RouterInputProtocolConfiguration; end
  class SrtListener < RouterInputProtocolConfiguration; end
  class SrtCaller < RouterInputProtocolConfiguration; end
  class Rtp < RouterInputProtocolConfiguration; end
  class Unknown < RouterInputProtocolConfiguration; end
end

#rtpTypes::RtpRouterInputConfiguration

The configuration settings for a Router Input using the RTP (Real-Time Transport Protocol) protocol, including the port and forward error correction state.



6462
6463
6464
6465
6466
6467
6468
6469
6470
6471
6472
6473
6474
6475
6476
6477
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6462

class RouterInputProtocolConfiguration < Struct.new(
  :rist,
  :srt_listener,
  :srt_caller,
  :rtp,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Rist < RouterInputProtocolConfiguration; end
  class SrtListener < RouterInputProtocolConfiguration; end
  class SrtCaller < RouterInputProtocolConfiguration; end
  class Rtp < RouterInputProtocolConfiguration; end
  class Unknown < RouterInputProtocolConfiguration; end
end

#srt_callerTypes::SrtCallerRouterInputConfiguration

The configuration settings for a router input using the SRT (Secure Reliable Transport) protocol in caller mode, including the source address and port, minimum latency, stream ID, and decryption key configuration.



6462
6463
6464
6465
6466
6467
6468
6469
6470
6471
6472
6473
6474
6475
6476
6477
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6462

class RouterInputProtocolConfiguration < Struct.new(
  :rist,
  :srt_listener,
  :srt_caller,
  :rtp,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Rist < RouterInputProtocolConfiguration; end
  class SrtListener < RouterInputProtocolConfiguration; end
  class SrtCaller < RouterInputProtocolConfiguration; end
  class Rtp < RouterInputProtocolConfiguration; end
  class Unknown < RouterInputProtocolConfiguration; end
end

#srt_listenerTypes::SrtListenerRouterInputConfiguration

The configuration settings for a router input using the SRT (Secure Reliable Transport) protocol in listener mode, including the port, minimum latency, and decryption key configuration.



6462
6463
6464
6465
6466
6467
6468
6469
6470
6471
6472
6473
6474
6475
6476
6477
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6462

class RouterInputProtocolConfiguration < Struct.new(
  :rist,
  :srt_listener,
  :srt_caller,
  :rtp,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Rist < RouterInputProtocolConfiguration; end
  class SrtListener < RouterInputProtocolConfiguration; end
  class SrtCaller < RouterInputProtocolConfiguration; end
  class Rtp < RouterInputProtocolConfiguration; end
  class Unknown < RouterInputProtocolConfiguration; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



6462
6463
6464
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6462

def unknown
  @unknown
end