Class: Aws::MediaConnect::Types::RouterInputThumbnailDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::RouterInputThumbnailDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
The details of a thumbnail associated with a router input, including the thumbnail messages, the thumbnail image, the timecode, and the timestamp.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#thumbnail ⇒ String
The thumbnail image, encoded as a Base64-encoded binary data object.
-
#thumbnail_messages ⇒ Array<Types::RouterInputMessage>
The messages associated with the router input thumbnail.
-
#timecode ⇒ String
The timecode associated with the thumbnail.
-
#timestamp ⇒ Time
The timestamp associated with the thumbnail.
Instance Attribute Details
#thumbnail ⇒ String
The thumbnail image, encoded as a Base64-encoded binary data object.
6590 6591 6592 6593 6594 6595 6596 6597 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6590 class RouterInputThumbnailDetails < Struct.new( :thumbnail_messages, :thumbnail, :timecode, :timestamp) SENSITIVE = [] include Aws::Structure end |
#thumbnail_messages ⇒ Array<Types::RouterInputMessage>
The messages associated with the router input thumbnail.
6590 6591 6592 6593 6594 6595 6596 6597 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6590 class RouterInputThumbnailDetails < Struct.new( :thumbnail_messages, :thumbnail, :timecode, :timestamp) SENSITIVE = [] include Aws::Structure end |
#timecode ⇒ String
The timecode associated with the thumbnail.
6590 6591 6592 6593 6594 6595 6596 6597 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6590 class RouterInputThumbnailDetails < Struct.new( :thumbnail_messages, :thumbnail, :timecode, :timestamp) SENSITIVE = [] include Aws::Structure end |
#timestamp ⇒ Time
The timestamp associated with the thumbnail.
6590 6591 6592 6593 6594 6595 6596 6597 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6590 class RouterInputThumbnailDetails < Struct.new( :thumbnail_messages, :thumbnail, :timecode, :timestamp) SENSITIVE = [] include Aws::Structure end |