Class: Aws::MediaConnect::Types::RouterNetworkInterface
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::RouterNetworkInterface
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
A router network interface in AWS Elemental MediaConnect. A router network interface is a network interface that can be associated with one or more router inputs and outputs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the router network interface.
-
#associated_input_count ⇒ Integer
The number of router inputs associated with the network interface.
-
#associated_output_count ⇒ Integer
The number of router outputs associated with the network interface.
-
#configuration ⇒ Types::RouterNetworkInterfaceConfiguration
The configuration settings for a router network interface.
-
#created_at ⇒ Time
The timestamp when the router network interface was created.
-
#id ⇒ String
The unique identifier of the router network interface.
-
#name ⇒ String
The name of the router network interface.
-
#network_interface_type ⇒ String
The type of the router network interface.
-
#region_name ⇒ String
The Amazon Web Services Region where the router network interface is located.
-
#state ⇒ String
The current state of the router network interface.
-
#tags ⇒ Hash<String,String>
Key-value pairs that can be used to tag and organize this router network interface.
-
#updated_at ⇒ Time
The timestamp when the router network interface was last updated.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the router network interface.
6502 6503 6504 6505 6506 6507 6508 6509 6510 6511 6512 6513 6514 6515 6516 6517 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6502 class RouterNetworkInterface < Struct.new( :name, :arn, :id, :state, :network_interface_type, :configuration, :associated_output_count, :associated_input_count, :region_name, :created_at, :updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#associated_input_count ⇒ Integer
The number of router inputs associated with the network interface.
6502 6503 6504 6505 6506 6507 6508 6509 6510 6511 6512 6513 6514 6515 6516 6517 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6502 class RouterNetworkInterface < Struct.new( :name, :arn, :id, :state, :network_interface_type, :configuration, :associated_output_count, :associated_input_count, :region_name, :created_at, :updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#associated_output_count ⇒ Integer
The number of router outputs associated with the network interface.
6502 6503 6504 6505 6506 6507 6508 6509 6510 6511 6512 6513 6514 6515 6516 6517 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6502 class RouterNetworkInterface < Struct.new( :name, :arn, :id, :state, :network_interface_type, :configuration, :associated_output_count, :associated_input_count, :region_name, :created_at, :updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#configuration ⇒ Types::RouterNetworkInterfaceConfiguration
The configuration settings for a router network interface.
6502 6503 6504 6505 6506 6507 6508 6509 6510 6511 6512 6513 6514 6515 6516 6517 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6502 class RouterNetworkInterface < Struct.new( :name, :arn, :id, :state, :network_interface_type, :configuration, :associated_output_count, :associated_input_count, :region_name, :created_at, :updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the router network interface was created.
6502 6503 6504 6505 6506 6507 6508 6509 6510 6511 6512 6513 6514 6515 6516 6517 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6502 class RouterNetworkInterface < Struct.new( :name, :arn, :id, :state, :network_interface_type, :configuration, :associated_output_count, :associated_input_count, :region_name, :created_at, :updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the router network interface.
6502 6503 6504 6505 6506 6507 6508 6509 6510 6511 6512 6513 6514 6515 6516 6517 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6502 class RouterNetworkInterface < Struct.new( :name, :arn, :id, :state, :network_interface_type, :configuration, :associated_output_count, :associated_input_count, :region_name, :created_at, :updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the router network interface.
6502 6503 6504 6505 6506 6507 6508 6509 6510 6511 6512 6513 6514 6515 6516 6517 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6502 class RouterNetworkInterface < Struct.new( :name, :arn, :id, :state, :network_interface_type, :configuration, :associated_output_count, :associated_input_count, :region_name, :created_at, :updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#network_interface_type ⇒ String
The type of the router network interface.
6502 6503 6504 6505 6506 6507 6508 6509 6510 6511 6512 6513 6514 6515 6516 6517 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6502 class RouterNetworkInterface < Struct.new( :name, :arn, :id, :state, :network_interface_type, :configuration, :associated_output_count, :associated_input_count, :region_name, :created_at, :updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#region_name ⇒ String
The Amazon Web Services Region where the router network interface is located.
6502 6503 6504 6505 6506 6507 6508 6509 6510 6511 6512 6513 6514 6515 6516 6517 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6502 class RouterNetworkInterface < Struct.new( :name, :arn, :id, :state, :network_interface_type, :configuration, :associated_output_count, :associated_input_count, :region_name, :created_at, :updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the router network interface.
6502 6503 6504 6505 6506 6507 6508 6509 6510 6511 6512 6513 6514 6515 6516 6517 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6502 class RouterNetworkInterface < Struct.new( :name, :arn, :id, :state, :network_interface_type, :configuration, :associated_output_count, :associated_input_count, :region_name, :created_at, :updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Key-value pairs that can be used to tag and organize this router network interface.
6502 6503 6504 6505 6506 6507 6508 6509 6510 6511 6512 6513 6514 6515 6516 6517 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6502 class RouterNetworkInterface < Struct.new( :name, :arn, :id, :state, :network_interface_type, :configuration, :associated_output_count, :associated_input_count, :region_name, :created_at, :updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp when the router network interface was last updated.
6502 6503 6504 6505 6506 6507 6508 6509 6510 6511 6512 6513 6514 6515 6516 6517 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6502 class RouterNetworkInterface < Struct.new( :name, :arn, :id, :state, :network_interface_type, :configuration, :associated_output_count, :associated_input_count, :region_name, :created_at, :updated_at, :tags) SENSITIVE = [] include Aws::Structure end |