Class: Aws::MediaConnect::Types::RouterOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::RouterOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
A router output in AWS Elemental MediaConnect. A router output is a destination for media content that can receive input from one or more router inputs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the router output.
-
#availability_zone ⇒ String
The Availability Zone of the router output.
-
#configuration ⇒ Types::RouterOutputConfiguration
The configuration settings for a router output.
-
#created_at ⇒ Time
The timestamp when the router output was created.
-
#fabric_configuration ⇒ Types::FabricConfiguration
The fabric configuration settings for the router output.
-
#id ⇒ String
The unique identifier of the router output.
-
#ip_address ⇒ String
The IP address of the router output.
-
#maintenance_configuration ⇒ Types::MaintenanceConfiguration
The maintenance configuration settings applied to this router output.
-
#maintenance_schedule ⇒ Types::MaintenanceSchedule
The current maintenance schedule details for this router output.
-
#maintenance_schedule_type ⇒ String
The type of maintenance schedule currently in effect for this router output.
-
#maintenance_type ⇒ String
The type of maintenance configuration applied to this router output.
-
#maximum_bitrate ⇒ Integer
The maximum bitrate for the router output.
-
#messages ⇒ Array<Types::RouterOutputMessage>
The messages associated with the router output.
-
#name ⇒ String
The name of the router output.
-
#output_type ⇒ String
The type of the router output.
-
#region_name ⇒ String
The Amazon Web Services Region where the router output is located.
-
#routed_input_arn ⇒ String
The Amazon Resource Name (ARN) of the router input associated with the output.
-
#routed_state ⇒ String
The current state of the association between the router output and its input.
-
#routing_scope ⇒ String
Indicates whether the router output is configured for Regional or global routing.
-
#state ⇒ String
The overall state of the router output.
-
#stream_details ⇒ Types::RouterOutputStreamDetails
Information about the router output's stream, including connection state and destination details.
-
#tags ⇒ Hash<String,String>
Key-value pairs that can be used to tag and organize this router output.
-
#tier ⇒ String
The tier level of the router output.
-
#updated_at ⇒ Time
The timestamp when the router output was last updated.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the router output.
6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6914 class RouterOutput < Struct.new( :name, :arn, :id, :state, :output_type, :configuration, :routed_state, :region_name, :availability_zone, :maximum_bitrate, :routing_scope, :tier, :created_at, :updated_at, :messages, :tags, :stream_details, :ip_address, :routed_input_arn, :maintenance_type, :maintenance_configuration, :maintenance_schedule_type, :maintenance_schedule, :fabric_configuration) SENSITIVE = [] include Aws::Structure end |
#availability_zone ⇒ String
The Availability Zone of the router output.
6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6914 class RouterOutput < Struct.new( :name, :arn, :id, :state, :output_type, :configuration, :routed_state, :region_name, :availability_zone, :maximum_bitrate, :routing_scope, :tier, :created_at, :updated_at, :messages, :tags, :stream_details, :ip_address, :routed_input_arn, :maintenance_type, :maintenance_configuration, :maintenance_schedule_type, :maintenance_schedule, :fabric_configuration) SENSITIVE = [] include Aws::Structure end |
#configuration ⇒ Types::RouterOutputConfiguration
The configuration settings for a router output.
6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6914 class RouterOutput < Struct.new( :name, :arn, :id, :state, :output_type, :configuration, :routed_state, :region_name, :availability_zone, :maximum_bitrate, :routing_scope, :tier, :created_at, :updated_at, :messages, :tags, :stream_details, :ip_address, :routed_input_arn, :maintenance_type, :maintenance_configuration, :maintenance_schedule_type, :maintenance_schedule, :fabric_configuration) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the router output was created.
6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6914 class RouterOutput < Struct.new( :name, :arn, :id, :state, :output_type, :configuration, :routed_state, :region_name, :availability_zone, :maximum_bitrate, :routing_scope, :tier, :created_at, :updated_at, :messages, :tags, :stream_details, :ip_address, :routed_input_arn, :maintenance_type, :maintenance_configuration, :maintenance_schedule_type, :maintenance_schedule, :fabric_configuration) SENSITIVE = [] include Aws::Structure end |
#fabric_configuration ⇒ Types::FabricConfiguration
The fabric configuration settings for the router output.
6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6914 class RouterOutput < Struct.new( :name, :arn, :id, :state, :output_type, :configuration, :routed_state, :region_name, :availability_zone, :maximum_bitrate, :routing_scope, :tier, :created_at, :updated_at, :messages, :tags, :stream_details, :ip_address, :routed_input_arn, :maintenance_type, :maintenance_configuration, :maintenance_schedule_type, :maintenance_schedule, :fabric_configuration) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the router output.
6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6914 class RouterOutput < Struct.new( :name, :arn, :id, :state, :output_type, :configuration, :routed_state, :region_name, :availability_zone, :maximum_bitrate, :routing_scope, :tier, :created_at, :updated_at, :messages, :tags, :stream_details, :ip_address, :routed_input_arn, :maintenance_type, :maintenance_configuration, :maintenance_schedule_type, :maintenance_schedule, :fabric_configuration) SENSITIVE = [] include Aws::Structure end |
#ip_address ⇒ String
The IP address of the router output.
6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6914 class RouterOutput < Struct.new( :name, :arn, :id, :state, :output_type, :configuration, :routed_state, :region_name, :availability_zone, :maximum_bitrate, :routing_scope, :tier, :created_at, :updated_at, :messages, :tags, :stream_details, :ip_address, :routed_input_arn, :maintenance_type, :maintenance_configuration, :maintenance_schedule_type, :maintenance_schedule, :fabric_configuration) SENSITIVE = [] include Aws::Structure end |
#maintenance_configuration ⇒ Types::MaintenanceConfiguration
The maintenance configuration settings applied to this router output.
6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6914 class RouterOutput < Struct.new( :name, :arn, :id, :state, :output_type, :configuration, :routed_state, :region_name, :availability_zone, :maximum_bitrate, :routing_scope, :tier, :created_at, :updated_at, :messages, :tags, :stream_details, :ip_address, :routed_input_arn, :maintenance_type, :maintenance_configuration, :maintenance_schedule_type, :maintenance_schedule, :fabric_configuration) SENSITIVE = [] include Aws::Structure end |
#maintenance_schedule ⇒ Types::MaintenanceSchedule
The current maintenance schedule details for this router output.
6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6914 class RouterOutput < Struct.new( :name, :arn, :id, :state, :output_type, :configuration, :routed_state, :region_name, :availability_zone, :maximum_bitrate, :routing_scope, :tier, :created_at, :updated_at, :messages, :tags, :stream_details, :ip_address, :routed_input_arn, :maintenance_type, :maintenance_configuration, :maintenance_schedule_type, :maintenance_schedule, :fabric_configuration) SENSITIVE = [] include Aws::Structure end |
#maintenance_schedule_type ⇒ String
The type of maintenance schedule currently in effect for this router output.
6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6914 class RouterOutput < Struct.new( :name, :arn, :id, :state, :output_type, :configuration, :routed_state, :region_name, :availability_zone, :maximum_bitrate, :routing_scope, :tier, :created_at, :updated_at, :messages, :tags, :stream_details, :ip_address, :routed_input_arn, :maintenance_type, :maintenance_configuration, :maintenance_schedule_type, :maintenance_schedule, :fabric_configuration) SENSITIVE = [] include Aws::Structure end |
#maintenance_type ⇒ String
The type of maintenance configuration applied to this router output.
6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6914 class RouterOutput < Struct.new( :name, :arn, :id, :state, :output_type, :configuration, :routed_state, :region_name, :availability_zone, :maximum_bitrate, :routing_scope, :tier, :created_at, :updated_at, :messages, :tags, :stream_details, :ip_address, :routed_input_arn, :maintenance_type, :maintenance_configuration, :maintenance_schedule_type, :maintenance_schedule, :fabric_configuration) SENSITIVE = [] include Aws::Structure end |
#maximum_bitrate ⇒ Integer
The maximum bitrate for the router output.
6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6914 class RouterOutput < Struct.new( :name, :arn, :id, :state, :output_type, :configuration, :routed_state, :region_name, :availability_zone, :maximum_bitrate, :routing_scope, :tier, :created_at, :updated_at, :messages, :tags, :stream_details, :ip_address, :routed_input_arn, :maintenance_type, :maintenance_configuration, :maintenance_schedule_type, :maintenance_schedule, :fabric_configuration) SENSITIVE = [] include Aws::Structure end |
#messages ⇒ Array<Types::RouterOutputMessage>
The messages associated with the router output.
6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6914 class RouterOutput < Struct.new( :name, :arn, :id, :state, :output_type, :configuration, :routed_state, :region_name, :availability_zone, :maximum_bitrate, :routing_scope, :tier, :created_at, :updated_at, :messages, :tags, :stream_details, :ip_address, :routed_input_arn, :maintenance_type, :maintenance_configuration, :maintenance_schedule_type, :maintenance_schedule, :fabric_configuration) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the router output.
6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6914 class RouterOutput < Struct.new( :name, :arn, :id, :state, :output_type, :configuration, :routed_state, :region_name, :availability_zone, :maximum_bitrate, :routing_scope, :tier, :created_at, :updated_at, :messages, :tags, :stream_details, :ip_address, :routed_input_arn, :maintenance_type, :maintenance_configuration, :maintenance_schedule_type, :maintenance_schedule, :fabric_configuration) SENSITIVE = [] include Aws::Structure end |
#output_type ⇒ String
The type of the router output.
6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6914 class RouterOutput < Struct.new( :name, :arn, :id, :state, :output_type, :configuration, :routed_state, :region_name, :availability_zone, :maximum_bitrate, :routing_scope, :tier, :created_at, :updated_at, :messages, :tags, :stream_details, :ip_address, :routed_input_arn, :maintenance_type, :maintenance_configuration, :maintenance_schedule_type, :maintenance_schedule, :fabric_configuration) SENSITIVE = [] include Aws::Structure end |
#region_name ⇒ String
The Amazon Web Services Region where the router output is located.
6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6914 class RouterOutput < Struct.new( :name, :arn, :id, :state, :output_type, :configuration, :routed_state, :region_name, :availability_zone, :maximum_bitrate, :routing_scope, :tier, :created_at, :updated_at, :messages, :tags, :stream_details, :ip_address, :routed_input_arn, :maintenance_type, :maintenance_configuration, :maintenance_schedule_type, :maintenance_schedule, :fabric_configuration) SENSITIVE = [] include Aws::Structure end |
#routed_input_arn ⇒ String
The Amazon Resource Name (ARN) of the router input associated with the output.
6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6914 class RouterOutput < Struct.new( :name, :arn, :id, :state, :output_type, :configuration, :routed_state, :region_name, :availability_zone, :maximum_bitrate, :routing_scope, :tier, :created_at, :updated_at, :messages, :tags, :stream_details, :ip_address, :routed_input_arn, :maintenance_type, :maintenance_configuration, :maintenance_schedule_type, :maintenance_schedule, :fabric_configuration) SENSITIVE = [] include Aws::Structure end |
#routed_state ⇒ String
The current state of the association between the router output and its input.
6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6914 class RouterOutput < Struct.new( :name, :arn, :id, :state, :output_type, :configuration, :routed_state, :region_name, :availability_zone, :maximum_bitrate, :routing_scope, :tier, :created_at, :updated_at, :messages, :tags, :stream_details, :ip_address, :routed_input_arn, :maintenance_type, :maintenance_configuration, :maintenance_schedule_type, :maintenance_schedule, :fabric_configuration) SENSITIVE = [] include Aws::Structure end |
#routing_scope ⇒ String
Indicates whether the router output is configured for Regional or global routing.
6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6914 class RouterOutput < Struct.new( :name, :arn, :id, :state, :output_type, :configuration, :routed_state, :region_name, :availability_zone, :maximum_bitrate, :routing_scope, :tier, :created_at, :updated_at, :messages, :tags, :stream_details, :ip_address, :routed_input_arn, :maintenance_type, :maintenance_configuration, :maintenance_schedule_type, :maintenance_schedule, :fabric_configuration) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The overall state of the router output.
6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6914 class RouterOutput < Struct.new( :name, :arn, :id, :state, :output_type, :configuration, :routed_state, :region_name, :availability_zone, :maximum_bitrate, :routing_scope, :tier, :created_at, :updated_at, :messages, :tags, :stream_details, :ip_address, :routed_input_arn, :maintenance_type, :maintenance_configuration, :maintenance_schedule_type, :maintenance_schedule, :fabric_configuration) SENSITIVE = [] include Aws::Structure end |
#stream_details ⇒ Types::RouterOutputStreamDetails
Information about the router output's stream, including connection state and destination details. The specific details provided vary based on the router output type.
6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6914 class RouterOutput < Struct.new( :name, :arn, :id, :state, :output_type, :configuration, :routed_state, :region_name, :availability_zone, :maximum_bitrate, :routing_scope, :tier, :created_at, :updated_at, :messages, :tags, :stream_details, :ip_address, :routed_input_arn, :maintenance_type, :maintenance_configuration, :maintenance_schedule_type, :maintenance_schedule, :fabric_configuration) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Key-value pairs that can be used to tag and organize this router output.
6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6914 class RouterOutput < Struct.new( :name, :arn, :id, :state, :output_type, :configuration, :routed_state, :region_name, :availability_zone, :maximum_bitrate, :routing_scope, :tier, :created_at, :updated_at, :messages, :tags, :stream_details, :ip_address, :routed_input_arn, :maintenance_type, :maintenance_configuration, :maintenance_schedule_type, :maintenance_schedule, :fabric_configuration) SENSITIVE = [] include Aws::Structure end |
#tier ⇒ String
The tier level of the router output.
6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6914 class RouterOutput < Struct.new( :name, :arn, :id, :state, :output_type, :configuration, :routed_state, :region_name, :availability_zone, :maximum_bitrate, :routing_scope, :tier, :created_at, :updated_at, :messages, :tags, :stream_details, :ip_address, :routed_input_arn, :maintenance_type, :maintenance_configuration, :maintenance_schedule_type, :maintenance_schedule, :fabric_configuration) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp when the router output was last updated.
6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6914 class RouterOutput < Struct.new( :name, :arn, :id, :state, :output_type, :configuration, :routed_state, :region_name, :availability_zone, :maximum_bitrate, :routing_scope, :tier, :created_at, :updated_at, :messages, :tags, :stream_details, :ip_address, :routed_input_arn, :maintenance_type, :maintenance_configuration, :maintenance_schedule_type, :maintenance_schedule, :fabric_configuration) SENSITIVE = [] include Aws::Structure end |