Class: Aws::MediaConnect::Types::RouterOutputProtocolConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-mediaconnect/types.rb

Overview

Note:

RouterOutputProtocolConfiguration is a union - when making an API calls you must set exactly one of the members.

Note:

RouterOutputProtocolConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of RouterOutputProtocolConfiguration corresponding to the set member.

The protocol configuration settings for a router output.

Defined Under Namespace

Classes: Rist, Rtp, SrtCaller, SrtListener, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ristTypes::RistRouterOutputConfiguration

The configuration settings for a router output using the RIST (Reliable Internet Stream Transport) protocol, including the destination address and port.



7087
7088
7089
7090
7091
7092
7093
7094
7095
7096
7097
7098
7099
7100
7101
7102
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7087

class RouterOutputProtocolConfiguration < Struct.new(
  :rist,
  :srt_listener,
  :srt_caller,
  :rtp,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Rist < RouterOutputProtocolConfiguration; end
  class SrtListener < RouterOutputProtocolConfiguration; end
  class SrtCaller < RouterOutputProtocolConfiguration; end
  class Rtp < RouterOutputProtocolConfiguration; end
  class Unknown < RouterOutputProtocolConfiguration; end
end

#rtpTypes::RtpRouterOutputConfiguration

The configuration settings for a router output using the RTP (Real-Time Transport Protocol) protocol, including the destination address and port, and forward error correction state.



7087
7088
7089
7090
7091
7092
7093
7094
7095
7096
7097
7098
7099
7100
7101
7102
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7087

class RouterOutputProtocolConfiguration < Struct.new(
  :rist,
  :srt_listener,
  :srt_caller,
  :rtp,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Rist < RouterOutputProtocolConfiguration; end
  class SrtListener < RouterOutputProtocolConfiguration; end
  class SrtCaller < RouterOutputProtocolConfiguration; end
  class Rtp < RouterOutputProtocolConfiguration; end
  class Unknown < RouterOutputProtocolConfiguration; end
end

#srt_callerTypes::SrtCallerRouterOutputConfiguration

The configuration settings for a router output using the SRT (Secure Reliable Transport) protocol in caller mode, including the destination address and port, minimum latency, stream ID, and encryption key configuration.



7087
7088
7089
7090
7091
7092
7093
7094
7095
7096
7097
7098
7099
7100
7101
7102
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7087

class RouterOutputProtocolConfiguration < Struct.new(
  :rist,
  :srt_listener,
  :srt_caller,
  :rtp,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Rist < RouterOutputProtocolConfiguration; end
  class SrtListener < RouterOutputProtocolConfiguration; end
  class SrtCaller < RouterOutputProtocolConfiguration; end
  class Rtp < RouterOutputProtocolConfiguration; end
  class Unknown < RouterOutputProtocolConfiguration; end
end

#srt_listenerTypes::SrtListenerRouterOutputConfiguration

The configuration settings for a router output using the SRT (Secure Reliable Transport) protocol in listener mode, including the port, minimum latency, and encryption key configuration.



7087
7088
7089
7090
7091
7092
7093
7094
7095
7096
7097
7098
7099
7100
7101
7102
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7087

class RouterOutputProtocolConfiguration < Struct.new(
  :rist,
  :srt_listener,
  :srt_caller,
  :rtp,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Rist < RouterOutputProtocolConfiguration; end
  class SrtListener < RouterOutputProtocolConfiguration; end
  class SrtCaller < RouterOutputProtocolConfiguration; end
  class Rtp < RouterOutputProtocolConfiguration; end
  class Unknown < RouterOutputProtocolConfiguration; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



7087
7088
7089
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7087

def unknown
  @unknown
end