Class: Aws::MediaConnect::Types::RouterOutputStreamDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::RouterOutputStreamDetails
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
RouterOutputStreamDetails is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of RouterOutputStreamDetails corresponding to the set member.
Information about the router output's stream, including connection state and destination details. The specific details provided vary based on the router output type.
Defined Under Namespace
Classes: MediaConnectFlow, MediaLiveInput, Standard, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#media_connect_flow ⇒ Types::MediaConnectFlowRouterOutputStreamDetails
Configuration details for a MediaConnect flow when used as a router output destination.
-
#media_live_input ⇒ Types::MediaLiveInputRouterOutputStreamDetails
Configuration details for a MediaLive input when used as a router output destination.
-
#standard ⇒ Types::StandardRouterOutputStreamDetails
Configuration details for a standard router output stream type.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#media_connect_flow ⇒ Types::MediaConnectFlowRouterOutputStreamDetails
Configuration details for a MediaConnect flow when used as a router output destination.
7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7142 class RouterOutputStreamDetails < Struct.new( :standard, :media_connect_flow, :media_live_input, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Standard < RouterOutputStreamDetails; end class MediaConnectFlow < RouterOutputStreamDetails; end class MediaLiveInput < RouterOutputStreamDetails; end class Unknown < RouterOutputStreamDetails; end end |
#media_live_input ⇒ Types::MediaLiveInputRouterOutputStreamDetails
Configuration details for a MediaLive input when used as a router output destination.
7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7142 class RouterOutputStreamDetails < Struct.new( :standard, :media_connect_flow, :media_live_input, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Standard < RouterOutputStreamDetails; end class MediaConnectFlow < RouterOutputStreamDetails; end class MediaLiveInput < RouterOutputStreamDetails; end class Unknown < RouterOutputStreamDetails; end end |
#standard ⇒ Types::StandardRouterOutputStreamDetails
Configuration details for a standard router output stream type. Contains information about the destination IP address and connection state for basic output routing.
7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7142 class RouterOutputStreamDetails < Struct.new( :standard, :media_connect_flow, :media_live_input, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Standard < RouterOutputStreamDetails; end class MediaConnectFlow < RouterOutputStreamDetails; end class MediaLiveInput < RouterOutputStreamDetails; end class Unknown < RouterOutputStreamDetails; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
7142 7143 7144 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7142 def unknown @unknown end |