Class: Aws::MediaConnect::Types::SetSourceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconnect/types.rb

Overview

The settings for the source of the flow.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#decryptionTypes::Encryption

The type of encryption that is used on the content ingested from this source. Allowable encryption types: static-key.

Returns:



7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7359

class SetSourceRequest < Struct.new(
  :decryption,
  :description,
  :entitlement_arn,
  :ingest_port,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :media_stream_source_configurations,
  :min_latency,
  :name,
  :protocol,
  :sender_control_port,
  :sender_ip_address,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :vpc_interface_name,
  :whitelist_cidr,
  :gateway_bridge_source,
  :ndi_source_settings,
  :source_tags,
  :router_integration_state,
  :router_integration_transit_decryption)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description for the source. This value is not used or seen outside of the current MediaConnect account.

Returns:

  • (String)


7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7359

class SetSourceRequest < Struct.new(
  :decryption,
  :description,
  :entitlement_arn,
  :ingest_port,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :media_stream_source_configurations,
  :min_latency,
  :name,
  :protocol,
  :sender_control_port,
  :sender_ip_address,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :vpc_interface_name,
  :whitelist_cidr,
  :gateway_bridge_source,
  :ndi_source_settings,
  :source_tags,
  :router_integration_state,
  :router_integration_transit_decryption)
  SENSITIVE = []
  include Aws::Structure
end

#entitlement_arnString

The ARN of the entitlement that allows you to subscribe to this flow. The entitlement is set by the flow originator, and the ARN is generated as part of the originator’s flow.

Returns:

  • (String)


7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7359

class SetSourceRequest < Struct.new(
  :decryption,
  :description,
  :entitlement_arn,
  :ingest_port,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :media_stream_source_configurations,
  :min_latency,
  :name,
  :protocol,
  :sender_control_port,
  :sender_ip_address,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :vpc_interface_name,
  :whitelist_cidr,
  :gateway_bridge_source,
  :ndi_source_settings,
  :source_tags,
  :router_integration_state,
  :router_integration_transit_decryption)
  SENSITIVE = []
  include Aws::Structure
end

#gateway_bridge_sourceTypes::SetGatewayBridgeSourceRequest

The source configuration for cloud flows receiving a stream from a bridge.



7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7359

class SetSourceRequest < Struct.new(
  :decryption,
  :description,
  :entitlement_arn,
  :ingest_port,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :media_stream_source_configurations,
  :min_latency,
  :name,
  :protocol,
  :sender_control_port,
  :sender_ip_address,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :vpc_interface_name,
  :whitelist_cidr,
  :gateway_bridge_source,
  :ndi_source_settings,
  :source_tags,
  :router_integration_state,
  :router_integration_transit_decryption)
  SENSITIVE = []
  include Aws::Structure
end

#ingest_portInteger

The port that the flow will be listening on for incoming content.

Returns:

  • (Integer)


7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7359

class SetSourceRequest < Struct.new(
  :decryption,
  :description,
  :entitlement_arn,
  :ingest_port,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :media_stream_source_configurations,
  :min_latency,
  :name,
  :protocol,
  :sender_control_port,
  :sender_ip_address,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :vpc_interface_name,
  :whitelist_cidr,
  :gateway_bridge_source,
  :ndi_source_settings,
  :source_tags,
  :router_integration_state,
  :router_integration_transit_decryption)
  SENSITIVE = []
  include Aws::Structure
end

#max_bitrateInteger

The smoothing max bitrate (in bps) for RIST, RTP, and RTP-FEC streams.

Returns:

  • (Integer)


7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7359

class SetSourceRequest < Struct.new(
  :decryption,
  :description,
  :entitlement_arn,
  :ingest_port,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :media_stream_source_configurations,
  :min_latency,
  :name,
  :protocol,
  :sender_control_port,
  :sender_ip_address,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :vpc_interface_name,
  :whitelist_cidr,
  :gateway_bridge_source,
  :ndi_source_settings,
  :source_tags,
  :router_integration_state,
  :router_integration_transit_decryption)
  SENSITIVE = []
  include Aws::Structure
end

#max_latencyInteger

The maximum latency in milliseconds. This parameter applies only to RIST-based and Zixi-based streams.

Returns:

  • (Integer)


7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7359

class SetSourceRequest < Struct.new(
  :decryption,
  :description,
  :entitlement_arn,
  :ingest_port,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :media_stream_source_configurations,
  :min_latency,
  :name,
  :protocol,
  :sender_control_port,
  :sender_ip_address,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :vpc_interface_name,
  :whitelist_cidr,
  :gateway_bridge_source,
  :ndi_source_settings,
  :source_tags,
  :router_integration_state,
  :router_integration_transit_decryption)
  SENSITIVE = []
  include Aws::Structure
end

#max_sync_bufferInteger

The size of the buffer (in milliseconds) to use to sync incoming source data.

Returns:

  • (Integer)


7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7359

class SetSourceRequest < Struct.new(
  :decryption,
  :description,
  :entitlement_arn,
  :ingest_port,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :media_stream_source_configurations,
  :min_latency,
  :name,
  :protocol,
  :sender_control_port,
  :sender_ip_address,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :vpc_interface_name,
  :whitelist_cidr,
  :gateway_bridge_source,
  :ndi_source_settings,
  :source_tags,
  :router_integration_state,
  :router_integration_transit_decryption)
  SENSITIVE = []
  include Aws::Structure
end

#media_stream_source_configurationsArray<Types::MediaStreamSourceConfigurationRequest>

The media streams that are associated with the source, and the parameters for those associations.



7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7359

class SetSourceRequest < Struct.new(
  :decryption,
  :description,
  :entitlement_arn,
  :ingest_port,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :media_stream_source_configurations,
  :min_latency,
  :name,
  :protocol,
  :sender_control_port,
  :sender_ip_address,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :vpc_interface_name,
  :whitelist_cidr,
  :gateway_bridge_source,
  :ndi_source_settings,
  :source_tags,
  :router_integration_state,
  :router_integration_transit_decryption)
  SENSITIVE = []
  include Aws::Structure
end

#min_latencyInteger

The minimum latency in milliseconds for SRT-based streams. In streams that use the SRT protocol, this value that you set on your MediaConnect source or output represents the minimal potential latency of that connection. The latency of the stream is set to the highest number between the sender’s minimum latency and the receiver’s minimum latency.

Returns:

  • (Integer)


7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7359

class SetSourceRequest < Struct.new(
  :decryption,
  :description,
  :entitlement_arn,
  :ingest_port,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :media_stream_source_configurations,
  :min_latency,
  :name,
  :protocol,
  :sender_control_port,
  :sender_ip_address,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :vpc_interface_name,
  :whitelist_cidr,
  :gateway_bridge_source,
  :ndi_source_settings,
  :source_tags,
  :router_integration_state,
  :router_integration_transit_decryption)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the source.

Returns:

  • (String)


7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7359

class SetSourceRequest < Struct.new(
  :decryption,
  :description,
  :entitlement_arn,
  :ingest_port,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :media_stream_source_configurations,
  :min_latency,
  :name,
  :protocol,
  :sender_control_port,
  :sender_ip_address,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :vpc_interface_name,
  :whitelist_cidr,
  :gateway_bridge_source,
  :ndi_source_settings,
  :source_tags,
  :router_integration_state,
  :router_integration_transit_decryption)
  SENSITIVE = []
  include Aws::Structure
end

#ndi_source_settingsTypes::NdiSourceSettings

The settings for the NDI® source. This includes the exact name of the upstream NDI sender that you want to connect to your source.



7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7359

class SetSourceRequest < Struct.new(
  :decryption,
  :description,
  :entitlement_arn,
  :ingest_port,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :media_stream_source_configurations,
  :min_latency,
  :name,
  :protocol,
  :sender_control_port,
  :sender_ip_address,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :vpc_interface_name,
  :whitelist_cidr,
  :gateway_bridge_source,
  :ndi_source_settings,
  :source_tags,
  :router_integration_state,
  :router_integration_transit_decryption)
  SENSITIVE = []
  include Aws::Structure
end

#protocolString

The protocol that is used by the source.

<note markdown=“1”> Elemental MediaConnect no longer supports the Fujitsu QoS protocol. This reference is maintained for legacy purposes only.

</note>

Returns:

  • (String)


7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7359

class SetSourceRequest < Struct.new(
  :decryption,
  :description,
  :entitlement_arn,
  :ingest_port,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :media_stream_source_configurations,
  :min_latency,
  :name,
  :protocol,
  :sender_control_port,
  :sender_ip_address,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :vpc_interface_name,
  :whitelist_cidr,
  :gateway_bridge_source,
  :ndi_source_settings,
  :source_tags,
  :router_integration_state,
  :router_integration_transit_decryption)
  SENSITIVE = []
  include Aws::Structure
end

#router_integration_stateString

Indicates whether to enable or disable router integration when setting a flow source.

Returns:

  • (String)


7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7359

class SetSourceRequest < Struct.new(
  :decryption,
  :description,
  :entitlement_arn,
  :ingest_port,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :media_stream_source_configurations,
  :min_latency,
  :name,
  :protocol,
  :sender_control_port,
  :sender_ip_address,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :vpc_interface_name,
  :whitelist_cidr,
  :gateway_bridge_source,
  :ndi_source_settings,
  :source_tags,
  :router_integration_state,
  :router_integration_transit_decryption)
  SENSITIVE = []
  include Aws::Structure
end

#router_integration_transit_decryptionTypes::FlowTransitEncryption

The decryption configuration for the flow source when router integration is enabled. Specifies how the source content should be decrypted when router integration is used.



7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7359

class SetSourceRequest < Struct.new(
  :decryption,
  :description,
  :entitlement_arn,
  :ingest_port,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :media_stream_source_configurations,
  :min_latency,
  :name,
  :protocol,
  :sender_control_port,
  :sender_ip_address,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :vpc_interface_name,
  :whitelist_cidr,
  :gateway_bridge_source,
  :ndi_source_settings,
  :source_tags,
  :router_integration_state,
  :router_integration_transit_decryption)
  SENSITIVE = []
  include Aws::Structure
end

#sender_control_portInteger

The port that the flow uses to send outbound requests to initiate connection with the sender.

Returns:

  • (Integer)


7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7359

class SetSourceRequest < Struct.new(
  :decryption,
  :description,
  :entitlement_arn,
  :ingest_port,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :media_stream_source_configurations,
  :min_latency,
  :name,
  :protocol,
  :sender_control_port,
  :sender_ip_address,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :vpc_interface_name,
  :whitelist_cidr,
  :gateway_bridge_source,
  :ndi_source_settings,
  :source_tags,
  :router_integration_state,
  :router_integration_transit_decryption)
  SENSITIVE = []
  include Aws::Structure
end

#sender_ip_addressString

The IP address that the flow communicates with to initiate connection with the sender.

Returns:

  • (String)


7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7359

class SetSourceRequest < Struct.new(
  :decryption,
  :description,
  :entitlement_arn,
  :ingest_port,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :media_stream_source_configurations,
  :min_latency,
  :name,
  :protocol,
  :sender_control_port,
  :sender_ip_address,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :vpc_interface_name,
  :whitelist_cidr,
  :gateway_bridge_source,
  :ndi_source_settings,
  :source_tags,
  :router_integration_state,
  :router_integration_transit_decryption)
  SENSITIVE = []
  include Aws::Structure
end

#source_listener_addressString

Source IP or domain name for SRT-caller protocol.

Returns:

  • (String)


7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7359

class SetSourceRequest < Struct.new(
  :decryption,
  :description,
  :entitlement_arn,
  :ingest_port,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :media_stream_source_configurations,
  :min_latency,
  :name,
  :protocol,
  :sender_control_port,
  :sender_ip_address,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :vpc_interface_name,
  :whitelist_cidr,
  :gateway_bridge_source,
  :ndi_source_settings,
  :source_tags,
  :router_integration_state,
  :router_integration_transit_decryption)
  SENSITIVE = []
  include Aws::Structure
end

#source_listener_portInteger

Source port for SRT-caller protocol.

Returns:

  • (Integer)


7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7359

class SetSourceRequest < Struct.new(
  :decryption,
  :description,
  :entitlement_arn,
  :ingest_port,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :media_stream_source_configurations,
  :min_latency,
  :name,
  :protocol,
  :sender_control_port,
  :sender_ip_address,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :vpc_interface_name,
  :whitelist_cidr,
  :gateway_bridge_source,
  :ndi_source_settings,
  :source_tags,
  :router_integration_state,
  :router_integration_transit_decryption)
  SENSITIVE = []
  include Aws::Structure
end

#source_tagsHash<String,String>

The key-value pairs that can be used to tag and organize the source.

Returns:

  • (Hash<String,String>)


7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7359

class SetSourceRequest < Struct.new(
  :decryption,
  :description,
  :entitlement_arn,
  :ingest_port,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :media_stream_source_configurations,
  :min_latency,
  :name,
  :protocol,
  :sender_control_port,
  :sender_ip_address,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :vpc_interface_name,
  :whitelist_cidr,
  :gateway_bridge_source,
  :ndi_source_settings,
  :source_tags,
  :router_integration_state,
  :router_integration_transit_decryption)
  SENSITIVE = []
  include Aws::Structure
end

#stream_idString

The stream ID that you want to use for this transport. This parameter applies only to Zixi and SRT caller-based streams.

Returns:

  • (String)


7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7359

class SetSourceRequest < Struct.new(
  :decryption,
  :description,
  :entitlement_arn,
  :ingest_port,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :media_stream_source_configurations,
  :min_latency,
  :name,
  :protocol,
  :sender_control_port,
  :sender_ip_address,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :vpc_interface_name,
  :whitelist_cidr,
  :gateway_bridge_source,
  :ndi_source_settings,
  :source_tags,
  :router_integration_state,
  :router_integration_transit_decryption)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_interface_nameString

The name of the VPC interface to use for this source.

Returns:

  • (String)


7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7359

class SetSourceRequest < Struct.new(
  :decryption,
  :description,
  :entitlement_arn,
  :ingest_port,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :media_stream_source_configurations,
  :min_latency,
  :name,
  :protocol,
  :sender_control_port,
  :sender_ip_address,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :vpc_interface_name,
  :whitelist_cidr,
  :gateway_bridge_source,
  :ndi_source_settings,
  :source_tags,
  :router_integration_state,
  :router_integration_transit_decryption)
  SENSITIVE = []
  include Aws::Structure
end

#whitelist_cidrString

The range of IP addresses that should be allowed to contribute content to your source. These IP addresses should be in the form of a Classless Inter-Domain Routing (CIDR) block; for example, 10.0.0.0/16.

Returns:

  • (String)


7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7359

class SetSourceRequest < Struct.new(
  :decryption,
  :description,
  :entitlement_arn,
  :ingest_port,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :media_stream_source_configurations,
  :min_latency,
  :name,
  :protocol,
  :sender_control_port,
  :sender_ip_address,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :vpc_interface_name,
  :whitelist_cidr,
  :gateway_bridge_source,
  :ndi_source_settings,
  :source_tags,
  :router_integration_state,
  :router_integration_transit_decryption)
  SENSITIVE = []
  include Aws::Structure
end