Class: Aws::MediaConnect::Types::SilentAudioConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconnect/types.rb

Overview

Detects silent audio in the router input’s source content and reports it through a CloudWatch metric, an EventBridge event, and a router input message.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#stateString

Indicates whether silent audio detection is enabled or disabled.

Returns:

  • (String)


7422
7423
7424
7425
7426
7427
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7422

class SilentAudioConfiguration < Struct.new(
  :state,
  :threshold_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#threshold_secondsInteger

The number of consecutive seconds of silence that MediaConnect must detect before it reports an issue.

Returns:

  • (Integer)


7422
7423
7424
7425
7426
7427
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7422

class SilentAudioConfiguration < Struct.new(
  :state,
  :threshold_seconds)
  SENSITIVE = []
  include Aws::Structure
end