Class: Aws::MediaConnect::Types::StopRouterInputResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::StopRouterInputResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the router input that was stopped.
-
#name ⇒ String
The name of the router input that was stopped.
-
#state ⇒ String
The current state of the router input after being stopped.
Instance Attribute Details
#arn ⇒ String
The ARN of the router input that was stopped.
7882 7883 7884 7885 7886 7887 7888 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7882 class StopRouterInputResponse < Struct.new( :arn, :name, :state) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the router input that was stopped.
7882 7883 7884 7885 7886 7887 7888 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7882 class StopRouterInputResponse < Struct.new( :arn, :name, :state) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the router input after being stopped.
7882 7883 7884 7885 7886 7887 7888 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7882 class StopRouterInputResponse < Struct.new( :arn, :name, :state) SENSITIVE = [] include Aws::Structure end |