Class: Aws::MediaConnect::Types::StopRouterOutputResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::StopRouterOutputResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the router output that was stopped.
-
#name ⇒ String
The name of the router output that was stopped.
-
#state ⇒ String
The current state of the router output after being stopped.
Instance Attribute Details
#arn ⇒ String
The ARN of the router output that was stopped.
7902 7903 7904 7905 7906 7907 7908 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7902 class StopRouterOutputResponse < Struct.new( :arn, :name, :state) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the router output that was stopped.
7902 7903 7904 7905 7906 7907 7908 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7902 class StopRouterOutputResponse < Struct.new( :arn, :name, :state) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the router output after being stopped.
7902 7903 7904 7905 7906 7907 7908 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7902 class StopRouterOutputResponse < Struct.new( :arn, :name, :state) SENSITIVE = [] include Aws::Structure end |