Class: Aws::MediaConnect::Types::UpdateFlowEntitlementRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::UpdateFlowEntitlementRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the entitlement.
-
#encryption ⇒ Types::UpdateEncryption
The type of encryption that will be used on the output associated with this entitlement.
-
#entitlement_arn ⇒ String
The Amazon Resource Name (ARN) of the entitlement that you want to update.
-
#entitlement_status ⇒ String
An indication of whether you want to enable the entitlement to allow access, or disable it to stop streaming content to the subscriber’s flow temporarily.
-
#flow_arn ⇒ String
The ARN of the flow that is associated with the entitlement that you want to update.
-
#subscribers ⇒ Array<String>
The Amazon Web Services account IDs that you want to share your content with.
Instance Attribute Details
#description ⇒ String
A description of the entitlement. This description appears only on the MediaConnect console and will not be seen by the subscriber or end user.
8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 8873 class UpdateFlowEntitlementRequest < Struct.new( :description, :encryption, :entitlement_arn, :entitlement_status, :flow_arn, :subscribers) SENSITIVE = [] include Aws::Structure end |
#encryption ⇒ Types::UpdateEncryption
The type of encryption that will be used on the output associated with this entitlement. Allowable encryption types: static-key, speke.
8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 8873 class UpdateFlowEntitlementRequest < Struct.new( :description, :encryption, :entitlement_arn, :entitlement_status, :flow_arn, :subscribers) SENSITIVE = [] include Aws::Structure end |
#entitlement_arn ⇒ String
The Amazon Resource Name (ARN) of the entitlement that you want to update.
8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 8873 class UpdateFlowEntitlementRequest < Struct.new( :description, :encryption, :entitlement_arn, :entitlement_status, :flow_arn, :subscribers) SENSITIVE = [] include Aws::Structure end |
#entitlement_status ⇒ String
An indication of whether you want to enable the entitlement to allow access, or disable it to stop streaming content to the subscriber’s flow temporarily. If you don’t specify the ‘entitlementStatus` field in your request, MediaConnect leaves the value unchanged.
8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 8873 class UpdateFlowEntitlementRequest < Struct.new( :description, :encryption, :entitlement_arn, :entitlement_status, :flow_arn, :subscribers) SENSITIVE = [] include Aws::Structure end |
#flow_arn ⇒ String
The ARN of the flow that is associated with the entitlement that you want to update.
8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 8873 class UpdateFlowEntitlementRequest < Struct.new( :description, :encryption, :entitlement_arn, :entitlement_status, :flow_arn, :subscribers) SENSITIVE = [] include Aws::Structure end |
#subscribers ⇒ Array<String>
The Amazon Web Services account IDs that you want to share your content with. The receiving accounts (subscribers) will be allowed to create their own flow using your content as the source.
8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 8873 class UpdateFlowEntitlementRequest < Struct.new( :description, :encryption, :entitlement_arn, :entitlement_status, :flow_arn, :subscribers) SENSITIVE = [] include Aws::Structure end |