Class: Aws::MediaConnect::Types::UpdateFlowOutputRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::UpdateFlowOutputRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cidr_allow_list ⇒ Array<String>
The range of IP addresses that should be allowed to initiate output requests to this flow.
-
#description ⇒ String
A description of the output.
-
#destination ⇒ String
The IP address where you want to send the output.
-
#encryption ⇒ Types::UpdateEncryption
The type of key used for the encryption.
-
#flow_arn ⇒ String
The Amazon Resource Name (ARN) of the flow that is associated with the output that you want to update.
-
#max_latency ⇒ Integer
The maximum latency in milliseconds.
-
#media_stream_output_configurations ⇒ Array<Types::MediaStreamOutputConfigurationRequest>
The media streams that are associated with the output, and the parameters for those associations.
-
#min_latency ⇒ Integer
The minimum latency in milliseconds for SRT-based streams.
-
#ndi_output_timecode_source ⇒ String
Controls how MediaConnect generates timecodes for NDI output frames.
-
#ndi_program_name ⇒ String
A suffix for the name of the NDI® sender that the flow creates.
-
#ndi_speed_hq_quality ⇒ Integer
A quality setting for the NDI Speed HQ encoder.
-
#output_arn ⇒ String
The ARN of the output that you want to update.
-
#output_status ⇒ String
An indication of whether the output should transmit data or not.
-
#port ⇒ Integer
The port to use when content is distributed to this output.
-
#protocol ⇒ String
The protocol to use for the output.
-
#remote_id ⇒ String
The remote ID for the Zixi-pull stream.
-
#router_integration_state ⇒ String
Indicates whether to enable or disable router integration for this flow output.
-
#router_integration_transit_encryption ⇒ Types::FlowTransitEncryption
The configuration that defines how content is encrypted during transit between the MediaConnect router and a MediaConnect flow.
-
#sender_control_port ⇒ Integer
The port that the flow uses to send outbound requests to initiate connection with the sender.
-
#sender_ip_address ⇒ String
The IP address that the flow communicates with to initiate connection with the sender.
-
#smoothing_latency ⇒ Integer
The smoothing latency in milliseconds for RIST, RTP, and RTP-FEC streams.
-
#stream_id ⇒ String
The stream ID that you want to use for this transport.
-
#vpc_interface_attachment ⇒ Types::VpcInterfaceAttachment
The name of the VPC interface attachment to use for this output.
Instance Attribute Details
#cidr_allow_list ⇒ Array<String>
The range of IP addresses that should be allowed to initiate output requests to this flow. These IP addresses should be in the form of a Classless Inter-Domain Routing (CIDR) block; for example, 10.0.0.0/16.
9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 9111 9112 9113 9114 9115 9116 9117 9118 9119 9120 9121 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9095 class UpdateFlowOutputRequest < Struct.new( :cidr_allow_list, :description, :destination, :encryption, :flow_arn, :max_latency, :media_stream_output_configurations, :min_latency, :output_arn, :port, :protocol, :remote_id, :sender_control_port, :sender_ip_address, :smoothing_latency, :stream_id, :vpc_interface_attachment, :output_status, :ndi_program_name, :ndi_speed_hq_quality, :router_integration_state, :router_integration_transit_encryption, :ndi_output_timecode_source) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the output. This description appears only on the MediaConnect console and will not be seen by the end user.
9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 9111 9112 9113 9114 9115 9116 9117 9118 9119 9120 9121 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9095 class UpdateFlowOutputRequest < Struct.new( :cidr_allow_list, :description, :destination, :encryption, :flow_arn, :max_latency, :media_stream_output_configurations, :min_latency, :output_arn, :port, :protocol, :remote_id, :sender_control_port, :sender_ip_address, :smoothing_latency, :stream_id, :vpc_interface_attachment, :output_status, :ndi_program_name, :ndi_speed_hq_quality, :router_integration_state, :router_integration_transit_encryption, :ndi_output_timecode_source) SENSITIVE = [] include Aws::Structure end |
#destination ⇒ String
The IP address where you want to send the output.
9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 9111 9112 9113 9114 9115 9116 9117 9118 9119 9120 9121 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9095 class UpdateFlowOutputRequest < Struct.new( :cidr_allow_list, :description, :destination, :encryption, :flow_arn, :max_latency, :media_stream_output_configurations, :min_latency, :output_arn, :port, :protocol, :remote_id, :sender_control_port, :sender_ip_address, :smoothing_latency, :stream_id, :vpc_interface_attachment, :output_status, :ndi_program_name, :ndi_speed_hq_quality, :router_integration_state, :router_integration_transit_encryption, :ndi_output_timecode_source) SENSITIVE = [] include Aws::Structure end |
#encryption ⇒ Types::UpdateEncryption
The type of key used for the encryption. If no ‘keyType` is provided, the service will use the default setting (static-key). Allowable encryption types: static-key.
9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 9111 9112 9113 9114 9115 9116 9117 9118 9119 9120 9121 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9095 class UpdateFlowOutputRequest < Struct.new( :cidr_allow_list, :description, :destination, :encryption, :flow_arn, :max_latency, :media_stream_output_configurations, :min_latency, :output_arn, :port, :protocol, :remote_id, :sender_control_port, :sender_ip_address, :smoothing_latency, :stream_id, :vpc_interface_attachment, :output_status, :ndi_program_name, :ndi_speed_hq_quality, :router_integration_state, :router_integration_transit_encryption, :ndi_output_timecode_source) SENSITIVE = [] include Aws::Structure end |
#flow_arn ⇒ String
The Amazon Resource Name (ARN) of the flow that is associated with the output that you want to update.
9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 9111 9112 9113 9114 9115 9116 9117 9118 9119 9120 9121 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9095 class UpdateFlowOutputRequest < Struct.new( :cidr_allow_list, :description, :destination, :encryption, :flow_arn, :max_latency, :media_stream_output_configurations, :min_latency, :output_arn, :port, :protocol, :remote_id, :sender_control_port, :sender_ip_address, :smoothing_latency, :stream_id, :vpc_interface_attachment, :output_status, :ndi_program_name, :ndi_speed_hq_quality, :router_integration_state, :router_integration_transit_encryption, :ndi_output_timecode_source) SENSITIVE = [] include Aws::Structure end |
#max_latency ⇒ Integer
The maximum latency in milliseconds. This parameter applies only to RIST-based and Zixi-based streams.
9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 9111 9112 9113 9114 9115 9116 9117 9118 9119 9120 9121 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9095 class UpdateFlowOutputRequest < Struct.new( :cidr_allow_list, :description, :destination, :encryption, :flow_arn, :max_latency, :media_stream_output_configurations, :min_latency, :output_arn, :port, :protocol, :remote_id, :sender_control_port, :sender_ip_address, :smoothing_latency, :stream_id, :vpc_interface_attachment, :output_status, :ndi_program_name, :ndi_speed_hq_quality, :router_integration_state, :router_integration_transit_encryption, :ndi_output_timecode_source) SENSITIVE = [] include Aws::Structure end |
#media_stream_output_configurations ⇒ Array<Types::MediaStreamOutputConfigurationRequest>
The media streams that are associated with the output, and the parameters for those associations.
9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 9111 9112 9113 9114 9115 9116 9117 9118 9119 9120 9121 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9095 class UpdateFlowOutputRequest < Struct.new( :cidr_allow_list, :description, :destination, :encryption, :flow_arn, :max_latency, :media_stream_output_configurations, :min_latency, :output_arn, :port, :protocol, :remote_id, :sender_control_port, :sender_ip_address, :smoothing_latency, :stream_id, :vpc_interface_attachment, :output_status, :ndi_program_name, :ndi_speed_hq_quality, :router_integration_state, :router_integration_transit_encryption, :ndi_output_timecode_source) SENSITIVE = [] include Aws::Structure end |
#min_latency ⇒ Integer
The minimum latency in milliseconds for SRT-based streams. In streams that use the SRT protocol, this value that you set on your MediaConnect source or output represents the minimal potential latency of that connection. The latency of the stream is set to the highest number between the sender’s minimum latency and the receiver’s minimum latency.
9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 9111 9112 9113 9114 9115 9116 9117 9118 9119 9120 9121 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9095 class UpdateFlowOutputRequest < Struct.new( :cidr_allow_list, :description, :destination, :encryption, :flow_arn, :max_latency, :media_stream_output_configurations, :min_latency, :output_arn, :port, :protocol, :remote_id, :sender_control_port, :sender_ip_address, :smoothing_latency, :stream_id, :vpc_interface_attachment, :output_status, :ndi_program_name, :ndi_speed_hq_quality, :router_integration_state, :router_integration_transit_encryption, :ndi_output_timecode_source) SENSITIVE = [] include Aws::Structure end |
#ndi_output_timecode_source ⇒ String
Controls how MediaConnect generates timecodes for NDI output frames. If you don’t specify this field, MediaConnect leaves the value unchanged.
-
‘EMBEDDED_TIMECODE` - Preserves timecodes from the input transport stream. The timecodes must be embedded in the video stream as SEI timing messages. If no embedded timecode is detected, MediaConnect uses the UTC system time instead.
-
‘UTC_SYSTEM_TIME` - Generates timecodes based on the system clock time when each frame is sent.
9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 9111 9112 9113 9114 9115 9116 9117 9118 9119 9120 9121 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9095 class UpdateFlowOutputRequest < Struct.new( :cidr_allow_list, :description, :destination, :encryption, :flow_arn, :max_latency, :media_stream_output_configurations, :min_latency, :output_arn, :port, :protocol, :remote_id, :sender_control_port, :sender_ip_address, :smoothing_latency, :stream_id, :vpc_interface_attachment, :output_status, :ndi_program_name, :ndi_speed_hq_quality, :router_integration_state, :router_integration_transit_encryption, :ndi_output_timecode_source) SENSITIVE = [] include Aws::Structure end |
#ndi_program_name ⇒ String
A suffix for the name of the NDI® sender that the flow creates. If a custom name isn’t specified, MediaConnect uses the output name.
9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 9111 9112 9113 9114 9115 9116 9117 9118 9119 9120 9121 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9095 class UpdateFlowOutputRequest < Struct.new( :cidr_allow_list, :description, :destination, :encryption, :flow_arn, :max_latency, :media_stream_output_configurations, :min_latency, :output_arn, :port, :protocol, :remote_id, :sender_control_port, :sender_ip_address, :smoothing_latency, :stream_id, :vpc_interface_attachment, :output_status, :ndi_program_name, :ndi_speed_hq_quality, :router_integration_state, :router_integration_transit_encryption, :ndi_output_timecode_source) SENSITIVE = [] include Aws::Structure end |
#ndi_speed_hq_quality ⇒ Integer
A quality setting for the NDI Speed HQ encoder.
9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 9111 9112 9113 9114 9115 9116 9117 9118 9119 9120 9121 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9095 class UpdateFlowOutputRequest < Struct.new( :cidr_allow_list, :description, :destination, :encryption, :flow_arn, :max_latency, :media_stream_output_configurations, :min_latency, :output_arn, :port, :protocol, :remote_id, :sender_control_port, :sender_ip_address, :smoothing_latency, :stream_id, :vpc_interface_attachment, :output_status, :ndi_program_name, :ndi_speed_hq_quality, :router_integration_state, :router_integration_transit_encryption, :ndi_output_timecode_source) SENSITIVE = [] include Aws::Structure end |
#output_arn ⇒ String
The ARN of the output that you want to update.
9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 9111 9112 9113 9114 9115 9116 9117 9118 9119 9120 9121 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9095 class UpdateFlowOutputRequest < Struct.new( :cidr_allow_list, :description, :destination, :encryption, :flow_arn, :max_latency, :media_stream_output_configurations, :min_latency, :output_arn, :port, :protocol, :remote_id, :sender_control_port, :sender_ip_address, :smoothing_latency, :stream_id, :vpc_interface_attachment, :output_status, :ndi_program_name, :ndi_speed_hq_quality, :router_integration_state, :router_integration_transit_encryption, :ndi_output_timecode_source) SENSITIVE = [] include Aws::Structure end |
#output_status ⇒ String
An indication of whether the output should transmit data or not. If you don’t specify the ‘outputStatus` field in your request, MediaConnect leaves the value unchanged.
9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 9111 9112 9113 9114 9115 9116 9117 9118 9119 9120 9121 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9095 class UpdateFlowOutputRequest < Struct.new( :cidr_allow_list, :description, :destination, :encryption, :flow_arn, :max_latency, :media_stream_output_configurations, :min_latency, :output_arn, :port, :protocol, :remote_id, :sender_control_port, :sender_ip_address, :smoothing_latency, :stream_id, :vpc_interface_attachment, :output_status, :ndi_program_name, :ndi_speed_hq_quality, :router_integration_state, :router_integration_transit_encryption, :ndi_output_timecode_source) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The port to use when content is distributed to this output.
9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 9111 9112 9113 9114 9115 9116 9117 9118 9119 9120 9121 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9095 class UpdateFlowOutputRequest < Struct.new( :cidr_allow_list, :description, :destination, :encryption, :flow_arn, :max_latency, :media_stream_output_configurations, :min_latency, :output_arn, :port, :protocol, :remote_id, :sender_control_port, :sender_ip_address, :smoothing_latency, :stream_id, :vpc_interface_attachment, :output_status, :ndi_program_name, :ndi_speed_hq_quality, :router_integration_state, :router_integration_transit_encryption, :ndi_output_timecode_source) SENSITIVE = [] include Aws::Structure end |
#protocol ⇒ String
The protocol to use for the output.
<note markdown=“1”> Elemental MediaConnect no longer supports the Fujitsu QoS protocol. This reference is maintained for legacy purposes only.
</note>
9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 9111 9112 9113 9114 9115 9116 9117 9118 9119 9120 9121 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9095 class UpdateFlowOutputRequest < Struct.new( :cidr_allow_list, :description, :destination, :encryption, :flow_arn, :max_latency, :media_stream_output_configurations, :min_latency, :output_arn, :port, :protocol, :remote_id, :sender_control_port, :sender_ip_address, :smoothing_latency, :stream_id, :vpc_interface_attachment, :output_status, :ndi_program_name, :ndi_speed_hq_quality, :router_integration_state, :router_integration_transit_encryption, :ndi_output_timecode_source) SENSITIVE = [] include Aws::Structure end |
#remote_id ⇒ String
The remote ID for the Zixi-pull stream.
9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 9111 9112 9113 9114 9115 9116 9117 9118 9119 9120 9121 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9095 class UpdateFlowOutputRequest < Struct.new( :cidr_allow_list, :description, :destination, :encryption, :flow_arn, :max_latency, :media_stream_output_configurations, :min_latency, :output_arn, :port, :protocol, :remote_id, :sender_control_port, :sender_ip_address, :smoothing_latency, :stream_id, :vpc_interface_attachment, :output_status, :ndi_program_name, :ndi_speed_hq_quality, :router_integration_state, :router_integration_transit_encryption, :ndi_output_timecode_source) SENSITIVE = [] include Aws::Structure end |
#router_integration_state ⇒ String
Indicates whether to enable or disable router integration for this flow output.
9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 9111 9112 9113 9114 9115 9116 9117 9118 9119 9120 9121 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9095 class UpdateFlowOutputRequest < Struct.new( :cidr_allow_list, :description, :destination, :encryption, :flow_arn, :max_latency, :media_stream_output_configurations, :min_latency, :output_arn, :port, :protocol, :remote_id, :sender_control_port, :sender_ip_address, :smoothing_latency, :stream_id, :vpc_interface_attachment, :output_status, :ndi_program_name, :ndi_speed_hq_quality, :router_integration_state, :router_integration_transit_encryption, :ndi_output_timecode_source) SENSITIVE = [] include Aws::Structure end |
#router_integration_transit_encryption ⇒ Types::FlowTransitEncryption
The configuration that defines how content is encrypted during transit between the MediaConnect router and a MediaConnect flow.
9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 9111 9112 9113 9114 9115 9116 9117 9118 9119 9120 9121 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9095 class UpdateFlowOutputRequest < Struct.new( :cidr_allow_list, :description, :destination, :encryption, :flow_arn, :max_latency, :media_stream_output_configurations, :min_latency, :output_arn, :port, :protocol, :remote_id, :sender_control_port, :sender_ip_address, :smoothing_latency, :stream_id, :vpc_interface_attachment, :output_status, :ndi_program_name, :ndi_speed_hq_quality, :router_integration_state, :router_integration_transit_encryption, :ndi_output_timecode_source) SENSITIVE = [] include Aws::Structure end |
#sender_control_port ⇒ Integer
The port that the flow uses to send outbound requests to initiate connection with the sender.
9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 9111 9112 9113 9114 9115 9116 9117 9118 9119 9120 9121 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9095 class UpdateFlowOutputRequest < Struct.new( :cidr_allow_list, :description, :destination, :encryption, :flow_arn, :max_latency, :media_stream_output_configurations, :min_latency, :output_arn, :port, :protocol, :remote_id, :sender_control_port, :sender_ip_address, :smoothing_latency, :stream_id, :vpc_interface_attachment, :output_status, :ndi_program_name, :ndi_speed_hq_quality, :router_integration_state, :router_integration_transit_encryption, :ndi_output_timecode_source) SENSITIVE = [] include Aws::Structure end |
#sender_ip_address ⇒ String
The IP address that the flow communicates with to initiate connection with the sender.
9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 9111 9112 9113 9114 9115 9116 9117 9118 9119 9120 9121 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9095 class UpdateFlowOutputRequest < Struct.new( :cidr_allow_list, :description, :destination, :encryption, :flow_arn, :max_latency, :media_stream_output_configurations, :min_latency, :output_arn, :port, :protocol, :remote_id, :sender_control_port, :sender_ip_address, :smoothing_latency, :stream_id, :vpc_interface_attachment, :output_status, :ndi_program_name, :ndi_speed_hq_quality, :router_integration_state, :router_integration_transit_encryption, :ndi_output_timecode_source) SENSITIVE = [] include Aws::Structure end |
#smoothing_latency ⇒ Integer
The smoothing latency in milliseconds for RIST, RTP, and RTP-FEC streams.
9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 9111 9112 9113 9114 9115 9116 9117 9118 9119 9120 9121 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9095 class UpdateFlowOutputRequest < Struct.new( :cidr_allow_list, :description, :destination, :encryption, :flow_arn, :max_latency, :media_stream_output_configurations, :min_latency, :output_arn, :port, :protocol, :remote_id, :sender_control_port, :sender_ip_address, :smoothing_latency, :stream_id, :vpc_interface_attachment, :output_status, :ndi_program_name, :ndi_speed_hq_quality, :router_integration_state, :router_integration_transit_encryption, :ndi_output_timecode_source) SENSITIVE = [] include Aws::Structure end |
#stream_id ⇒ String
The stream ID that you want to use for this transport. This parameter applies only to Zixi and SRT caller-based streams.
9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 9111 9112 9113 9114 9115 9116 9117 9118 9119 9120 9121 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9095 class UpdateFlowOutputRequest < Struct.new( :cidr_allow_list, :description, :destination, :encryption, :flow_arn, :max_latency, :media_stream_output_configurations, :min_latency, :output_arn, :port, :protocol, :remote_id, :sender_control_port, :sender_ip_address, :smoothing_latency, :stream_id, :vpc_interface_attachment, :output_status, :ndi_program_name, :ndi_speed_hq_quality, :router_integration_state, :router_integration_transit_encryption, :ndi_output_timecode_source) SENSITIVE = [] include Aws::Structure end |
#vpc_interface_attachment ⇒ Types::VpcInterfaceAttachment
The name of the VPC interface attachment to use for this output.
9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 9111 9112 9113 9114 9115 9116 9117 9118 9119 9120 9121 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9095 class UpdateFlowOutputRequest < Struct.new( :cidr_allow_list, :description, :destination, :encryption, :flow_arn, :max_latency, :media_stream_output_configurations, :min_latency, :output_arn, :port, :protocol, :remote_id, :sender_control_port, :sender_ip_address, :smoothing_latency, :stream_id, :vpc_interface_attachment, :output_status, :ndi_program_name, :ndi_speed_hq_quality, :router_integration_state, :router_integration_transit_encryption, :ndi_output_timecode_source) SENSITIVE = [] include Aws::Structure end |