Class: Aws::MediaConnect::Types::UpdateRouterOutputRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconnect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the router output that you want to update.

Returns:

  • (String)


9647
9648
9649
9650
9651
9652
9653
9654
9655
9656
9657
9658
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9647

class UpdateRouterOutputRequest < Struct.new(
  :arn,
  :name,
  :configuration,
  :maximum_bitrate,
  :routing_scope,
  :tier,
  :maintenance_configuration,
  :fabric_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#configurationTypes::RouterOutputConfiguration

The updated configuration settings for the router output. Changing the type of the configuration is not supported.



9647
9648
9649
9650
9651
9652
9653
9654
9655
9656
9657
9658
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9647

class UpdateRouterOutputRequest < Struct.new(
  :arn,
  :name,
  :configuration,
  :maximum_bitrate,
  :routing_scope,
  :tier,
  :maintenance_configuration,
  :fabric_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#fabric_configurationTypes::FabricConfiguration

The updated fabric configuration settings for the router output. You cannot update the fabric configuration while the output has an active route. You must unroute the output before updating the fabric configuration.



9647
9648
9649
9650
9651
9652
9653
9654
9655
9656
9657
9658
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9647

class UpdateRouterOutputRequest < Struct.new(
  :arn,
  :name,
  :configuration,
  :maximum_bitrate,
  :routing_scope,
  :tier,
  :maintenance_configuration,
  :fabric_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#maintenance_configurationTypes::MaintenanceConfiguration

The updated maintenance configuration settings for the router output, including any changes to preferred maintenance windows and schedules.



9647
9648
9649
9650
9651
9652
9653
9654
9655
9656
9657
9658
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9647

class UpdateRouterOutputRequest < Struct.new(
  :arn,
  :name,
  :configuration,
  :maximum_bitrate,
  :routing_scope,
  :tier,
  :maintenance_configuration,
  :fabric_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_bitrateInteger

The updated maximum bitrate for the router output.

Returns:

  • (Integer)


9647
9648
9649
9650
9651
9652
9653
9654
9655
9656
9657
9658
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9647

class UpdateRouterOutputRequest < Struct.new(
  :arn,
  :name,
  :configuration,
  :maximum_bitrate,
  :routing_scope,
  :tier,
  :maintenance_configuration,
  :fabric_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The updated name for the router output.

Returns:

  • (String)


9647
9648
9649
9650
9651
9652
9653
9654
9655
9656
9657
9658
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9647

class UpdateRouterOutputRequest < Struct.new(
  :arn,
  :name,
  :configuration,
  :maximum_bitrate,
  :routing_scope,
  :tier,
  :maintenance_configuration,
  :fabric_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#routing_scopeString

Specifies whether the router output can take inputs that are in different Regions. REGIONAL (default) - can only take inputs from same Region. GLOBAL - can take inputs from any Region.

Returns:

  • (String)


9647
9648
9649
9650
9651
9652
9653
9654
9655
9656
9657
9658
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9647

class UpdateRouterOutputRequest < Struct.new(
  :arn,
  :name,
  :configuration,
  :maximum_bitrate,
  :routing_scope,
  :tier,
  :maintenance_configuration,
  :fabric_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#tierString

The updated tier level for the router output.

Returns:

  • (String)


9647
9648
9649
9650
9651
9652
9653
9654
9655
9656
9657
9658
# File 'lib/aws-sdk-mediaconnect/types.rb', line 9647

class UpdateRouterOutputRequest < Struct.new(
  :arn,
  :name,
  :configuration,
  :maximum_bitrate,
  :routing_scope,
  :tier,
  :maintenance_configuration,
  :fabric_configuration)
  SENSITIVE = []
  include Aws::Structure
end