Class: Aws::MediaConnect::Waiters::FlowDeleted

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-mediaconnect/waiters.rb

Overview

Wait until a flow is deleted

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ FlowDeleted

Returns a new instance of FlowDeleted.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 40
  • :delay (Integer) — default: 3
  • :before_attempt (Proc)
  • :before_wait (Proc)


168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/aws-sdk-mediaconnect/waiters.rb', line 168

def initialize(options)
  @client = options.fetch(:client)
  @waiter = Aws::Waiters::Waiter.new({
    max_attempts: 40,
    delay: 3,
    poller: Aws::Waiters::Poller.new(
      operation_name: :describe_flow,
      acceptors: [
        {
          "matcher" => "error",
          "state" => "success",
          "expected" => "NotFoundException"
        },
        {
          "matcher" => "path",
          "argument" => "flow.status",
          "state" => "retry",
          "expected" => "DELETING"
        },
        {
          "matcher" => "error",
          "state" => "retry",
          "expected" => "InternalServerErrorException"
        },
        {
          "matcher" => "error",
          "state" => "retry",
          "expected" => "ServiceUnavailableException"
        },
        {
          "matcher" => "path",
          "argument" => "flow.status",
          "state" => "failure",
          "expected" => "ERROR"
        }
      ]
    )
  }.merge(options))
end

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



215
216
217
# File 'lib/aws-sdk-mediaconnect/waiters.rb', line 215

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeFlowResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :flow_arn (required, String)

    The ARN of the flow that you want to describe.

Returns:



210
211
212
# File 'lib/aws-sdk-mediaconnect/waiters.rb', line 210

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end