Class: Aws::MediaConnect::Waiters::InputStandby
- Inherits:
-
Object
- Object
- Aws::MediaConnect::Waiters::InputStandby
- Defined in:
- lib/aws-sdk-mediaconnect/waiters.rb,
sig/waiters.rbs
Overview
Wait until the Input is STANDBY
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ InputStandby
constructor
A new instance of InputStandby.
-
#wait(params = {}) ⇒ Types::GetRouterInputResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ InputStandby
Returns a new instance of InputStandby.
422 423 |
# File 'lib/aws-sdk-mediaconnect/waiters.rb', line 422
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
470 471 472 |
# File 'lib/aws-sdk-mediaconnect/waiters.rb', line 470 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetRouterInputResponse
Returns a response object which responds to the following methods:
- #router_input => Types::RouterInput
465 |
# File 'lib/aws-sdk-mediaconnect/waiters.rb', line 465
def wait: (
|