Class: Aws::MediaConnect::Waiters::OutputActive

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-mediaconnect/waiters.rb,
sig/waiters.rbs

Overview

Wait until the Output is ACTIVE

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ OutputActive

Returns a new instance of OutputActive.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 40
  • :delay (Integer) — default: 3
  • :before_attempt (Proc)
  • :before_wait (Proc)


483
484
# File 'lib/aws-sdk-mediaconnect/waiters.rb', line 483

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



543
544
545
# File 'lib/aws-sdk-mediaconnect/waiters.rb', line 543

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::GetRouterOutputResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :arn (required, String)

    The Amazon Resource Name (ARN) of the router output that you want to retrieve information about.

Returns:



538
# File 'lib/aws-sdk-mediaconnect/waiters.rb', line 538

def wait: (