Class: Aws::MediaConnect::Waiters::OutputDeleted
- Inherits:
-
Object
- Object
- Aws::MediaConnect::Waiters::OutputDeleted
- Defined in:
- lib/aws-sdk-mediaconnect/waiters.rb,
sig/waiters.rbs
Overview
Wait until the Output is deleted
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ OutputDeleted
constructor
A new instance of OutputDeleted.
-
#wait(params = {}) ⇒ Types::GetRouterOutputResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ OutputDeleted
Returns a new instance of OutputDeleted.
556 557 |
# File 'lib/aws-sdk-mediaconnect/waiters.rb', line 556
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
603 604 605 |
# File 'lib/aws-sdk-mediaconnect/waiters.rb', line 603 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetRouterOutputResponse
Returns a response object which responds to the following methods:
- #router_output => Types::RouterOutput
598 |
# File 'lib/aws-sdk-mediaconnect/waiters.rb', line 598
def wait: (
|