Class: Aws::MediaConnect::Waiters::OutputRouted

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-mediaconnect/waiters.rb

Overview

Wait until the Output is ROUTED

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ OutputRouted

Returns a new instance of OutputRouted.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 40
  • :delay (Integer) — default: 3
  • :before_attempt (Proc)
  • :before_wait (Proc)


616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
# File 'lib/aws-sdk-mediaconnect/waiters.rb', line 616

def initialize(options)
  @client = options.fetch(:client)
  @waiter = Aws::Waiters::Waiter.new({
    max_attempts: 40,
    delay: 3,
    poller: Aws::Waiters::Poller.new(
      operation_name: :get_router_output,
      acceptors: [
        {
          "matcher" => "path",
          "argument" => "router_output.routed_state",
          "state" => "success",
          "expected" => "ROUTED"
        },
        {
          "matcher" => "path",
          "argument" => "router_output.routed_state",
          "state" => "retry",
          "expected" => "ROUTING"
        },
        {
          "matcher" => "error",
          "state" => "retry",
          "expected" => "InternalServerErrorException"
        },
        {
          "matcher" => "error",
          "state" => "retry",
          "expected" => "ServiceUnavailableException"
        }
      ]
    )
  }.merge(options))
end

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



658
659
660
# File 'lib/aws-sdk-mediaconnect/waiters.rb', line 658

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::GetRouterOutputResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :arn (required, String)

    The Amazon Resource Name (ARN) of the router output that you want to retrieve information about.

Returns:



653
654
655
# File 'lib/aws-sdk-mediaconnect/waiters.rb', line 653

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end