Class: Aws::MediaConnect::Waiters::OutputStandby

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-mediaconnect/waiters.rb

Overview

Wait until the Output is STANDBY

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ OutputStandby

Returns a new instance of OutputStandby.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 40
  • :delay (Integer) — default: 3
  • :before_attempt (Proc)
  • :before_wait (Proc)


671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
# File 'lib/aws-sdk-mediaconnect/waiters.rb', line 671

def initialize(options)
  @client = options.fetch(:client)
  @waiter = Aws::Waiters::Waiter.new({
    max_attempts: 40,
    delay: 3,
    poller: Aws::Waiters::Poller.new(
      operation_name: :get_router_output,
      acceptors: [
        {
          "matcher" => "path",
          "argument" => "router_output.state",
          "state" => "success",
          "expected" => "STANDBY"
        },
        {
          "matcher" => "path",
          "argument" => "router_output.state",
          "state" => "retry",
          "expected" => "STOPPING"
        },
        {
          "matcher" => "error",
          "state" => "retry",
          "expected" => "InternalServerErrorException"
        },
        {
          "matcher" => "error",
          "state" => "retry",
          "expected" => "ServiceUnavailableException"
        },
        {
          "matcher" => "path",
          "argument" => "router_output.state",
          "state" => "failure",
          "expected" => "ERROR"
        }
      ]
    )
  }.merge(options))
end

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



719
720
721
# File 'lib/aws-sdk-mediaconnect/waiters.rb', line 719

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::GetRouterOutputResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :arn (required, String)

    The Amazon Resource Name (ARN) of the router output that you want to retrieve information about.

Returns:



714
715
716
# File 'lib/aws-sdk-mediaconnect/waiters.rb', line 714

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end