Class: Aws::MediaConnect::Waiters::OutputUnrouted

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-mediaconnect/waiters.rb

Overview

Wait until the Output is UNROUTED

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ OutputUnrouted

Returns a new instance of OutputUnrouted.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 40
  • :delay (Integer) — default: 3
  • :before_attempt (Proc)
  • :before_wait (Proc)


732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
# File 'lib/aws-sdk-mediaconnect/waiters.rb', line 732

def initialize(options)
  @client = options.fetch(:client)
  @waiter = Aws::Waiters::Waiter.new({
    max_attempts: 40,
    delay: 3,
    poller: Aws::Waiters::Poller.new(
      operation_name: :get_router_output,
      acceptors: [
        {
          "matcher" => "path",
          "argument" => "router_output.routed_state",
          "state" => "success",
          "expected" => "UNROUTED"
        },
        {
          "matcher" => "path",
          "argument" => "router_output.routed_state",
          "state" => "retry",
          "expected" => "ROUTING"
        },
        {
          "matcher" => "error",
          "state" => "retry",
          "expected" => "InternalServerErrorException"
        },
        {
          "matcher" => "error",
          "state" => "retry",
          "expected" => "ServiceUnavailableException"
        }
      ]
    )
  }.merge(options))
end

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



774
775
776
# File 'lib/aws-sdk-mediaconnect/waiters.rb', line 774

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::GetRouterOutputResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :arn (required, String)

    The Amazon Resource Name (ARN) of the router output that you want to retrieve information about.

Returns:



769
770
771
# File 'lib/aws-sdk-mediaconnect/waiters.rb', line 769

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end