Class: Aws::MediaConnect::Types::Encryption

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconnect/types.rb

Overview

Encryption information.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#algorithmString

The type of algorithm that is used for the encryption (such as aes128, aes192, or aes256).

Returns:

  • (String)


2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2303

class Encryption < Struct.new(
  :algorithm,
  :constant_initialization_vector,
  :device_id,
  :key_type,
  :region,
  :resource_id,
  :role_arn,
  :secret_arn,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#constant_initialization_vectorString

A 128-bit, 16-byte hex value represented by a 32-character string, to be used with the key for encrypting content. This parameter is not valid for static key encryption.

Returns:

  • (String)


2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2303

class Encryption < Struct.new(
  :algorithm,
  :constant_initialization_vector,
  :device_id,
  :key_type,
  :region,
  :resource_id,
  :role_arn,
  :secret_arn,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#device_idString

The value of one of the devices that you configured with your digital rights management (DRM) platform key provider. This parameter is required for SPEKE encryption and is not valid for static key encryption.

Returns:

  • (String)


2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2303

class Encryption < Struct.new(
  :algorithm,
  :constant_initialization_vector,
  :device_id,
  :key_type,
  :region,
  :resource_id,
  :role_arn,
  :secret_arn,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#key_typeString

The type of key that is used for the encryption. If no keyType is provided, the service will use the default setting (static-key).

Returns:

  • (String)


2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2303

class Encryption < Struct.new(
  :algorithm,
  :constant_initialization_vector,
  :device_id,
  :key_type,
  :region,
  :resource_id,
  :role_arn,
  :secret_arn,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#regionString

The Amazon Web Services Region that the API Gateway proxy endpoint was created in. This parameter is required for SPEKE encryption and is not valid for static key encryption.

Returns:

  • (String)


2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2303

class Encryption < Struct.new(
  :algorithm,
  :constant_initialization_vector,
  :device_id,
  :key_type,
  :region,
  :resource_id,
  :role_arn,
  :secret_arn,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#resource_idString

An identifier for the content. The service sends this value to the key server to identify the current endpoint. The resource ID is also known as the content ID. This parameter is required for SPEKE encryption and is not valid for static key encryption.

Returns:

  • (String)


2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2303

class Encryption < Struct.new(
  :algorithm,
  :constant_initialization_vector,
  :device_id,
  :key_type,
  :region,
  :resource_id,
  :role_arn,
  :secret_arn,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The ARN of the role that you created during setup (when you set up MediaConnect as a trusted entity).

Returns:

  • (String)


2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2303

class Encryption < Struct.new(
  :algorithm,
  :constant_initialization_vector,
  :device_id,
  :key_type,
  :region,
  :resource_id,
  :role_arn,
  :secret_arn,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#secret_arnString

The ARN of the secret that you created in Secrets Manager to store the encryption key. This parameter is required for static key encryption and is not valid for SPEKE encryption.

Returns:

  • (String)


2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2303

class Encryption < Struct.new(
  :algorithm,
  :constant_initialization_vector,
  :device_id,
  :key_type,
  :region,
  :resource_id,
  :role_arn,
  :secret_arn,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#urlString

The URL from the API Gateway proxy that you set up to talk to your key server. This parameter is required for SPEKE encryption and is not valid for static key encryption.

Returns:

  • (String)


2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2303

class Encryption < Struct.new(
  :algorithm,
  :constant_initialization_vector,
  :device_id,
  :key_type,
  :region,
  :resource_id,
  :role_arn,
  :secret_arn,
  :url)
  SENSITIVE = []
  include Aws::Structure
end