Class: Aws::MediaConnect::Types::Entitlement

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconnect/types.rb

Overview

The settings for a flow entitlement.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_transfer_subscriber_fee_percentInteger

Percentage from 0-100 of the data transfer cost to be billed to the subscriber.

Returns:

  • (Integer)


2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2404

class Entitlement < Struct.new(
  :data_transfer_subscriber_fee_percent,
  :description,
  :encryption,
  :entitlement_arn,
  :entitlement_status,
  :name,
  :subscribers)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the entitlement.

Returns:

  • (String)


2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2404

class Entitlement < Struct.new(
  :data_transfer_subscriber_fee_percent,
  :description,
  :encryption,
  :entitlement_arn,
  :entitlement_status,
  :name,
  :subscribers)
  SENSITIVE = []
  include Aws::Structure
end

#encryptionTypes::Encryption

The type of encryption that will be used on the output that is associated with this entitlement.

Returns:



2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2404

class Entitlement < Struct.new(
  :data_transfer_subscriber_fee_percent,
  :description,
  :encryption,
  :entitlement_arn,
  :entitlement_status,
  :name,
  :subscribers)
  SENSITIVE = []
  include Aws::Structure
end

#entitlement_arnString

The ARN of the entitlement.

Returns:

  • (String)


2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2404

class Entitlement < Struct.new(
  :data_transfer_subscriber_fee_percent,
  :description,
  :encryption,
  :entitlement_arn,
  :entitlement_status,
  :name,
  :subscribers)
  SENSITIVE = []
  include Aws::Structure
end

#entitlement_statusString

An indication of whether the entitlement is enabled.

Returns:

  • (String)


2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2404

class Entitlement < Struct.new(
  :data_transfer_subscriber_fee_percent,
  :description,
  :encryption,
  :entitlement_arn,
  :entitlement_status,
  :name,
  :subscribers)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the entitlement.

Returns:

  • (String)


2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2404

class Entitlement < Struct.new(
  :data_transfer_subscriber_fee_percent,
  :description,
  :encryption,
  :entitlement_arn,
  :entitlement_status,
  :name,
  :subscribers)
  SENSITIVE = []
  include Aws::Structure
end

#subscribersArray<String>

The Amazon Web Services account IDs that you want to share your content with. The receiving accounts (subscribers) will be allowed to create their own flow using your content as the source.

Returns:

  • (Array<String>)


2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2404

class Entitlement < Struct.new(
  :data_transfer_subscriber_fee_percent,
  :description,
  :encryption,
  :entitlement_arn,
  :entitlement_status,
  :name,
  :subscribers)
  SENSITIVE = []
  include Aws::Structure
end