Class: Aws::MediaConnect::Types::Entitlement
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::Entitlement
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
The settings for a flow entitlement.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_transfer_subscriber_fee_percent ⇒ Integer
Percentage from 0-100 of the data transfer cost to be billed to the subscriber.
-
#description ⇒ String
A description of the entitlement.
-
#encryption ⇒ Types::Encryption
The type of encryption that will be used on the output that is associated with this entitlement.
-
#entitlement_arn ⇒ String
The ARN of the entitlement.
-
#entitlement_status ⇒ String
An indication of whether the entitlement is enabled.
-
#name ⇒ String
The name of the entitlement.
-
#subscribers ⇒ Array<String>
The Amazon Web Services account IDs that you want to share your content with.
Instance Attribute Details
#data_transfer_subscriber_fee_percent ⇒ Integer
Percentage from 0-100 of the data transfer cost to be billed to the subscriber.
2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2353 class Entitlement < Struct.new( :data_transfer_subscriber_fee_percent, :description, :encryption, :entitlement_arn, :entitlement_status, :name, :subscribers) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the entitlement.
2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2353 class Entitlement < Struct.new( :data_transfer_subscriber_fee_percent, :description, :encryption, :entitlement_arn, :entitlement_status, :name, :subscribers) SENSITIVE = [] include Aws::Structure end |
#encryption ⇒ Types::Encryption
The type of encryption that will be used on the output that is associated with this entitlement.
2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2353 class Entitlement < Struct.new( :data_transfer_subscriber_fee_percent, :description, :encryption, :entitlement_arn, :entitlement_status, :name, :subscribers) SENSITIVE = [] include Aws::Structure end |
#entitlement_arn ⇒ String
The ARN of the entitlement.
2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2353 class Entitlement < Struct.new( :data_transfer_subscriber_fee_percent, :description, :encryption, :entitlement_arn, :entitlement_status, :name, :subscribers) SENSITIVE = [] include Aws::Structure end |
#entitlement_status ⇒ String
An indication of whether the entitlement is enabled.
2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2353 class Entitlement < Struct.new( :data_transfer_subscriber_fee_percent, :description, :encryption, :entitlement_arn, :entitlement_status, :name, :subscribers) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the entitlement.
2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2353 class Entitlement < Struct.new( :data_transfer_subscriber_fee_percent, :description, :encryption, :entitlement_arn, :entitlement_status, :name, :subscribers) SENSITIVE = [] include Aws::Structure end |
#subscribers ⇒ Array<String>
The Amazon Web Services account IDs that you want to share your content with. The receiving accounts (subscribers) will be allowed to create their own flow using your content as the source.
2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2353 class Entitlement < Struct.new( :data_transfer_subscriber_fee_percent, :description, :encryption, :entitlement_arn, :entitlement_status, :name, :subscribers) SENSITIVE = [] include Aws::Structure end |