Class: Aws::MediaConnect::Types::FrozenFramesConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::FrozenFramesConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
Detects frozen video frames in the router input's source content and reports them through a CloudWatch metric, an EventBridge event, and a router input message.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#state ⇒ String
Indicates whether frozen frames detection is enabled or disabled.
-
#threshold_seconds ⇒ Integer
The number of consecutive seconds of a frozen frame that MediaConnect must detect before it reports an issue.
Instance Attribute Details
#state ⇒ String
Indicates whether frozen frames detection is enabled or disabled.
2923 2924 2925 2926 2927 2928 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2923 class FrozenFramesConfiguration < Struct.new( :state, :threshold_seconds) SENSITIVE = [] include Aws::Structure end |
#threshold_seconds ⇒ Integer
The number of consecutive seconds of a frozen frame that MediaConnect must detect before it reports an issue.
2923 2924 2925 2926 2927 2928 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2923 class FrozenFramesConfiguration < Struct.new( :state, :threshold_seconds) SENSITIVE = [] include Aws::Structure end |