Class: Aws::MediaConnect::Types::FrozenFramesConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconnect/types.rb

Overview

Detects frozen video frames in the router input’s source content and reports them through a CloudWatch metric, an EventBridge event, and a router input message.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#stateString

Indicates whether frozen frames detection is enabled or disabled.

Returns:

  • (String)


2898
2899
2900
2901
2902
2903
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2898

class FrozenFramesConfiguration < Struct.new(
  :state,
  :threshold_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#threshold_secondsInteger

The number of consecutive seconds of a frozen frame that MediaConnect must detect before it reports an issue.

Returns:

  • (Integer)


2898
2899
2900
2901
2902
2903
# File 'lib/aws-sdk-mediaconnect/types.rb', line 2898

class FrozenFramesConfiguration < Struct.new(
  :state,
  :threshold_seconds)
  SENSITIVE = []
  include Aws::Structure
end