Class: Aws::MediaConnect::Types::GatewayInstance
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::GatewayInstance
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
The settings for an instance in a gateway.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bridge_placement ⇒ String
The availability of the instance to host new bridges.
-
#connection_status ⇒ String
The connection state of the instance.
-
#gateway_arn ⇒ String
The Amazon Resource Name (ARN) of the instance.
-
#gateway_instance_arn ⇒ String
The ARN of the gateway.
-
#instance_id ⇒ String
The instance ID generated by the SSM install.
-
#instance_messages ⇒ Array<Types::MessageDetail>
Messages with information about the gateway.
-
#instance_state ⇒ String
The status of the instance.
-
#running_bridge_count ⇒ Integer
The running bridge count.
Instance Attribute Details
#bridge_placement ⇒ String
The availability of the instance to host new bridges. The bridgePlacement property can be LOCKED or AVAILABLE. If it is LOCKED, no new bridges can be deployed to this instance. If it is AVAILABLE, new bridges can be deployed to this instance.
3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3009 class GatewayInstance < Struct.new( :bridge_placement, :connection_status, :gateway_arn, :gateway_instance_arn, :instance_id, :instance_messages, :instance_state, :running_bridge_count) SENSITIVE = [] include Aws::Structure end |
#connection_status ⇒ String
The connection state of the instance.
3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3009 class GatewayInstance < Struct.new( :bridge_placement, :connection_status, :gateway_arn, :gateway_instance_arn, :instance_id, :instance_messages, :instance_state, :running_bridge_count) SENSITIVE = [] include Aws::Structure end |
#gateway_arn ⇒ String
The Amazon Resource Name (ARN) of the instance.
3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3009 class GatewayInstance < Struct.new( :bridge_placement, :connection_status, :gateway_arn, :gateway_instance_arn, :instance_id, :instance_messages, :instance_state, :running_bridge_count) SENSITIVE = [] include Aws::Structure end |
#gateway_instance_arn ⇒ String
The ARN of the gateway.
3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3009 class GatewayInstance < Struct.new( :bridge_placement, :connection_status, :gateway_arn, :gateway_instance_arn, :instance_id, :instance_messages, :instance_state, :running_bridge_count) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The instance ID generated by the SSM install. This will begin with “mi-”.
3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3009 class GatewayInstance < Struct.new( :bridge_placement, :connection_status, :gateway_arn, :gateway_instance_arn, :instance_id, :instance_messages, :instance_state, :running_bridge_count) SENSITIVE = [] include Aws::Structure end |
#instance_messages ⇒ Array<Types::MessageDetail>
Messages with information about the gateway.
3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3009 class GatewayInstance < Struct.new( :bridge_placement, :connection_status, :gateway_arn, :gateway_instance_arn, :instance_id, :instance_messages, :instance_state, :running_bridge_count) SENSITIVE = [] include Aws::Structure end |
#instance_state ⇒ String
The status of the instance.
3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3009 class GatewayInstance < Struct.new( :bridge_placement, :connection_status, :gateway_arn, :gateway_instance_arn, :instance_id, :instance_messages, :instance_state, :running_bridge_count) SENSITIVE = [] include Aws::Structure end |
#running_bridge_count ⇒ Integer
The running bridge count.
3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3009 class GatewayInstance < Struct.new( :bridge_placement, :connection_status, :gateway_arn, :gateway_instance_arn, :instance_id, :instance_messages, :instance_state, :running_bridge_count) SENSITIVE = [] include Aws::Structure end |