Class: Aws::MediaConnect::Types::ListBridgesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::ListBridgesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bridges ⇒ Array<Types::ListedBridge>
A list of bridge summaries.
-
#next_token ⇒ String
The token that identifies the batch of results that you want to see.
Instance Attribute Details
#bridges ⇒ Array<Types::ListedBridge>
A list of bridge summaries.
3499 3500 3501 3502 3503 3504 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3499 class ListBridgesResponse < Struct.new( :bridges, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token that identifies the batch of results that you want to see.
For example, you submit a ListBridges request with MaxResults
set at 5. The service returns the first batch of results (up to 5)
and a NextToken value. To see the next batch of results, you can
submit the ListBridges request a second time and specify the
NextToken value.
3499 3500 3501 3502 3503 3504 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3499 class ListBridgesResponse < Struct.new( :bridges, :next_token) SENSITIVE = [] include Aws::Structure end |