Class: Aws::MediaConnect::Types::ListGatewayInstancesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::ListGatewayInstancesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instances ⇒ Array<Types::ListedGatewayInstance>
A list of instance summaries.
-
#next_token ⇒ String
The token that identifies the batch of results that you want to see.
Instance Attribute Details
#instances ⇒ Array<Types::ListedGatewayInstance>
A list of instance summaries.
3672 3673 3674 3675 3676 3677 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3672 class ListGatewayInstancesResponse < Struct.new( :instances, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token that identifies the batch of results that you want to see.
For example, you submit a ListInstances request with MaxResults
set at 5. The service returns the first batch of results (up to 5)
and a NextToken value. To see the next batch of results, you can
submit the ListInstances request a second time and specify the
NextToken value.
3672 3673 3674 3675 3676 3677 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 3672 class ListGatewayInstancesResponse < Struct.new( :instances, :next_token) SENSITIVE = [] include Aws::Structure end |