Class: Aws::MediaConnect::Types::MediaStreamSourceConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::MediaStreamSourceConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
The media stream that you want to associate with the source, and the parameters for that association.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#encoding_name ⇒ String
The format that was used to encode the data.
-
#input_configurations ⇒ Array<Types::InputConfigurationRequest>
The media streams that you want to associate with the source.
-
#media_stream_name ⇒ String
The name of the media stream.
Instance Attribute Details
#encoding_name ⇒ String
The format that was used to encode the data. For ancillary data streams, set the encoding name to smpte291. For audio streams, set the encoding name to pcm. For video, 2110 streams, set the encoding name to raw. For video, JPEG XS streams, set the encoding name to jxsv.
4933 4934 4935 4936 4937 4938 4939 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 4933 class MediaStreamSourceConfigurationRequest < Struct.new( :encoding_name, :input_configurations, :media_stream_name) SENSITIVE = [] include Aws::Structure end |
#input_configurations ⇒ Array<Types::InputConfigurationRequest>
The media streams that you want to associate with the source.
4933 4934 4935 4936 4937 4938 4939 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 4933 class MediaStreamSourceConfigurationRequest < Struct.new( :encoding_name, :input_configurations, :media_stream_name) SENSITIVE = [] include Aws::Structure end |
#media_stream_name ⇒ String
The name of the media stream.
4933 4934 4935 4936 4937 4938 4939 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 4933 class MediaStreamSourceConfigurationRequest < Struct.new( :encoding_name, :input_configurations, :media_stream_name) SENSITIVE = [] include Aws::Structure end |