Class: Aws::MediaConnect::Types::NdiMediaInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconnect/types.rb

Overview

Metadata about the audio and video media that is part of the NDI®source content. This includes details about the individual media streams.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#streamsArray<Types::NdiMediaStreamInfo>

A list of the individual media streams that make up the NDI source. This includes details about each stream’s codec, resolution, frame rate, audio channels, and other parameters.

Returns:



5085
5086
5087
5088
5089
# File 'lib/aws-sdk-mediaconnect/types.rb', line 5085

class NdiMediaInfo < Struct.new(
  :streams)
  SENSITIVE = []
  include Aws::Structure
end