Class: Aws::MediaConnect::Types::NdiMediaStreamInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::NdiMediaStreamInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
Detailed information about a single media stream that is part of an NDI® source. This includes details about the stream type, codec, resolution, frame rate, audio channels, and sample rate.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channels ⇒ Integer
The number of audio channels in the stream.
-
#codec ⇒ String
The codec used for the media stream.
-
#frame_rate ⇒ String
The number of video frames displayed per second.
-
#frame_resolution ⇒ Types::FrameResolution
The width and height dimensions of the video frame in pixels.
-
#sample_rate ⇒ Integer
The number of audio samples captured per second, measured in kilohertz (kHz).
-
#scan_mode ⇒ String
The method used to display video frames.
-
#stream_id ⇒ Integer
A unique identifier for the media stream.
-
#stream_type ⇒ String
The type of media stream (for example, ‘Video` or `Audio`).
Instance Attribute Details
#channels ⇒ Integer
The number of audio channels in the stream. Used when the ‘streamType` is `Audio`.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 5135 class NdiMediaStreamInfo < Struct.new( :stream_type, :codec, :stream_id, :scan_mode, :frame_resolution, :frame_rate, :channels, :sample_rate) SENSITIVE = [] include Aws::Structure end |
#codec ⇒ String
The codec used for the media stream. For NDI sources, use ‘speed-hq`.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 5135 class NdiMediaStreamInfo < Struct.new( :stream_type, :codec, :stream_id, :scan_mode, :frame_resolution, :frame_rate, :channels, :sample_rate) SENSITIVE = [] include Aws::Structure end |
#frame_rate ⇒ String
The number of video frames displayed per second. Used when the ‘streamType` is `Video`.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 5135 class NdiMediaStreamInfo < Struct.new( :stream_type, :codec, :stream_id, :scan_mode, :frame_resolution, :frame_rate, :channels, :sample_rate) SENSITIVE = [] include Aws::Structure end |
#frame_resolution ⇒ Types::FrameResolution
The width and height dimensions of the video frame in pixels. Used when the ‘streamType` is `Video`.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 5135 class NdiMediaStreamInfo < Struct.new( :stream_type, :codec, :stream_id, :scan_mode, :frame_resolution, :frame_rate, :channels, :sample_rate) SENSITIVE = [] include Aws::Structure end |
#sample_rate ⇒ Integer
The number of audio samples captured per second, measured in kilohertz (kHz). Used when the ‘streamType` is `Audio`.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 5135 class NdiMediaStreamInfo < Struct.new( :stream_type, :codec, :stream_id, :scan_mode, :frame_resolution, :frame_rate, :channels, :sample_rate) SENSITIVE = [] include Aws::Structure end |
#scan_mode ⇒ String
The method used to display video frames. Used when the ‘streamType` is `Video`.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 5135 class NdiMediaStreamInfo < Struct.new( :stream_type, :codec, :stream_id, :scan_mode, :frame_resolution, :frame_rate, :channels, :sample_rate) SENSITIVE = [] include Aws::Structure end |
#stream_id ⇒ Integer
A unique identifier for the media stream.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 5135 class NdiMediaStreamInfo < Struct.new( :stream_type, :codec, :stream_id, :scan_mode, :frame_resolution, :frame_rate, :channels, :sample_rate) SENSITIVE = [] include Aws::Structure end |
#stream_type ⇒ String
The type of media stream (for example, ‘Video` or `Audio`).
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 5135 class NdiMediaStreamInfo < Struct.new( :stream_type, :codec, :stream_id, :scan_mode, :frame_resolution, :frame_rate, :channels, :sample_rate) SENSITIVE = [] include Aws::Structure end |