Class: Aws::MediaConnect::Types::NdiSourceSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconnect/types.rb

Overview

The settings for the NDI® source. This includes the exact name of the upstream NDI sender that you want to connect to your source.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#source_nameString

The exact name of an existing NDI sender that’s registered with your discovery server. If included, the format of this name must be ‘MACHINENAME (ProgramName)`.

Returns:

  • (String)


5224
5225
5226
5227
5228
# File 'lib/aws-sdk-mediaconnect/types.rb', line 5224

class NdiSourceSettings < Struct.new(
  :source_name)
  SENSITIVE = []
  include Aws::Structure
end