Class: Aws::MediaConnect::Types::RouterInputProtocolConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConnect::Types::RouterInputProtocolConfiguration
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-mediaconnect/types.rb
Overview
RouterInputProtocolConfiguration is a union - when making an API calls you must set exactly one of the members.
RouterInputProtocolConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of RouterInputProtocolConfiguration corresponding to the set member.
The protocol configuration settings for a router input.
Direct Known Subclasses
Defined Under Namespace
Classes: Rist, Rtp, SrtCaller, SrtListener, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#rist ⇒ Types::RistRouterInputConfiguration
The configuration settings for a router input using the RIST (Reliable Internet Stream Transport) protocol, including the port and recovery latency.
-
#rtp ⇒ Types::RtpRouterInputConfiguration
The configuration settings for a Router Input using the RTP (Real-Time Transport Protocol) protocol, including the port and forward error correction state.
-
#srt_caller ⇒ Types::SrtCallerRouterInputConfiguration
The configuration settings for a router input using the SRT (Secure Reliable Transport) protocol in caller mode, including the source address and port, minimum latency, stream ID, and decryption key configuration.
-
#srt_listener ⇒ Types::SrtListenerRouterInputConfiguration
The configuration settings for a router input using the SRT (Secure Reliable Transport) protocol in listener mode, including the port, minimum latency, and decryption key configuration.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#rist ⇒ Types::RistRouterInputConfiguration
The configuration settings for a router input using the RIST (Reliable Internet Stream Transport) protocol, including the port and recovery latency.
6437 6438 6439 6440 6441 6442 6443 6444 6445 6446 6447 6448 6449 6450 6451 6452 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6437 class RouterInputProtocolConfiguration < Struct.new( :rist, :srt_listener, :srt_caller, :rtp, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Rist < RouterInputProtocolConfiguration; end class SrtListener < RouterInputProtocolConfiguration; end class SrtCaller < RouterInputProtocolConfiguration; end class Rtp < RouterInputProtocolConfiguration; end class Unknown < RouterInputProtocolConfiguration; end end |
#rtp ⇒ Types::RtpRouterInputConfiguration
The configuration settings for a Router Input using the RTP (Real-Time Transport Protocol) protocol, including the port and forward error correction state.
6437 6438 6439 6440 6441 6442 6443 6444 6445 6446 6447 6448 6449 6450 6451 6452 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6437 class RouterInputProtocolConfiguration < Struct.new( :rist, :srt_listener, :srt_caller, :rtp, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Rist < RouterInputProtocolConfiguration; end class SrtListener < RouterInputProtocolConfiguration; end class SrtCaller < RouterInputProtocolConfiguration; end class Rtp < RouterInputProtocolConfiguration; end class Unknown < RouterInputProtocolConfiguration; end end |
#srt_caller ⇒ Types::SrtCallerRouterInputConfiguration
The configuration settings for a router input using the SRT (Secure Reliable Transport) protocol in caller mode, including the source address and port, minimum latency, stream ID, and decryption key configuration.
6437 6438 6439 6440 6441 6442 6443 6444 6445 6446 6447 6448 6449 6450 6451 6452 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6437 class RouterInputProtocolConfiguration < Struct.new( :rist, :srt_listener, :srt_caller, :rtp, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Rist < RouterInputProtocolConfiguration; end class SrtListener < RouterInputProtocolConfiguration; end class SrtCaller < RouterInputProtocolConfiguration; end class Rtp < RouterInputProtocolConfiguration; end class Unknown < RouterInputProtocolConfiguration; end end |
#srt_listener ⇒ Types::SrtListenerRouterInputConfiguration
The configuration settings for a router input using the SRT (Secure Reliable Transport) protocol in listener mode, including the port, minimum latency, and decryption key configuration.
6437 6438 6439 6440 6441 6442 6443 6444 6445 6446 6447 6448 6449 6450 6451 6452 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6437 class RouterInputProtocolConfiguration < Struct.new( :rist, :srt_listener, :srt_caller, :rtp, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Rist < RouterInputProtocolConfiguration; end class SrtListener < RouterInputProtocolConfiguration; end class SrtCaller < RouterInputProtocolConfiguration; end class Rtp < RouterInputProtocolConfiguration; end class Unknown < RouterInputProtocolConfiguration; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
6437 6438 6439 |
# File 'lib/aws-sdk-mediaconnect/types.rb', line 6437 def unknown @unknown end |