Class: Aws::MediaConnect::Types::RouterOutputProtocolConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-mediaconnect/types.rb

Overview

Note:

RouterOutputProtocolConfiguration is a union - when making an API calls you must set exactly one of the members.

Note:

RouterOutputProtocolConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of RouterOutputProtocolConfiguration corresponding to the set member.

The protocol configuration settings for a router output.

Direct Known Subclasses

Rist, Rtp, SrtCaller, SrtListener, Unknown

Defined Under Namespace

Classes: Rist, Rtp, SrtCaller, SrtListener, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ristTypes::RistRouterOutputConfiguration

The configuration settings for a router output using the RIST (Reliable Internet Stream Transport) protocol, including the destination address and port.



7057
7058
7059
7060
7061
7062
7063
7064
7065
7066
7067
7068
7069
7070
7071
7072
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7057

class RouterOutputProtocolConfiguration < Struct.new(
  :rist,
  :srt_listener,
  :srt_caller,
  :rtp,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Rist < RouterOutputProtocolConfiguration; end
  class SrtListener < RouterOutputProtocolConfiguration; end
  class SrtCaller < RouterOutputProtocolConfiguration; end
  class Rtp < RouterOutputProtocolConfiguration; end
  class Unknown < RouterOutputProtocolConfiguration; end
end

#rtpTypes::RtpRouterOutputConfiguration

The configuration settings for a router output using the RTP (Real-Time Transport Protocol) protocol, including the destination address and port, and forward error correction state.



7057
7058
7059
7060
7061
7062
7063
7064
7065
7066
7067
7068
7069
7070
7071
7072
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7057

class RouterOutputProtocolConfiguration < Struct.new(
  :rist,
  :srt_listener,
  :srt_caller,
  :rtp,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Rist < RouterOutputProtocolConfiguration; end
  class SrtListener < RouterOutputProtocolConfiguration; end
  class SrtCaller < RouterOutputProtocolConfiguration; end
  class Rtp < RouterOutputProtocolConfiguration; end
  class Unknown < RouterOutputProtocolConfiguration; end
end

#srt_callerTypes::SrtCallerRouterOutputConfiguration

The configuration settings for a router output using the SRT (Secure Reliable Transport) protocol in caller mode, including the destination address and port, minimum latency, stream ID, and encryption key configuration.



7057
7058
7059
7060
7061
7062
7063
7064
7065
7066
7067
7068
7069
7070
7071
7072
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7057

class RouterOutputProtocolConfiguration < Struct.new(
  :rist,
  :srt_listener,
  :srt_caller,
  :rtp,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Rist < RouterOutputProtocolConfiguration; end
  class SrtListener < RouterOutputProtocolConfiguration; end
  class SrtCaller < RouterOutputProtocolConfiguration; end
  class Rtp < RouterOutputProtocolConfiguration; end
  class Unknown < RouterOutputProtocolConfiguration; end
end

#srt_listenerTypes::SrtListenerRouterOutputConfiguration

The configuration settings for a router output using the SRT (Secure Reliable Transport) protocol in listener mode, including the port, minimum latency, and encryption key configuration.



7057
7058
7059
7060
7061
7062
7063
7064
7065
7066
7067
7068
7069
7070
7071
7072
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7057

class RouterOutputProtocolConfiguration < Struct.new(
  :rist,
  :srt_listener,
  :srt_caller,
  :rtp,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Rist < RouterOutputProtocolConfiguration; end
  class SrtListener < RouterOutputProtocolConfiguration; end
  class SrtCaller < RouterOutputProtocolConfiguration; end
  class Rtp < RouterOutputProtocolConfiguration; end
  class Unknown < RouterOutputProtocolConfiguration; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



7057
7058
7059
# File 'lib/aws-sdk-mediaconnect/types.rb', line 7057

def unknown
  @unknown
end