Class: Aws::MediaConnect::Types::Transport

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconnect/types.rb

Overview

Attributes related to the transport stream that are used in a source or output.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cidr_allow_listArray<String>

The range of IP addresses that should be allowed to initiate output requests to this flow. These IP addresses should be in the form of a Classless Inter-Domain Routing (CIDR) block; for example, 10.0.0.0/16

Returns:

  • (Array<String>)


8166
8167
8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
8180
8181
8182
8183
8184
8185
8186
# File 'lib/aws-sdk-mediaconnect/types.rb', line 8166

class Transport < Struct.new(
  :cidr_allow_list,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :min_latency,
  :protocol,
  :remote_id,
  :sender_control_port,
  :sender_ip_address,
  :smoothing_latency,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :ndi_speed_hq_quality,
  :ndi_program_name,
  :ndi_source_settings,
  :ndi_output_timecode_source)
  SENSITIVE = []
  include Aws::Structure
end

#max_bitrateInteger

The smoothing max bitrate (in bps) for RIST, RTP, and RTP-FEC streams.

Returns:

  • (Integer)


8166
8167
8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
8180
8181
8182
8183
8184
8185
8186
# File 'lib/aws-sdk-mediaconnect/types.rb', line 8166

class Transport < Struct.new(
  :cidr_allow_list,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :min_latency,
  :protocol,
  :remote_id,
  :sender_control_port,
  :sender_ip_address,
  :smoothing_latency,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :ndi_speed_hq_quality,
  :ndi_program_name,
  :ndi_source_settings,
  :ndi_output_timecode_source)
  SENSITIVE = []
  include Aws::Structure
end

#max_latencyInteger

The maximum latency in milliseconds. This parameter applies only to RIST-based and Zixi-based streams.

Returns:

  • (Integer)


8166
8167
8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
8180
8181
8182
8183
8184
8185
8186
# File 'lib/aws-sdk-mediaconnect/types.rb', line 8166

class Transport < Struct.new(
  :cidr_allow_list,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :min_latency,
  :protocol,
  :remote_id,
  :sender_control_port,
  :sender_ip_address,
  :smoothing_latency,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :ndi_speed_hq_quality,
  :ndi_program_name,
  :ndi_source_settings,
  :ndi_output_timecode_source)
  SENSITIVE = []
  include Aws::Structure
end

#max_sync_bufferInteger

The size of the buffer (in milliseconds) to use to sync incoming source data.

Returns:

  • (Integer)


8166
8167
8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
8180
8181
8182
8183
8184
8185
8186
# File 'lib/aws-sdk-mediaconnect/types.rb', line 8166

class Transport < Struct.new(
  :cidr_allow_list,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :min_latency,
  :protocol,
  :remote_id,
  :sender_control_port,
  :sender_ip_address,
  :smoothing_latency,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :ndi_speed_hq_quality,
  :ndi_program_name,
  :ndi_source_settings,
  :ndi_output_timecode_source)
  SENSITIVE = []
  include Aws::Structure
end

#min_latencyInteger

The minimum latency in milliseconds for SRT-based streams. In streams that use the SRT protocol, this value that you set on your MediaConnect source or output represents the minimal potential latency of that connection. The latency of the stream is set to the highest number between the sender’s minimum latency and the receiver’s minimum latency.

Returns:

  • (Integer)


8166
8167
8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
8180
8181
8182
8183
8184
8185
8186
# File 'lib/aws-sdk-mediaconnect/types.rb', line 8166

class Transport < Struct.new(
  :cidr_allow_list,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :min_latency,
  :protocol,
  :remote_id,
  :sender_control_port,
  :sender_ip_address,
  :smoothing_latency,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :ndi_speed_hq_quality,
  :ndi_program_name,
  :ndi_source_settings,
  :ndi_output_timecode_source)
  SENSITIVE = []
  include Aws::Structure
end

#ndi_output_timecode_sourceString

The timecode source for NDI output frames. For NDI outputs, this field is always present and defaults to ‘EMBEDDED_TIMECODE`.

  • ‘EMBEDDED_TIMECODE` - Preserves timecodes from the input transport stream. The timecodes must be embedded in the video stream as SEI timing messages. If no embedded timecode is detected, MediaConnect uses the UTC system time instead.

  • ‘UTC_SYSTEM_TIME` - Generates timecodes based on the system clock time when each frame is sent.

Returns:

  • (String)


8166
8167
8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
8180
8181
8182
8183
8184
8185
8186
# File 'lib/aws-sdk-mediaconnect/types.rb', line 8166

class Transport < Struct.new(
  :cidr_allow_list,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :min_latency,
  :protocol,
  :remote_id,
  :sender_control_port,
  :sender_ip_address,
  :smoothing_latency,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :ndi_speed_hq_quality,
  :ndi_program_name,
  :ndi_source_settings,
  :ndi_output_timecode_source)
  SENSITIVE = []
  include Aws::Structure
end

#ndi_program_nameString

A suffix for the name of the NDI® sender that the flow creates. If a custom name isn’t specified, MediaConnect uses the output name.

Returns:

  • (String)


8166
8167
8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
8180
8181
8182
8183
8184
8185
8186
# File 'lib/aws-sdk-mediaconnect/types.rb', line 8166

class Transport < Struct.new(
  :cidr_allow_list,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :min_latency,
  :protocol,
  :remote_id,
  :sender_control_port,
  :sender_ip_address,
  :smoothing_latency,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :ndi_speed_hq_quality,
  :ndi_program_name,
  :ndi_source_settings,
  :ndi_output_timecode_source)
  SENSITIVE = []
  include Aws::Structure
end

#ndi_source_settingsTypes::NdiSourceSettings

The settings for the NDI source. This includes the exact name of the upstream NDI sender that you want to connect to your source.



8166
8167
8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
8180
8181
8182
8183
8184
8185
8186
# File 'lib/aws-sdk-mediaconnect/types.rb', line 8166

class Transport < Struct.new(
  :cidr_allow_list,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :min_latency,
  :protocol,
  :remote_id,
  :sender_control_port,
  :sender_ip_address,
  :smoothing_latency,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :ndi_speed_hq_quality,
  :ndi_program_name,
  :ndi_source_settings,
  :ndi_output_timecode_source)
  SENSITIVE = []
  include Aws::Structure
end

#ndi_speed_hq_qualityInteger

A quality setting for the NDI Speed HQ encoder.

Returns:

  • (Integer)


8166
8167
8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
8180
8181
8182
8183
8184
8185
8186
# File 'lib/aws-sdk-mediaconnect/types.rb', line 8166

class Transport < Struct.new(
  :cidr_allow_list,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :min_latency,
  :protocol,
  :remote_id,
  :sender_control_port,
  :sender_ip_address,
  :smoothing_latency,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :ndi_speed_hq_quality,
  :ndi_program_name,
  :ndi_source_settings,
  :ndi_output_timecode_source)
  SENSITIVE = []
  include Aws::Structure
end

#protocolString

The protocol that is used by the source or output.

<note markdown=“1”> Elemental MediaConnect no longer supports the Fujitsu QoS protocol. This reference is maintained for legacy purposes only.

</note>

Returns:

  • (String)


8166
8167
8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
8180
8181
8182
8183
8184
8185
8186
# File 'lib/aws-sdk-mediaconnect/types.rb', line 8166

class Transport < Struct.new(
  :cidr_allow_list,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :min_latency,
  :protocol,
  :remote_id,
  :sender_control_port,
  :sender_ip_address,
  :smoothing_latency,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :ndi_speed_hq_quality,
  :ndi_program_name,
  :ndi_source_settings,
  :ndi_output_timecode_source)
  SENSITIVE = []
  include Aws::Structure
end

#remote_idString

The remote ID for the Zixi-pull stream.

Returns:

  • (String)


8166
8167
8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
8180
8181
8182
8183
8184
8185
8186
# File 'lib/aws-sdk-mediaconnect/types.rb', line 8166

class Transport < Struct.new(
  :cidr_allow_list,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :min_latency,
  :protocol,
  :remote_id,
  :sender_control_port,
  :sender_ip_address,
  :smoothing_latency,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :ndi_speed_hq_quality,
  :ndi_program_name,
  :ndi_source_settings,
  :ndi_output_timecode_source)
  SENSITIVE = []
  include Aws::Structure
end

#sender_control_portInteger

The port that the flow uses to send outbound requests to initiate connection with the sender.

Returns:

  • (Integer)


8166
8167
8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
8180
8181
8182
8183
8184
8185
8186
# File 'lib/aws-sdk-mediaconnect/types.rb', line 8166

class Transport < Struct.new(
  :cidr_allow_list,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :min_latency,
  :protocol,
  :remote_id,
  :sender_control_port,
  :sender_ip_address,
  :smoothing_latency,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :ndi_speed_hq_quality,
  :ndi_program_name,
  :ndi_source_settings,
  :ndi_output_timecode_source)
  SENSITIVE = []
  include Aws::Structure
end

#sender_ip_addressString

The IP address that the flow communicates with to initiate connection with the sender.

Returns:

  • (String)


8166
8167
8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
8180
8181
8182
8183
8184
8185
8186
# File 'lib/aws-sdk-mediaconnect/types.rb', line 8166

class Transport < Struct.new(
  :cidr_allow_list,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :min_latency,
  :protocol,
  :remote_id,
  :sender_control_port,
  :sender_ip_address,
  :smoothing_latency,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :ndi_speed_hq_quality,
  :ndi_program_name,
  :ndi_source_settings,
  :ndi_output_timecode_source)
  SENSITIVE = []
  include Aws::Structure
end

#smoothing_latencyInteger

The smoothing latency in milliseconds for RIST, RTP, and RTP-FEC streams.

Returns:

  • (Integer)


8166
8167
8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
8180
8181
8182
8183
8184
8185
8186
# File 'lib/aws-sdk-mediaconnect/types.rb', line 8166

class Transport < Struct.new(
  :cidr_allow_list,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :min_latency,
  :protocol,
  :remote_id,
  :sender_control_port,
  :sender_ip_address,
  :smoothing_latency,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :ndi_speed_hq_quality,
  :ndi_program_name,
  :ndi_source_settings,
  :ndi_output_timecode_source)
  SENSITIVE = []
  include Aws::Structure
end

#source_listener_addressString

Source IP or domain name for SRT-caller protocol.

Returns:

  • (String)


8166
8167
8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
8180
8181
8182
8183
8184
8185
8186
# File 'lib/aws-sdk-mediaconnect/types.rb', line 8166

class Transport < Struct.new(
  :cidr_allow_list,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :min_latency,
  :protocol,
  :remote_id,
  :sender_control_port,
  :sender_ip_address,
  :smoothing_latency,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :ndi_speed_hq_quality,
  :ndi_program_name,
  :ndi_source_settings,
  :ndi_output_timecode_source)
  SENSITIVE = []
  include Aws::Structure
end

#source_listener_portInteger

Source port for SRT-caller protocol.

Returns:

  • (Integer)


8166
8167
8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
8180
8181
8182
8183
8184
8185
8186
# File 'lib/aws-sdk-mediaconnect/types.rb', line 8166

class Transport < Struct.new(
  :cidr_allow_list,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :min_latency,
  :protocol,
  :remote_id,
  :sender_control_port,
  :sender_ip_address,
  :smoothing_latency,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :ndi_speed_hq_quality,
  :ndi_program_name,
  :ndi_source_settings,
  :ndi_output_timecode_source)
  SENSITIVE = []
  include Aws::Structure
end

#stream_idString

The stream ID that you want to use for this transport. This parameter applies only to Zixi and SRT caller-based streams.

Returns:

  • (String)


8166
8167
8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
8180
8181
8182
8183
8184
8185
8186
# File 'lib/aws-sdk-mediaconnect/types.rb', line 8166

class Transport < Struct.new(
  :cidr_allow_list,
  :max_bitrate,
  :max_latency,
  :max_sync_buffer,
  :min_latency,
  :protocol,
  :remote_id,
  :sender_control_port,
  :sender_ip_address,
  :smoothing_latency,
  :source_listener_address,
  :source_listener_port,
  :stream_id,
  :ndi_speed_hq_quality,
  :ndi_program_name,
  :ndi_source_settings,
  :ndi_output_timecode_source)
  SENSITIVE = []
  include Aws::Structure
end