Class: Aws::MediaConnect::Waiters::OutputActive
- Inherits:
-
Object
- Object
- Aws::MediaConnect::Waiters::OutputActive
- Defined in:
- lib/aws-sdk-mediaconnect/waiters.rb,
sig/waiters.rbs
Overview
Wait until the Output is ACTIVE
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ OutputActive
constructor
A new instance of OutputActive.
-
#wait(params = {}) ⇒ Types::GetRouterOutputResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ OutputActive
Returns a new instance of OutputActive.
483 484 |
# File 'lib/aws-sdk-mediaconnect/waiters.rb', line 483
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
543 544 545 |
# File 'lib/aws-sdk-mediaconnect/waiters.rb', line 543 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetRouterOutputResponse
Returns a response object which responds to the following methods:
- #router_output => Types::RouterOutput
538 |
# File 'lib/aws-sdk-mediaconnect/waiters.rb', line 538
def wait: (
|