Class: Aws::MediaConnect::Waiters::OutputDeleted
- Inherits:
-
Object
- Object
- Aws::MediaConnect::Waiters::OutputDeleted
- Defined in:
- lib/aws-sdk-mediaconnect/waiters.rb
Overview
Wait until the Output is deleted
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ OutputDeleted
constructor
A new instance of OutputDeleted.
-
#wait(params = {}) ⇒ Types::GetRouterOutputResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ OutputDeleted
Returns a new instance of OutputDeleted.
556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 |
# File 'lib/aws-sdk-mediaconnect/waiters.rb', line 556 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 40, delay: 3, poller: Aws::Waiters::Poller.new( operation_name: :get_router_output, acceptors: [ { "matcher" => "path", "argument" => "router_output.state", "state" => "retry", "expected" => "DELETING" }, { "matcher" => "error", "state" => "retry", "expected" => "InternalServerErrorException" }, { "matcher" => "error", "state" => "retry", "expected" => "ServiceUnavailableException" }, { "matcher" => "path", "argument" => "router_output.state", "state" => "failure", "expected" => "ERROR" }, { "matcher" => "error", "state" => "success", "expected" => "NotFoundException" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
603 604 605 |
# File 'lib/aws-sdk-mediaconnect/waiters.rb', line 603 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetRouterOutputResponse
Returns a response object which responds to the following methods:
-
#router_output => Types::RouterOutput
598 599 600 |
# File 'lib/aws-sdk-mediaconnect/waiters.rb', line 598 def wait(params = {}) @waiter.wait(client: @client, params: params) end |